@@ -22,7 +22,6 @@
 #include "CMapQMAP.h"
 #include "CMainWindow.h"
 #include "CCreateMapGeoTiff.h"
-
 #include "CMouseMoveMap.h"
 #include "CMouseZoomMap.h"
 #include "CMouseSelMap.h"
@@ -37,31 +36,37 @@
 #include "CMouseAddDistance.h"
 #include "CMouseOverlay.h"
 #include "CMouseColorPicker.h"
-
 #include "CWpt.h"
 #include "CTrack.h"
 #include "CSearchDB.h"
 #include "CWptDB.h"
 #include "CMapDB.h"
 #include "CTrackDB.h"
+#include "CTrackToolWidget.h"
 #include "CRouteDB.h"
 #include "CLiveLogDB.h"
 #include "COverlayDB.h"
-
 #include "CMegaMenu.h"
-
 #include "GeoMath.h"
 #include "WptIcons.h"
-
 #include "Platform.h"
-
 #include "IUnit.h"
-
-#include <QtGui>
 #include "CMenus.h"
 #include "CUndoStackView.h"
 #include "CCanvasUndoCommandZoom.h"
 #include "CMapUndoCommandMove.h"
+#include "CPlot.h"
+
+#include <QtGui>
+
+QPen CCanvas::penBorderBlue(QColor(10,10,150,220),3);
+QPen CCanvas::penBorderBlack(QColor(0,0,0,200),3);
+QBrush CCanvas::brushBackWhite(QColor(255,255,255,210));
+QBrush CCanvas::brushBackYellow(QColor(0xff, 0xff, 0xcc, 0xE0));
+
+#ifdef WIN32
+#define isnan(x) _isnan(x)
+#endif
 
 CCanvas::CCanvas(QWidget * parent)
 : QWidget(parent)
@@ -87,6 +92,14 @@ CCanvas::CCanvas(QWidget * parent)
     mouseColorPicker = new CMouseColorPicker(this);
 
     cursorFocus = false;
+
+    profile = new CPlot(CPlotData::eLinear, CPlot::eIcon, this);
+    profile->resize(300,120);
+    profile->hide();
+//    profile->setToolTip(tr("Click to edit track and to see large profile"));
+
+    connect(profile, SIGNAL(activePointSignal(double)), this, SLOT(slotActiveTrackPoint(double)));
+    connect(mouseMoveMap, SIGNAL(sigTrkPt(CTrack::pt_t*)), profile, SLOT(slotTrkPt(CTrack::pt_t*)));
 }
 
 
@@ -200,6 +213,12 @@ void CCanvas::setMouseMode(mouse_mode_e mode)
 void CCanvas::resizeEvent(QResizeEvent * e)
 {
     QWidget::resizeEvent(e);
+
+    QSize s = e->size();
+
+    profile->move(20, s.height() - profile->height() - 20);
+
+
     emit sigResize(e->size());
 }
 
@@ -221,7 +240,6 @@ void CCanvas::paintEvent(QPaintEvent * e)
 void CCanvas::mouseMoveEvent(QMouseEvent * e)
 {
     posMouse = e->pos();
-
     mouseMoveEventCoord(e);
     mouse->mouseMoveEvent(e);
 }
@@ -240,6 +258,22 @@ void CCanvas::mouseReleaseEvent(QMouseEvent * e)
     mouse->mouseReleaseEvent(e);
 }
 
+void CCanvas::mouseDoubleClickEvent(QMouseEvent * e)
+{
+    posMouse = e->pos();
+    mouse->mouseDoubleClickEvent(e);
+}
+
+void CCanvas::keyPressEvent(QKeyEvent * e)
+{
+    mouse->keyPressEvent(e);
+}
+
+void CCanvas::keyReleaseEvent(QKeyEvent * e)
+{
+    mouse->keyReleaseEvent(e);
+}
+
 
 void CCanvas::enterEvent(QEvent * )
 {
@@ -261,7 +295,7 @@ void CCanvas::leaveEvent(QEvent * )
 }
 
 
-#define BORDER  20
+#define BORDER  0
 
 void CCanvas::print(QPainter& p, const QSize& pagesize)
 {
@@ -269,6 +303,8 @@ void CCanvas::print(QPainter& p, const QSize& pagesize)
     QSize _size_ = pagesize;
     qreal s = 0.0;
 
+    qDebug() << "pagesize" << pagesize;
+
     p.save();
 
     if(pagesize.height() > pagesize.width())
@@ -288,7 +324,6 @@ void CCanvas::print(QPainter& p, const QSize& pagesize)
     p.translate(BORDER,BORDER);
     p.scale(s,s);
     p.setClipRegion(rect());
-    p.setRenderHint(QPainter::Antialiasing,true);
     p.setFont(CResources::self().getMapFont());
     draw(p);
     p.restore();
@@ -317,6 +352,67 @@ void CCanvas::print(QImage& img)
 
 }
 
+void CCanvas::print(QImage& img, const QSize& pagesize)
+{
+
+    bool rotate = false;
+    QSize s = pagesize ;
+    if(pagesize.width() < pagesize.height())
+    {
+        s = QSize(s.height(), s.width());
+        rotate = true;
+    }
+
+    img = QImage(s,  QImage::Format_ARGB32);
+    img.fill(Qt::white);
+
+    {
+        QPainter p(&img);
+        print(p, s);
+    }
+
+    if(rotate)
+    {
+        QMatrix matrix;
+        matrix.rotate(90);
+        img = img.transformed(matrix, Qt::SmoothTransformation);
+    }
+
+
+//    bool rotate = false;
+//    QImage _img_(size(), QImage::Format_ARGB32);
+//    if(pagesize.height() > pagesize.width())
+//    {
+//        _img_ = QImage(size().height(), size().width(), QImage::Format_ARGB32);
+//        rotate = true;
+//    }
+
+//    _img_.fill(Qt::white);
+
+//    QPainter p;
+//    p.begin(&_img_);
+//    if(rotate)
+//    {
+//        p.rotate(90.0);
+//        p.translate(0,-size().height());
+//    }
+//    draw(p);
+//    p.end();
+
+//    qreal s1 = (qreal)(_img_.width())  / (qreal)pagesize.width();
+//    qreal s2 = (qreal)(_img_.height()) / (qreal)pagesize.height();
+
+//    if(s1 < s2)
+//    {
+//        img = _img_.scaledToHeight(pagesize.height(),  Qt::SmoothTransformation);
+//    }
+//    else
+//    {
+//        img = _img_.scaledToWidth(pagesize.width(),  Qt::SmoothTransformation);
+//    }
+
+}
+
 
 void CCanvas::draw(QPainter& p)
 {
@@ -325,13 +421,15 @@ void CCanvas::draw(QPainter& p)
 
     // printf("draw canvas %d\n",needsRedraw);
 
+    USE_ANTI_ALIASING(p,!map.getFastDrawFlag() && CResources::self().useAntiAliasing());
+
     CMapDB::self().draw(p,rect(), needsRedraw);
-    CTrackDB::self().draw(p, rect(), needsRedraw);
     CRouteDB::self().draw(p, rect(), needsRedraw);
+    CTrackDB::self().draw(p, rect(), needsRedraw);
+    COverlayDB::self().draw(p, rect(), needsRedraw);
     CLiveLogDB::self().draw(p, rect(), needsRedraw);
     CWptDB::self().draw(p, rect(), needsRedraw);
     CSearchDB::self().draw(p, rect(), needsRedraw);
-    COverlayDB::self().draw(p, rect(), needsRedraw);
 
     drawRefPoints(p);
     drawScale(p);
@@ -358,7 +456,7 @@ void CCanvas::drawRefPoints(QPainter& p)
 
         if(rect().contains(x,y))
         {
-            p.drawPixmap(x - 15,y - 31,QPixmap(":/icons/iconRefPoint31x31"));
+            p.drawPixmap(x - 15,y - 31,QPixmap(":/icons/iconRefPoint31x31.png"));
             drawText(refpt->item->text(CCreateMapGeoTiff::eLabel),p,QPoint(x, y - 35));
         }
 
@@ -369,6 +467,11 @@ void CCanvas::drawRefPoints(QPainter& p)
 
 void CCanvas::drawScale(QPainter& p)
 {
+    if(!CResources::self().showScale())
+    {
+        return;
+    }
+
     IMap& map = CMapDB::self().getMap();
 
     double a,b,d;
@@ -465,6 +568,10 @@ void CCanvas::drawScale(QPainter& p)
 
 void CCanvas::drawCompass(QPainter& p)
 {
+    if(!CResources::self().showNorthIndicator())
+    {
+        return;
+    }
     QPolygon arrow;
 
 #define H 60
@@ -643,7 +750,7 @@ void CCanvas::mouseMoveEventCoord(QMouseEvent * e)
     {
         map.convertPt2M(x,y);
         info += QString(" (%1 %2)").arg(x,0,'f',0).arg(y,0,'f',0);
-        qDebug() << "--" << info;
+//        qDebug() << "--" << info;
     }
     else
     {
@@ -685,7 +792,7 @@ void CCanvas::raiseContextMenu(const QPoint& pos)
         }
         menu.addSeparator();
     }
-    menu.addAction(QIcon(":/icons/iconClipboard16x16.png"),tr("Copy Position"),this,SLOT(slotCopyPosition()));
+//    menu.addAction(QIcon(":/icons/iconClipboard16x16.png"),tr("Copy Position"),this,SLOT(slotCopyPosition()));
     mouse->contextMenu(menu);
 
     QPoint p = mapToGlobal(pos);
@@ -698,3 +805,74 @@ void CCanvas::showEvent ( QShowEvent * event )
     IMap& map = CMapDB::self().getMap();
     map.resize(size());
 }
+
+void CCanvas::slotTrackChanged()
+{
+    CTrack * trk = CTrackDB::self().highlightedTrack();
+    slotHighlightTrack(trk);
+}
+
+void CCanvas::slotActiveTrackPoint(double dist)
+{
+    CTrack * trk = CTrackDB::self().highlightedTrack();
+    if(trk == 0)
+    {
+        return;
+    }
+    CTrack::pt_t * pt = trk->getPointOfFocus(dist);
+    if(pt == 0)
+    {
+        return;
+    }
+
+    mouseMoveMap->setSelTrackPt(pt);
+}
+
+void CCanvas::slotHighlightTrack(CTrack * track)
+{
+    if(track && CResources::self().showTrackProfilePreview())
+    {
+        QPolygonF lineElev;
+        QPointF   focusElev;
+        float basefactor = IUnit::self().basefactor;
+
+        profile->clear();
+
+        QList<CTrack::pt_t>& trkpts = track->getTrackPoints();
+        QList<CTrack::pt_t>::const_iterator trkpt = trkpts.begin();
+        while(trkpt != trkpts.end())
+        {
+            if(trkpt->flags & CTrack::pt_t::eDeleted)
+            {
+                ++trkpt; continue;
+            }
+
+            if(trkpt->ele != WPT_NOFLOAT)
+            {
+                lineElev << QPointF(trkpt->distance, trkpt->ele * basefactor);
+            }
+
+            if(trkpt->flags & CTrack::pt_t::eFocus)
+            {
+                focusElev  = QPointF(trkpt->distance, trkpt->ele * basefactor);
+            }
+
+            trkpt++;
+        }
+
+        profile->newLine(lineElev,focusElev, "GPS");
+        profile->setXLabel(track->getName());
+        profile->setLimits();
+        profile->resetZoom();
+        profile->show();
+        disconnect(profile, SIGNAL(sigClicked()), CTrackDB::self().getToolWidget(), SLOT(slotShowProfile()));
+        connect(profile, SIGNAL(sigClicked()), CTrackDB::self().getToolWidget(), SLOT(slotShowProfile()));
+
+    }
+    else
+    {
+        profile->clear();
+        profile->hide();
+        disconnect(profile, SIGNAL(sigClicked()), CTrackDB::self().getToolWidget(), SLOT(slotShowProfile()));
+    }
+}
