@@ -24,6 +24,7 @@
 
 #include <QWidget>
 #include <QPointer>
+#include <QPainter>
 
 class IMouse;
 class CMouseMoveMap;
@@ -46,6 +47,16 @@ class QMenu;
 class CMouseCutTrack;
 class CMouseSelTrack;
 class QFont;
+class CPlot;
+class CTrack;
+
+#define PAINT_ROUNDED_RECT(p,r) p.drawRoundedRect(r,5,5)
+
+
+inline  void USE_ANTI_ALIASING(QPainter& p, bool useAntiAliasing)
+{
+    p.setRenderHints(QPainter::TextAntialiasing|QPainter::Antialiasing|QPainter::SmoothPixmapTransform|QPainter::HighQualityAntialiasing, useAntiAliasing);
+}
 
 /// the map canvas area
 class CCanvas : public QWidget
@@ -98,6 +109,7 @@ class CCanvas : public QWidget
         void print(QImage& img);
 
         void print(QPainter& p, const QSize& pagesize);
+        void print(QImage& img, const QSize& pagesize);
 
         /// change the current mouse mode
         void setMouseMode(mouse_mode_e mode);
@@ -112,11 +124,19 @@ class CCanvas : public QWidget
         /// get selected color from color picker cursor
         QColor getSelectedColor();
 
+        static QPen penBorderBlue;
+        static QPen penBorderBlack;
+        static QBrush brushBackWhite;
+        static QBrush brushBackYellow;
+
         signals:
         void sigResize(const QSize& size);
 
     private slots:
         void slotCopyPosition();
+        void slotHighlightTrack(CTrack * track);
+        void slotTrackChanged();
+        void slotActiveTrackPoint(double dist);
 
     protected:
         void paintEvent(QPaintEvent * e);
@@ -124,7 +144,10 @@ class CCanvas : public QWidget
         void mouseMoveEvent(QMouseEvent * e);
         void mousePressEvent(QMouseEvent * e);
         void mouseReleaseEvent(QMouseEvent * e);
+        void mouseDoubleClickEvent(QMouseEvent * e);
         void wheelEvent(QWheelEvent * e);
+        void keyPressEvent(QKeyEvent *);
+        void keyReleaseEvent(QKeyEvent *);
         void showEvent ( QShowEvent * event);
 
         /// set override cursor
@@ -166,5 +189,7 @@ class CCanvas : public QWidget
         QPoint posMouse;
 
         QLabel * info;
+
+        CPlot * profile;
 };
 #endif                           //CCANVAS_H
