@@ -24,6 +24,8 @@
 #include "CMapDB.h"
 #include "GeoMath.h"
 
+#include "config.h"
+
 #include <projects.h>
 #ifdef __MINGW32__
 #undef LP
@@ -44,11 +46,11 @@ CCreateMapGeoTiff::CCreateMapGeoTiff(QWidget * parent)
 {
     m_self = this;
     setupUi(this);
-    labelStep1->setPixmap(QPixmap(":/pics/Step1"));
-    labelStep2->setPixmap(QPixmap(":/pics/Step2"));
-    labelStep3->setPixmap(QPixmap(":/pics/Step3"));
+    labelStep1->setPixmap(QPixmap(":/pics/Step1.png"));
+    labelStep2->setPixmap(QPixmap(":/pics/Step2.png"));
+    labelStep3->setPixmap(QPixmap(":/pics/Step3.png"));
 
-    toolReload->setIcon(QPixmap(":/icons/iconReload16x16"));
+    toolReload->setIcon(QPixmap(":/icons/iconReload16x16.png"));
     toolOutFile->setIcon(QPixmap(":/icons/iconFileSave16x16.png"));
 
     helpStep1->setHelp(tr("Load Raster Map"),
@@ -81,6 +83,11 @@ CCreateMapGeoTiff::CCreateMapGeoTiff(QWidget * parent)
     QSettings cfg;
     lineMapProjection->setText(cfg.value("create/mapproj","+proj=merc +ellps=WGS84 +datum=WGS84 +no_defs").toString());
     lineGCPProjection->setText(cfg.value("create/gcpproj","+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs").toString());
+    check2x->setChecked(cfg.value("create/overview/2", false).toBool());
+    check4x->setChecked(cfg.value("create/overview/4", false).toBool());
+    check8x->setChecked(cfg.value("create/overview/8", false).toBool());
+    check16x->setChecked(cfg.value("create/overview/16", false).toBool());
+    check32x->setChecked(cfg.value("create/overview/32", false).toBool());
 
     comboMode->addItem(tr("square pixels (2 Ref. Pts.)"), eSquare);
     comboMode->addItem(tr("linear (3 Ref. Pts.)"), eLinear);
@@ -92,6 +99,7 @@ CCreateMapGeoTiff::CCreateMapGeoTiff(QWidget * parent)
     toolGCPProjWizard->setIcon(QPixmap(":/icons/iconWizzard16x16.png"));
 
     theMainWindow->getCanvas()->setMouseMode(CCanvas::eMouseMoveRefPoint);
+    theMainWindow->getCanvas()->installEventFilter(this);
 }
 
 CCreateMapGeoTiff::~CCreateMapGeoTiff()
@@ -99,8 +107,68 @@ CCreateMapGeoTiff::~CCreateMapGeoTiff()
     if(closemap) CMapDB::self().closeMap();
     if(theMainWindow->getCanvas()) theMainWindow->getCanvas()->setMouseMode(CCanvas::eMouseMoveArea);
     m_self = 0;
+
+    QSettings cfg;
+    cfg.setValue("create/overview/2", check2x->isChecked());
+    cfg.setValue("create/overview/4", check4x->isChecked());
+    cfg.setValue("create/overview/8", check8x->isChecked());
+    cfg.setValue("create/overview/16", check16x->isChecked());
+    cfg.setValue("create/overview/32", check32x->isChecked());
+
 }
 
+bool CCreateMapGeoTiff::eventFilter(QObject * watched, QEvent * event)
+{
+    if(watched == theMainWindow->getCanvas())
+    {
+        if(event->type() == QEvent::KeyPress)
+        {
+            int idx;
+            QTreeWidgetItem * item;
+            QKeyEvent * e = (QKeyEvent*)event;
+
+            if(e->key() != Qt::Key_N && e->key() != Qt::Key_B)
+            {
+                return QWidget::eventFilter(watched, event);
+            }
+
+            item = treeWidget->currentItem();
+            idx = treeWidget->indexOfTopLevelItem(item);
+            if(idx < 0)
+            {
+                return QWidget::eventFilter(watched, event);
+            }
+
+            if(e->key() == Qt::Key_N)
+            {
+                idx++;
+            }
+            else
+            {
+                idx--;
+            }
+
+
+            if(idx < 0)
+            {
+                return QWidget::eventFilter(watched, event);
+            }
+
+            if(idx >= treeWidget->topLevelItemCount())
+            {
+                return QWidget::eventFilter(watched, event);
+            }
+
+            item = treeWidget->topLevelItem(idx);
+            treeWidget->setCurrentItem(item);
+            treeWidget->scrollToItem(item);
+            slotItemDoubleClicked(item);
+
+        }
+    }
+
+    return QWidget::eventFilter(watched, event);
+}
 
 void CCreateMapGeoTiff::selRefPointByKey(const quint32 key)
 {
@@ -166,7 +234,7 @@ void CCreateMapGeoTiff::slotOpenFile()
     QSettings cfg;
     path = QDir(cfg.value("path/create",path.path()).toString());
 
-    QString filename = QFileDialog::getOpenFileName(0, tr("Open map file..."),path.path(), tr("Raw bitmaps (*.tif *.tiff *.png *.gif)"), 0, QFileDialog::DontUseNativeDialog);
+    QString filename = QFileDialog::getOpenFileName(0, tr("Open map file..."),path.path(), tr("Raw bitmaps (*.tif *.tiff *.png *.gif)"), 0, FILE_DIALOG_FLAGS);
     if(filename.isEmpty()) return;
 
     CMapDB::self().openMap(filename, true, *theMainWindow->getCanvas());
@@ -210,7 +278,7 @@ void CCreateMapGeoTiff::slotOutFile()
     QSettings cfg;
     path = QDir(cfg.value("path/create",path.path()).toString());
 
-    QString filename = QFileDialog::getSaveFileName(0, tr("Save result as..."),path.filePath(labelOutputFile->text()), tr("GeoTiff (*.tif *.tiff)"), 0, QFileDialog::DontUseNativeDialog);
+    QString filename = QFileDialog::getSaveFileName(0, tr("Save result as..."),path.filePath(labelOutputFile->text()), tr("GeoTiff (*.tif *.tiff)"), 0, FILE_DIALOG_FLAGS);
     if(filename.isEmpty()) return;
 
     labelOutputFile->setText(filename);
@@ -353,7 +421,7 @@ void CCreateMapGeoTiff::slotDelRef()
 void CCreateMapGeoTiff::slotLoadRef()
 {
 
-    QString filename = QFileDialog::getOpenFileName(0, tr("Load reference points..."),path.path(),"Ref. points (*.gcp *.tab)", 0, QFileDialog::DontUseNativeDialog);
+    QString filename = QFileDialog::getOpenFileName(0, tr("Load reference points..."),path.path(),"Ref. points (*.gcp *.tab)", 0, FILE_DIALOG_FLAGS);
     if(filename.isEmpty()) return;
 
     QFileInfo fi(filename);
@@ -542,7 +610,7 @@ void CCreateMapGeoTiff::slotSaveRef()
     QFileInfo fin(labelInputFile->text());
     QString base = fin.baseName();
 
-    QString filename = QFileDialog::getSaveFileName(0, tr("Save reference points..."),path.filePath(base),"Ref. points (*.gcp);;Mapinfo (*.tab)", &filter, QFileDialog::DontUseNativeDialog);
+    QString filename = QFileDialog::getSaveFileName(0, tr("Save reference points..."),path.filePath(base),"Ref. points (*.gcp);;Mapinfo (*.tab)", &filter, FILE_DIALOG_FLAGS);
     if(filename.isEmpty()) return;
 
     qDebug() << filename;
@@ -822,6 +890,7 @@ void CCreateMapGeoTiff::slotFinished( int exitCode, QProcess::ExitStatus status)
         {
             args << "-r" << "cubic";
         }
+
         args << "-dstnodata" << "\"255\"";
         args << tmpfile1->fileName();
 
@@ -847,7 +916,6 @@ void CCreateMapGeoTiff::slotFinished( int exitCode, QProcess::ExitStatus status)
         args << "-co" << "blockxsize=256";
         args << "-co" << "blockysize=256";
         args << "-co" << "compress=deflate";
-        args << "-co" << "predictor=1";
         args << tmpfile2->fileName();
         args << labelOutputFile->text();
 
@@ -857,6 +925,55 @@ void CCreateMapGeoTiff::slotFinished( int exitCode, QProcess::ExitStatus status)
         cmd.start(GDALTRANSLATE, args);
         return;
     }
+    if(state == eTile)
+    {
+        IMap& map = CMapDB::self().getMap();
+        state = eOverview;
+
+        QStringList args;
+        if(map.is32BitRgb())
+        {
+            args << "-r" << "cubic";
+        }
+        else
+        {
+            args << "-r" << "average";
+        }
+        args << "--config" << "COMPRESS_OVERVIEW" << "JPEG";
+        args << labelOutputFile->text();
+
+        if(check2x->isChecked())
+        {
+            args << "2";
+        }
+        if(check4x->isChecked())
+        {
+            args << "4";
+        }
+        if(check8x->isChecked())
+        {
+            args << "8";
+        }
+        if(check16x->isChecked())
+        {
+            args << "16";
+        }
+        if(check32x->isChecked())
+        {
+            args << "32";
+        }
+
+        if(args.count() > 6)
+        {
+
+            textBrowser->setTextColor(Qt::black);
+            textBrowser->append(GDALADDO " " +  args.join(" ") + "\n");
+
+            cmd.start(GDALADDO, args);
+            return;
+        }
+
+    }
     cleanupTmpFiles();
 
     textBrowser->setTextColor(Qt::black);
