@@ -72,6 +72,8 @@ class CCreateMapGeoTiff : public QWidget, private Ui::ICreateMapGeoTiff
 
         void selRefPointByKey(const quint32 key);
 
+        bool eventFilter(QObject * watched, QEvent * event);
+
     protected:
         void keyPressEvent(QKeyEvent * e);
 
@@ -122,7 +124,7 @@ class CCreateMapGeoTiff : public QWidget, private Ui::ICreateMapGeoTiff
 
         QProcess cmd;
 
-        enum state_e {eNone, eTranslate, eWarp, eTile};
+        enum state_e {eNone, eTranslate, eWarp, eTile, eOverview};
         state_e state;
 
         QPointer<QTemporaryFile> tmpfile1;
