@@ -24,6 +24,8 @@
 #include "CMainWindow.h"
 #include "CMapDB.h"
 
+#include "config.h"
+
 #include <QtGui>
 
 CCreateMapQMAP::CCreateMapQMAP(QWidget * parent)
@@ -54,8 +56,8 @@ CCreateMapQMAP::CCreateMapQMAP(QWidget * parent)
     connect(pushDown, SIGNAL(clicked()), this, SLOT(slotDown()));
     connect(pushSave, SIGNAL(clicked()), this, SLOT(slotSaveMap()));
 
-    labelStep1->setPixmap(QPixmap(":/pics/Step1"));
-    labelStep2->setPixmap(QPixmap(":/pics/Step2"));
+    labelStep1->setPixmap(QPixmap(":/pics/Step1.png"));
+    labelStep2->setPixmap(QPixmap(":/pics/Step2.png"));
 
 }
 
@@ -69,7 +71,7 @@ CCreateMapQMAP::~CCreateMapQMAP()
 
 void CCreateMapQMAP::slotOpenMap()
 {
-    QString filename = QFileDialog::getOpenFileName(0,tr("Select map definition file..."), mapPath,"QLandkarte map (*.qmap)", 0, QFileDialog::DontUseNativeDialog);
+    QString filename = QFileDialog::getOpenFileName(0,tr("Select map definition file..."), mapPath,"QLandkarte map (*.qmap)", 0, FILE_DIALOG_FLAGS);
 
     if(filename.isEmpty()) return;
     mapPath = QFileInfo(filename).path();
@@ -83,7 +85,7 @@ void CCreateMapQMAP::slotNewMap()
 {
     QString filename;
 
-    filename = QFileDialog::getSaveFileName(0,tr("Define a map collection file..."), mapPath,"QLandkarte map (*.qmap)", 0, QFileDialog::DontUseNativeDialog);
+    filename = QFileDialog::getSaveFileName(0,tr("Define a map collection file..."), mapPath,"QLandkarte map (*.qmap)", 0, FILE_DIALOG_FLAGS);
     if(filename.isEmpty()) return;
 
     QFileInfo fi(filename);
@@ -107,7 +109,7 @@ void CCreateMapQMAP::slotSaveMap()
     QString filename = labelCurrentMap->text();
     if(filename.isEmpty())
     {
-        filename = QFileDialog::getSaveFileName(0,tr("Define a map collection file..."), mapPath,"QLandkarte map (*.qmap)", 0, QFileDialog::DontUseNativeDialog);
+        filename = QFileDialog::getSaveFileName(0,tr("Define a map collection file..."), mapPath,"QLandkarte map (*.qmap)", 0, FILE_DIALOG_FLAGS);
         if(filename.isEmpty()) return;
     }
 
@@ -144,7 +146,7 @@ void CCreateMapQMAP::mapData2Item(QTreeWidgetItem *& item)
 
     foreach(file, files)
     {
-        CMapFile map(QDir(mapPath).filePath(file).toUtf8(),this);
+        CMapFile map(QDir(mapPath).filePath(file),this);
         if(!map.ok)
         {
             QMessageBox::critical(this,tr("Error..."), tr("Failed to load file %1.").arg(file), QMessageBox::Ok, QMessageBox::Ok);
@@ -160,11 +162,6 @@ void CCreateMapQMAP::mapData2Item(QTreeWidgetItem *& item)
         }
         projection = map.strProj;
 
-        //         if((xscale && (xscale != map.xscale)) || (yscale && (yscale != map.yscale))) {
-        //             QMessageBox::critical(this,tr("Error..."), tr("All maps in a level must have the x and y scale."), QMessageBox::Ok, QMessageBox::Ok);
-        //             delete item;
-        //             return;
-        //         }
         xscale = map.xscale;
         yscale = map.yscale;
 
