@@ -586,7 +586,7 @@ void CDeviceGarmin::slotTimeout()
     {
         dev->getRealTimePos(pvt);
     }
-    catch(int e)
+    catch(int)
     {
         timer->stop();
         log.fix = CLiveLog::eOff;
@@ -637,8 +637,8 @@ void CDeviceGarmin::slotTimeout()
 
         log.heading     = heading;
         log.velocity    = sqrtf( pvt.north * pvt.north + pvt.east * pvt.east );
-        log.error_horz  = pvt.eph;
-        log.error_vert  = pvt.epv;
+        log.error_horz  = pvt.eph/2.0;  //HS: moved division by 2 from CLiveLogDB.cpp
+        log.error_vert  = pvt.epv/2.0;  //HS: moved division by 2 from CLiveLogDB.cpp
     }
 
     emit sigLiveLog(log);
@@ -662,7 +662,7 @@ void CDeviceGarmin::uploadWpts(const QList<CWpt*>& wpts)
         garmin_icon_t * icon = GarminIcons;
         while(icon->name != 0)
         {
-            if((*wpt)->icon == icon->name)
+            if((*wpt)->getIconString() == icon->name)
             {
                 garwpt.smbl = icon->id;
                 break;
@@ -674,8 +674,14 @@ void CDeviceGarmin::uploadWpts(const QList<CWpt*>& wpts)
         garwpt.lon      = (*wpt)->lon;
         garwpt.alt      = (*wpt)->ele;
         garwpt.dist     = (*wpt)->prx;
-        garwpt.ident    = codec->fromUnicode((*wpt)->name).data();
-        garwpt.comment  = codec->fromUnicode((*wpt)->comment).data();
+        garwpt.ident    = codec->fromUnicode((*wpt)->getName()).data();
+
+        QString comment = (*wpt)->getComment();
+        comment.remove(QRegExp("<head.*[^>]*><\\/head>"));
+        comment.remove(QRegExp("<[^>]*>"));
+        comment = comment.simplified();
+
+        garwpt.comment  = codec->fromUnicode(comment).data();
 
         garwpts.push_back(garwpt);
 
@@ -693,7 +699,7 @@ void CDeviceGarmin::uploadWpts(const QList<CWpt*>& wpts)
 
         QApplication::restoreOverrideCursor();
     }
-    catch(int e)
+    catch(int)
     {
         QMessageBox::warning(0,tr("Device Link Error"),dev->getLastError().c_str(),QMessageBox::Ok,QMessageBox::NoButton);
         QApplication::restoreOverrideCursor();
@@ -721,7 +727,7 @@ void CDeviceGarmin::downloadWpts(QList<CWpt*>& wpts)
 
         QApplication::restoreOverrideCursor();
     }
-    catch(int e)
+    catch(int)
     {
         QMessageBox::warning(0,tr("Device Link Error"),dev->getLastError().c_str(),QMessageBox::Ok,QMessageBox::NoButton);
         QApplication::restoreOverrideCursor();
@@ -735,8 +741,8 @@ void CDeviceGarmin::downloadWpts(QList<CWpt*>& wpts)
     {
         CWpt * wpt = new CWpt(&CWptDB::self());
 
-        wpt->name       = codec->toUnicode(garwpt->ident.c_str());
-        wpt->comment    = codec->toUnicode(garwpt->comment.c_str());
+        wpt->setName(codec->toUnicode(garwpt->ident.c_str()));
+        wpt->setComment(codec->toUnicode(garwpt->comment.c_str()));
         wpt->lon        = garwpt->lon;
         wpt->lat        = garwpt->lat;
         wpt->ele        = garwpt->alt;
@@ -747,7 +753,7 @@ void CDeviceGarmin::downloadWpts(QList<CWpt*>& wpts)
         {
             if(garwpt->smbl == icon->id)
             {
-                wpt->icon = icon->name;
+                wpt->setIcon(icon->name);
                 break;
             }
             ++icon;
@@ -811,7 +817,7 @@ void CDeviceGarmin::uploadTracks(const QList<CTrack*>& trks)
 
         QApplication::restoreOverrideCursor();
     }
-    catch(int e)
+    catch(int)
     {
         QMessageBox::warning(0,tr("Device Link Error"),dev->getLastError().c_str(),QMessageBox::Ok,QMessageBox::NoButton);
         QApplication::restoreOverrideCursor();
@@ -839,7 +845,7 @@ void CDeviceGarmin::downloadTracks(QList<CTrack*>& trks)
 
         QApplication::restoreOverrideCursor();
     }
-    catch(int e)
+    catch(int)
     {
         QMessageBox::warning(0,tr("Device Link Error"),dev->getLastError().c_str(),QMessageBox::Ok,QMessageBox::NoButton);
         QApplication::restoreOverrideCursor();
@@ -909,7 +915,7 @@ void CDeviceGarmin::downloadScreenshot(QImage& image)
 
         QApplication::restoreOverrideCursor();
     }
-    catch(int e)
+    catch(int)
     {
         QMessageBox::warning(0,tr("Device Link Error"),dev->getLastError().c_str(),QMessageBox::Ok,QMessageBox::NoButton);
         QApplication::restoreOverrideCursor();
@@ -967,7 +973,7 @@ void CDeviceGarmin::uploadRoutes(const QList<CRoute*>& rtes)
         garmin_icon_t * icon = GarminIcons;
         while(icon->name != 0)
         {
-            if((*rte)->getIconName() == icon->name)
+            if((*rte)->getIconString() == icon->name)
             {
                 smbl = icon->id;
                 break;
@@ -979,14 +985,14 @@ void CDeviceGarmin::uploadRoutes(const QList<CRoute*>& rtes)
         garrte.ident = codec->fromUnicode(name).data();
 
         unsigned cnt = 0;
-        const QList<XY>& rtepts         = (*rte)->getRoutePoints();
-        QList<XY>::const_iterator rtept =  rtepts.begin();
+        const QVector<CRoute::pt_t>& rtepts         = (*rte)->getSecRtePoints().isEmpty() ? (*rte)->getPriRtePoints() : (*rte)->getSecRtePoints();
+        QVector<CRoute::pt_t>::const_iterator rtept =  rtepts.begin();
         while(rtept != rtepts.end())
         {
             Garmin::RtePt_t garrtept;
 
-            garrtept.lon            = rtept->u;
-            garrtept.lat            = rtept->v;
+            garrtept.lon            = rtept->lon;
+            garrtept.lat            = rtept->lat;
             garrtept.Wpt_t::ident   = QString("%1.%2").arg(id).arg(++cnt,3,10,QChar('0')).toAscii().data();
             garrtept.Wpt_t::comment = codec->fromUnicode(name).data();
             garrtept.Wpt_t::smbl    = smbl;
@@ -1010,7 +1016,7 @@ void CDeviceGarmin::uploadRoutes(const QList<CRoute*>& rtes)
 
         QApplication::restoreOverrideCursor();
     }
-    catch(int e)
+    catch(int)
     {
         QMessageBox::warning(0,tr("Device Link Error"),dev->getLastError().c_str(),QMessageBox::Ok,QMessageBox::NoButton);
         QApplication::restoreOverrideCursor();
@@ -1038,7 +1044,7 @@ void CDeviceGarmin::downloadRoutes(QList<CRoute*>& rtes)
 
         QApplication::restoreOverrideCursor();
     }
-    catch(int e)
+    catch(int)
     {
         QMessageBox::warning(0,tr("Device Link Error"),dev->getLastError().c_str(),QMessageBox::Ok,QMessageBox::NoButton);
         QApplication::restoreOverrideCursor();
@@ -1058,11 +1064,11 @@ void CDeviceGarmin::downloadRoutes(QList<CRoute*>& rtes)
         std::vector<Garmin::RtePt_t>::const_iterator garrtept = garrte->route.begin();
         while(garrtept != garrte->route.end())
         {
-            rte->addPosition(garrtept->lon, garrtept->lat);
+            rte->addPosition(garrtept->lon, garrtept->lat, garrtept->ident.c_str());
             ++garrtept;
         }
 
-        if(rte->getRoutePoints().count() > 0)
+        if(rte->getPriRtePoints().count() > 0)
         {
             rtes << rte;
         }
@@ -1129,7 +1135,7 @@ void CDeviceGarmin::uploadMap(const QList<IMapSelection*>& mss)
         }
         QApplication::restoreOverrideCursor();
     }
-    catch(int e)
+    catch(int)
     {
         QMessageBox::warning(0,tr("Device Link Error"),dev->getLastError().c_str(),QMessageBox::Ok,QMessageBox::NoButton);
         QApplication::restoreOverrideCursor();
@@ -1144,11 +1150,13 @@ void CDeviceGarmin::setLiveLog(bool on)
     Garmin::IDevice * dev = getDevice();
     if(dev == 0) return;
 
+    log.error_unit = "m";
+
     try
     {
         dev->setRealTimeMode(on);
     }
-    catch(int e)
+    catch(int)
     {
         timer->stop();
         log.fix = CLiveLog::eOff;
