@@ -20,40 +20,76 @@
 #ifndef CDIARY_H
 #define CDIARY_H
 
-#include <QObject>
+
+#include "IItem.h"
 #include <QDataStream>
 #include <QFile>
+#include <QPointer>
 
-class CDiary : public QObject
+class CDiaryEdit;
+class CTabWidget;
+
+class CWpt;
+class CTrack;
+class CRoute;
+class QTextFrame;
+class QTextTable;
+
+
+class CDiary : public IItem
 {
     Q_OBJECT;
     public:
         CDiary(QObject * parent);
-        CDiary(const CDiary& parent);
         virtual ~CDiary();
 
-        enum type_e {eEnd,eBase};
+        enum type_e {eEnd,eBase, eWpt, eTrk, eRte};
 
-        QString text(){return m_text;}
-        void setText(const QString& t){m_text = t;}
+        QString getInfo();
 
-        CDiary& operator=(const CDiary& d)
-        {
-            setParent(d.parent());
-            timestamp   = d.timestamp;
-            m_text      = d.m_text;
-            return *this;
-        }
+        void setIcon(const QString&){}
+
+        void linkToProject(quint64 key);
+
+        void showEditWidget(CTabWidget * tab, bool fromDB);
+
+        void clear();
+
+        QList<CWpt*>& getWpts(){return wpts;}
+        QList<CTrack*>& getTrks(){return trks;}
+        QList<CRoute*>& getRtes(){return rtes;}
+
+        bool isModified();       
+
+        void setModified();
+
+    signals:
+        void sigChanged();
+
+    private slots:
+        void slotEditWidgetDied(QObject*);
 
     private:
         friend QDataStream& operator >>(QDataStream& s, CDiary& diary);
         friend QDataStream& operator <<(QDataStream& s, CDiary& diary);
+        friend class CDiaryEdit;
+        friend class CDiaryDB;
 
-        /// creation timestamp
-        quint32 timestamp;
-        /// diary text
-        QString m_text;
+        quint64 keyProjectGeoDB;
 
+        QPointer<CDiaryEdit> editWidget;
+
+        QList<CWpt*> wpts;
+        QList<CRoute*> rtes;
+        QList<CTrack*> trks;
+
+        QPointer<QTextTable> tblWpt;
+        QPointer<QTextTable> tblTrk;
+        QPointer<QTextTable> tblRte;
+
+        QPointer<QTextFrame> diaryFrame;
+
+        bool modified;
 };
 
 QDataStream& operator >>(QDataStream& s, CDiary& diary);
