@@ -21,6 +21,8 @@
 #include "CResources.h"
 #include "IDevice.h"
 
+#include "config.h"
+
 #include <QtGui>
 
 CDlgScreenshot::CDlgScreenshot(QWidget * parent)
@@ -56,17 +58,29 @@ void CDlgScreenshot::slotSave()
 {
     QSettings cfg;
     QString pathData = cfg.value("path/data","./").toString();
+    QString filter = cfg.value("screenshot/imagetype","Bitmap (*.png)").toString();
 
-    QString filter;
     QString filename = QFileDialog::getSaveFileName( 0, tr("Select output file")
         ,pathData
-        ,"Bitmap (*.bmp);;"
+        ,"Bitmap (*.png)"
         ,&filter
-        , QFileDialog::DontUseNativeDialog
+        , FILE_DIALOG_FLAGS
         );
 
     if(filename.isEmpty()) return;
 
+    QFileInfo fi(filename);
+
+    if(fi.suffix().toLower() != "png")
+    {
+        filename += ".png";
+    }
+
+
     image.save(filename);
 
+
+    pathData = fi.absolutePath();
+    cfg.setValue("path/data", pathData);
+    cfg.setValue("screenshot/imagetype", filter);
 }
