@@ -254,11 +254,11 @@ void CGarminTile::readBasics(const QString& fn)
         QMap<QString,subfile_desc_t>::const_iterator subfile = subfiles.begin();
         while(subfile != subfiles.end())
         {
-            //             qDebug() << "--- subfile" << subfile->name << "---";
+            qDebug() << "--- subfile" << subfile->name << "---";
             QMap<QString,subfile_part_t>::const_iterator part = subfile->parts.begin();
             while(part != subfile->parts.end())
             {
-                //                 qDebug() << part.key() << hex << part->offset << part->size;
+                qDebug() << part.key() << hex << part->offset << part->size;
                 ++part;
             }
             ++subfile;
@@ -274,11 +274,67 @@ void CGarminTile::readBasics(const QString& fn)
         if((*subfile).parts.contains("GMP")) throw exce_t(errFormat,tr("File is NT format. QLandkarte GT is unable to read map files with NT format: ") + filename);
 
         readSubfileBasics(*subfile, file);
+
+// dem test code ----- start
+        if((*subfile).parts.contains("DEM"))
+        {
+//            qDebug() <<   fn;
+//            readDEM(*subfile, file);
+        }
+// dem test code ----- end
         ++subfile;
     }
 }
 
 
+void CGarminTile::readDEM(subfile_desc_t& subfile, QFileExt &file)
+{
+    quint32 i;
+
+    QByteArray demhdr;
+    readFile(file, subfile.parts["DEM"].offset, sizeof(hdr_dem_t), demhdr);
+    hdr_dem_t * pDemHdr = (hdr_dem_t * )demhdr.data();
+
+
+    quint16 levels  = gar_load(uint16_t,pDemHdr->levels);
+    quint32 size    = gar_load(uint32_t, pDemHdr->blk3_size);
+    quint32 offset  = gar_load(uint32_t, pDemHdr->blk3_offset);
+
+    qDebug() << "flags " << hex << pDemHdr->dem_flags;
+    qDebug() << "levels" << hex << levels;
+    qDebug() << "length" << hex << size;
+    qDebug() << "offset" << hex << offset;
+
+
+    for(i = 0; i < levels; i++)
+    {
+        QByteArray demlevel;
+        readFile(file, subfile.parts["DEM"].offset + offset + i * size, size, demlevel);
+        const dem_level_t * pDemLevel = (const dem_level_t * )demlevel.data();
+
+        qDebug() << "---------------------------------------------";
+        qDebug() << "index              " << hex << pDemLevel->index;
+        qDebug() << "nPixelPerTileX     " << hex << pDemLevel->nPixelPerTileX;
+        qDebug() << "nPixelPerTileY     " << hex << pDemLevel->nPixelPerTileY;
+        qDebug() << "Unknown1           " << hex << pDemLevel->Unknown1;
+        qDebug() << "Unknown2           " << hex << pDemLevel->Unknown2;
+        qDebug() << "Unknown3           " << hex << pDemLevel->Unknown3;
+        qDebug() << "nTilesX            " << hex << pDemLevel->nTilesX;
+        qDebug() << "nTilesY            " << hex << pDemLevel->nTilesY;
+        qDebug() << "format             " << hex << pDemLevel->format;
+        qDebug() << "blk1_size          " << hex << pDemLevel->blk1_size;
+        qDebug() << "blk1_offset        " << hex << pDemLevel->blk1_offset;
+        qDebug() << "blk2_offset        " << hex << pDemLevel->blk2_offset;
+        qDebug() << "westernBound       " << hex << pDemLevel->westernBound  << dec << pDemLevel->westernBound * 180.0 / 0x7FFFFFFF;
+        qDebug() << "northernBound      " << hex << pDemLevel->northernBound << dec << pDemLevel->northernBound * 180.0 / 0x7FFFFFFF;
+        qDebug() << "PixelPerMeterX     " << hex << pDemLevel->PixelPerMeterX << dec << pDemLevel->PixelPerMeterX;
+        qDebug() << "PixelPerMeterY     " << hex << pDemLevel->PixelPerMeterY << dec << pDemLevel->PixelPerMeterY;
+        qDebug() << "minHeight          " << hex << pDemLevel->minHeight << dec << pDemLevel->minHeight;
+        qDebug() << "maxHeight          " << hex << pDemLevel->maxHeight << dec << pDemLevel->maxHeight;
+    }
+
+}
+
 //static quint32 rgnoff = 0;
 void CGarminTile::readSubfileBasics(subfile_desc_t& subfile, QFileExt &file)
 {
@@ -309,13 +365,13 @@ void CGarminTile::readSubfileBasics(subfile_desc_t& subfile, QFileExt &file)
 
     // read map boundaries from header
     qint32 i32;
-    i32 = gar_ptr_load(int24_t, pTreHdr->northbound);
+    i32 = gar_ptr_load(int24_t, &pTreHdr->northbound);
     subfile.north = GARMIN_RAD(i32);
-    i32 = gar_ptr_load(int24_t, pTreHdr->eastbound);
+    i32 = gar_ptr_load(int24_t, &pTreHdr->eastbound);
     subfile.east = GARMIN_RAD(i32);
-    i32 = gar_ptr_load(int24_t, pTreHdr->southbound);
+    i32 = gar_ptr_load(int24_t, &pTreHdr->southbound);
     subfile.south = GARMIN_RAD(i32);
-    i32 = gar_ptr_load(int24_t, pTreHdr->westbound);
+    i32 = gar_ptr_load(int24_t, &pTreHdr->westbound);
     subfile.west = GARMIN_RAD(i32);
 
     if(subfile.east == subfile.west)
@@ -326,8 +382,8 @@ void CGarminTile::readSubfileBasics(subfile_desc_t& subfile, QFileExt &file)
     subfile.area = QRectF(QPointF(subfile.west, subfile.north), QPointF(subfile.east, subfile.south));
 
 #ifdef DEBUG_SHOW_TRE_DATA
-    qDebug() << "bounding area (rad)" << subfile.north << subfile.east << subfile.south << subfile.west;
-    qDebug() << "bounding area (\260)" << subfile.area;
+    qDebug() << "bounding area (\260)" << (subfile.north*RAD_TO_DEG) << (subfile.east*RAD_TO_DEG) << (subfile.south*RAD_TO_DEG) << (subfile.west*RAD_TO_DEG);
+    qDebug() << "bounding area (rad)" << subfile.area;
 #endif                       // DEBUG_SHOW_TRE_DATA
 
     QByteArray maplevel;
@@ -411,7 +467,7 @@ void CGarminTile::readSubfileBasics(subfile_desc_t& subfile, QFileExt &file)
         subdiv->n = i;
         subdiv->next         = gar_load(uint16_t, pSubDivN->next);
         subdiv->terminate    = TRE_SUBDIV_TERM(pSubDivN);
-        subdiv->rgn_start    = gar_ptr_load(uint24_t, pSubDivN->rgn_offset);
+        subdiv->rgn_start    = gar_ptr_load(uint24_t, &pSubDivN->rgn_offset);
         subdiv->rgn_start   += rgnoff;
         // skip if this is the first entry
         if(subdiv_prev != subdivs.end())
@@ -434,9 +490,9 @@ void CGarminTile::readSubfileBasics(subfile_desc_t& subfile, QFileExt &file)
         subdiv->level = TRE_MAP_LEVEL(pMapLevel);
         subdiv->shift = 24 - pMapLevel->bits;
 
-        cx = gar_ptr_load(uint24_t, pSubDivN->center_lng);
+        cx = gar_ptr_load(uint24_t, &pSubDivN->center_lng);
         subdiv->iCenterLng = cx;
-        cy = gar_ptr_load(uint24_t, pSubDivN->center_lat);
+        cy = gar_ptr_load(uint24_t, &pSubDivN->center_lat);
         subdiv->iCenterLat = cy;
         width   = TRE_SUBDIV_WIDTH(pSubDivN) << subdiv->shift;
         height  = gar_load(uint16_t, pSubDivN->height) << subdiv->shift;
@@ -471,7 +527,7 @@ void CGarminTile::readSubfileBasics(subfile_desc_t& subfile, QFileExt &file)
         subdiv->n = i;
         subdiv->next         = 0;
         subdiv->terminate    = TRE_SUBDIV_TERM(pSubDivL);
-        subdiv->rgn_start    = gar_ptr_load(uint24_t, pSubDivL->rgn_offset);
+        subdiv->rgn_start    = gar_ptr_load(uint24_t, &pSubDivL->rgn_offset);
         subdiv->rgn_start   += rgnoff;
         subdiv_prev->rgn_end = subdiv->rgn_start;
         subdiv->hasPoints    = pSubDivL->elements & 0x10;
@@ -482,9 +538,9 @@ void CGarminTile::readSubfileBasics(subfile_desc_t& subfile, QFileExt &file)
         subdiv->level = TRE_MAP_LEVEL(pMapLevel);
         subdiv->shift = 24 - pMapLevel->bits;
 
-        cx = gar_ptr_load(uint24_t, pSubDivL->center_lng);
+        cx = gar_ptr_load(uint24_t, &pSubDivL->center_lng);
         subdiv->iCenterLng = cx;
-        cy = gar_ptr_load(uint24_t, pSubDivL->center_lat);
+        cy = gar_ptr_load(uint24_t, &pSubDivL->center_lat);
         subdiv->iCenterLat = cy;
         width   = TRE_SUBDIV_WIDTH(pSubDivL) << subdiv->shift;
         height  = gar_load(uint16_t, pSubDivL->height) << subdiv->shift;
@@ -506,11 +562,9 @@ void CGarminTile::readSubfileBasics(subfile_desc_t& subfile, QFileExt &file)
         subdiv_prev = subdiv;
         ++pSubDivL; ++subdiv;
     }
-    subdivs.last().rgn_end = gar_load(uint32_t, pRgnHdr->hdr_rgn_t::length);
+    subdivs.last().rgn_end = gar_load(uint32_t, pRgnHdr->hdr_rgn_t::offset) + gar_load(uint32_t, pRgnHdr->hdr_rgn_t::length);
 
     // read extended NT elements
-
-    //     qDebug() << "yyy" << gar_load(uint32_t, pTreHdr->tre7_rec_size);
     if((gar_load(uint16_t, pTreHdr->hdr_subfile_part_t::length) >= 0x9A) && pTreHdr->tre7_size && (gar_load(uint32_t, pTreHdr->tre7_rec_size) >= sizeof(tre_subdiv2_t)))
     {
 
@@ -745,11 +799,21 @@ static inline bool isCompletlyOutside(const QVector<double> &u, const QVector<do
 
     QRectF ref(west, north,  east - west, south - north);
 
+    if(ref.width() == 0)
+    {
+        ref.setWidth(0.00001);
+    }
+    if(ref.height() == 0)
+    {
+        ref.setHeight(0.00001);
+    }
+
     if(viewport.intersects(ref))
     {
         return false;
     }
 
+
     return true;
 }
 
@@ -890,7 +954,6 @@ void CGarminTile::loadSubDiv(QFileExt &file, const subdiv_desc_t& subdiv, IGarmi
         pEnd  = pRawData + (opgon ? opgon : subdiv.rgn_end);
         while(pData < pEnd)
         {
-//            CGarminPolygon p;
             pData += p.decode(subdiv.iCenterLng, subdiv.iCenterLat, subdiv.shift, true, pData, pEnd);
 
             // skip points outside our current viewport
@@ -900,11 +963,11 @@ void CGarminTile::loadSubDiv(QFileExt &file, const subdiv_desc_t& subdiv, IGarmi
             }
 
 
-            if(strtbl && !p.lbl_in_NET && p.lbl_info && !fast)
+            if(strtbl && !p.lbl_in_NET && p.lbl_info)
             {
                 strtbl->get(file, p.lbl_info,IGarminStrTbl::norm, p.labels);
             }
-            else if(strtbl && p.lbl_in_NET && p.lbl_info && !fast)
+            else if(strtbl && p.lbl_in_NET && p.lbl_info)
             {
                 strtbl->get(file, p.lbl_info,IGarminStrTbl::net, p.labels);
             }
@@ -922,7 +985,6 @@ void CGarminTile::loadSubDiv(QFileExt &file, const subdiv_desc_t& subdiv, IGarmi
 
         while(pData < pEnd)
         {
-//            CGarminPolygon p;
             pData += p.decode(subdiv.iCenterLng, subdiv.iCenterLat, subdiv.shift, false, pData, pEnd);
 
             // skip points outside our current viewport
@@ -931,11 +993,11 @@ void CGarminTile::loadSubDiv(QFileExt &file, const subdiv_desc_t& subdiv, IGarmi
                 continue;
             }
 
-            if(strtbl && !p.lbl_in_NET && p.lbl_info)
+            if(strtbl && !p.lbl_in_NET && p.lbl_info && !fast)
             {
                 strtbl->get(file, p.lbl_info,IGarminStrTbl::norm, p.labels);
             }
-            else if(strtbl && p.lbl_in_NET && p.lbl_info)
+            else if(strtbl && p.lbl_in_NET && p.lbl_info && !fast)
             {
                 strtbl->get(file, p.lbl_info,IGarminStrTbl::net, p.labels);
             }
@@ -961,7 +1023,6 @@ void CGarminTile::loadSubDiv(QFileExt &file, const subdiv_desc_t& subdiv, IGarmi
         pEnd    = pData + subdiv.lengthPolygons2;
         while(pData < pEnd)
         {
-//            CGarminPolygon p;
             //             qDebug() << "rgn offset:" << hex << (rgnoff + (pData - pRawData));
             pData += p.decode2(subdiv.iCenterLng, subdiv.iCenterLat, subdiv.shift, false, pData, pEnd);
 
@@ -971,11 +1032,14 @@ void CGarminTile::loadSubDiv(QFileExt &file, const subdiv_desc_t& subdiv, IGarmi
                 continue;
             }
 
-            if(strtbl && !p.lbl_in_NET && p.lbl_info)
+            if(strtbl && !p.lbl_in_NET && p.lbl_info && !fast)
             {
                 strtbl->get(file, p.lbl_info,IGarminStrTbl::norm, p.labels);
             }
+
             polygons.push_back(p);
+
+
         }
     }
 
@@ -985,19 +1049,21 @@ void CGarminTile::loadSubDiv(QFileExt &file, const subdiv_desc_t& subdiv, IGarmi
         pEnd    = pData + subdiv.lengthPolylines2;
         while(pData < pEnd)
         {
-//            CGarminPolygon p;
             //             qDebug() << "rgn offset:" << hex << (rgnoff + (pData - pRawData));
             pData += p.decode2(subdiv.iCenterLng, subdiv.iCenterLat, subdiv.shift, true, pData, pEnd);
 
             // skip points outside our current viewport
             if(isCompletlyOutside(p.u, p.v, viewport))
+            {
                 continue;
+            }
 
-            polylines.push_back(p);
             if(strtbl && !p.lbl_in_NET && p.lbl_info)
             {
                 strtbl->get(file, p.lbl_info,IGarminStrTbl::norm, p.labels);
             }
+
+            polylines.push_back(p);
         }
     }
 
@@ -1013,14 +1079,16 @@ void CGarminTile::loadSubDiv(QFileExt &file, const subdiv_desc_t& subdiv, IGarmi
 
             // skip points outside our current viewport
             if(!viewport.contains(p.lon, p.lat))
+            {
                 continue;
+            }
 
-            pois.push_back(p);
             if(strtbl)
             {
                 p.isLbl6 ? strtbl->get(file, p.lbl_ptr, IGarminStrTbl::poi, p.labels)
                     : strtbl->get(file, p.lbl_ptr, IGarminStrTbl::norm, p.labels);
             }
+            pois.push_back(p);
         }
     }
 
