@@ -47,14 +47,14 @@ class CLiveLogDB : public IDB
 
         void draw(QPainter& p, const QRect& rect, bool& needsRedraw);
 
-        void loadGPX(CGpx& /*gpx*/){};
-        void saveGPX(CGpx& /*gpx*/, const QStringList& ){};
+        void loadGPX(CGpx& /*gpx*/){}
+        void saveGPX(CGpx& /*gpx*/, const QStringList& ){}
 
-        void loadQLB(CQlb& /*qlb*/){};
-        void saveQLB(CQlb& /*qlb*/){};
+        void loadQLB(CQlb& /*qlb*/, bool /*newKey*/){}
+        void saveQLB(CQlb& /*qlb*/){}
 
-        void upload(const QStringList&){};
-        void download(){};
+        void upload(const QStringList&){}
+        void download(){}
 
         void clear();
 
@@ -66,6 +66,8 @@ class CLiveLogDB : public IDB
 
         void addWpt();
 
+        bool contains(const QString& key){return false;}
+
     private slots:
         void slotLiveLog(const CLiveLog& log);
         void slotMapChanged();
