@@ -33,7 +33,6 @@
 #include "CGpx.h"
 #include "tcxreader.h"
 #include "CTabWidget.h"
-#include "printpreview.h"
 #include "CLiveLogDB.h"
 #include "COverlayDB.h"
 #include "CActions.h"
@@ -45,23 +44,37 @@
 #include "CAppOpts.h"
 #include "CMap3D.h"
 #include "CDlgExport.h"
+#ifdef HAS_GEODB
+#include "CGeoDB.h"
+#endif
+#ifdef HAS_DBUS
+#include "CDBus.h"
+#endif
 
 #include <QtGui>
 #ifdef WIN32
 #include <io.h>
 #endif
 
+#include "config.h"
+
 CMainWindow * theMainWindow = 0;
 
 CMainWindow::CMainWindow()
-: modified(false)
+#ifdef HAS_GEODB
+    : geodb(0)
+    , modified(false)
+#else
+    : modified(false)
+#endif
+
 {
     theMainWindow = this;
     groupProvidedMenu = 0;
     setupMenu = 0;
     setObjectName("MainWidget");
     setWindowTitle("QLandkarte GT");
-    setWindowIcon(QIcon(":/icons/iconGlobe16x16.png"));
+//    setWindowIcon(QIcon(":/icons/iconGlobe16x16.png"));
     setAcceptDrops(true);
 
     initWptIcons();
@@ -193,8 +206,11 @@ CMainWindow::CMainWindow()
     actionGroupProvider->addAction(CMenus::MainMoreMenu, "aMoveArea");
     actionGroupProvider->addAction(CMenus::MainMoreMenu, "aZoomArea");
     actionGroupProvider->addAction(CMenus::MainMoreMenu, "aCenterMap");
-    actionGroupProvider->addAction(CMenus::MainMoreMenu, "aDiary");
-    //    actionGroupProvider->addAction(CMenus::MainMoreMenu, "aWorldBasemap");
+//    actionGroupProvider->addAction(CMenus::MainMoreMenu, "aDiary");
+#ifdef HAS_DBUS
+    actionGroupProvider->addAction(CMenus::MainMoreMenu, "aOcm");
+#endif
+
 
     actionGroupProvider->addAction(CMenus::RouteMenu, "aSwitchToMain");
     actionGroupProvider->addAction(CMenus::RouteMenu, "aMoveArea");
@@ -247,10 +263,17 @@ CMainWindow::CMainWindow()
     wptdb       = new CWptDB(tabbar, this);
     trackdb     = new CTrackDB(tabbar, this);
     routedb     = new CRouteDB(tabbar, this);
+    overlaydb   = new COverlayDB(tabbar, this);
+    livelogdb   = new CLiveLogDB(tabbar, this);
+
     diarydb     = new CDiaryDB(canvasTab, this);
     searchdb    = new CSearchDB(tabbar, this);
-    livelogdb   = new CLiveLogDB(tabbar, this);
-    overlaydb   = new COverlayDB(tabbar, this);
+#ifdef HAS_GEODB
+    if(resources->useGeoDB())
+    {
+        geodb       = new CGeoDB(tabbar, this);
+    }
+#endif
 
     connect(searchdb, SIGNAL(sigChanged()), canvas, SLOT(update()));
     connect(wptdb, SIGNAL(sigChanged()), canvas, SLOT(update()));
@@ -268,7 +291,19 @@ CMainWindow::CMainWindow()
     connect(overlaydb, SIGNAL(sigModified()), this, SLOT(slotModified()));
     connect(routedb, SIGNAL(sigModified()), this, SLOT(slotModified()));
 
+
+#ifdef HAS_GEODB
+    if(geodb)
+    {
+        geodb->gainFocus();
+    }
+    else
+    {
+        searchdb->gainFocus();
+    }
+#else
     searchdb->gainFocus();
+#endif
 
     // restore last session position and size of mainWidget
     {
@@ -281,17 +316,23 @@ CMainWindow::CMainWindow()
             else
                 showMaximized();
         }
+        else
+        {
+            setGeometry(0,0,800,600);
+        }
     }
 
     // restore last session settings
     QList<int> sizes = mainSplitter->sizes();
-    sizes[0] = (int)(mainSplitter->width() * 0.1);
-    sizes[1] = (int)(mainSplitter->width() * 0.9);
+    sizes[0] = 200;
+    sizes[1] = 600;
+
     mainSplitter->setSizes(sizes);
     sizes = leftSplitter->sizes();
-    sizes[0] = (int)(mainSplitter->height() * 0.3);
-    sizes[1] = (int)(mainSplitter->height() * 0.3);
-    sizes[2] = (int)(mainSplitter->height() * 0.4);
+    sizes[0] = 200;
+    sizes[1] = 200;
+    sizes[2] = 200;
+
     leftSplitter->setSizes(sizes);
 
     if( cfg.contains("mainWidget/mainSplitter") )
@@ -329,11 +370,22 @@ CMainWindow::CMainWindow()
 
     mostRecent = cfg.value("geodata/mostRecent",QStringList()).toStringList();
 
-    foreach(QString arg, qlOpts->arguments)
+    if(!qlOpts->arguments.isEmpty())
     {
-        loadData(arg, QString());
-    }
+        CSearchDB::self().clear();
+        CMapDB::self().clear();
+        CWptDB::self().clear();
+        CTrackDB::self().clear();
+        CDiaryDB::self().clear();
+        COverlayDB::self().clear();
+        CRouteDB::self().clear();
+        clear();
 
+        foreach(QString arg, qlOpts->arguments)
+        {
+            loadData(arg, QString());
+        }
+    }
     modified = false;
     setTitleBar();
 
@@ -342,6 +394,12 @@ CMainWindow::CMainWindow()
 
     megaMenu->slotSplitterMoved(leftSplitter->sizes()[0], 1);
 
+#ifdef HAS_DBUS
+    dbus = new CDBus(qApp);
+#endif
+
+    connect(&CTrackDB::self(), SIGNAL(sigHighlightTrack(CTrack *)), canvas, SLOT(slotHighlightTrack(CTrack*)));
+    connect(&CTrackDB::self(), SIGNAL(sigChanged()), canvas, SLOT(slotTrackChanged()));
 }
 
 
@@ -370,6 +428,7 @@ void CMainWindow::slotReloadArgs()
     {
         loadData(arg, QString());
     }
+
 }
 
 
@@ -391,8 +450,9 @@ void CMainWindow::dragEnterEvent(QDragEnterEvent *event)
     {
         QList<QUrl> urls = event->mimeData()->urls();
         QFileInfo fi(urls[0].path());
+        QString ext = fi.suffix().toUpper();
 
-        if(fi.suffix() == "gpx")
+        if ( (ext == "QLB") || (ext == "GPX") || (ext == "TCX") )
         {
             event->acceptProposedAction();
         }
@@ -499,14 +559,15 @@ void CMainWindow::setupMenuBar()
     menu->addAction(QIcon(":/icons/iconFileLoad16x16.png"),tr("Load Geo Data"),this,SLOT(slotLoadData()), Qt::CTRL + Qt::Key_L);
     menu->addAction(QIcon(":/icons/iconFileSave16x16.png"),tr("Save Geo Data"),this,SLOT(slotSaveData()), Qt::CTRL + Qt::Key_S);
     menu->addAction(QIcon(":/icons/iconFileExport16x16.png"),tr("Export Geo Data"),this,SLOT(slotExportData()), Qt::CTRL + Qt::Key_X);
-    menu->addAction(QIcon(":/icons/iconFileAdd16x16.png"),tr("Add Geo Data"),this,SLOT(slotAddData()));
+    menu->addAction(QIcon(":/icons/iconFileAdd16x16.png"),tr("Add Geo Data"),this,SLOT(slotAddData()), Qt::ALT + Qt::Key_A);
     menu->addMenu(menuMostRecent);
     menu->addSeparator();
     menu->addAction(QIcon(":/icons/iconScreenshot16x16.png"),tr("Device Screenshot ..."),this,SLOT(slotScreenshot()));
-    menu->addAction(QIcon(":/icons/iconRaster16x16.png"),tr("Save as image ..."),this,SLOT(slotSaveImage()));
+    menu->addAction(QIcon(":/icons/iconRaster16x16.png"),tr("Save map as image ..."),this,SLOT(slotSaveImage()));
     menu->addAction(QIcon(":/icons/iconPrint16x16.png"),tr("Print Map ..."),this,SLOT(slotPrint()), Qt::CTRL + Qt::Key_P);
-    menu->addAction(QIcon(":/icons/iconPrint16x16.png"),tr("Print Diary ..."),this,SLOT(slotPrintPreview()));
+    //menu->addAction(QIcon(":/icons/iconPrint16x16.png"),tr("Print Diary ..."),this,SLOT(slotPrintPreview()));
     menu->addSeparator();
+    menu->addAction(QIcon(":/icons/iconUnknown16x16.png"),tr("Toggle toolview"),this,SLOT(slotToggleToolView()), Qt::CTRL + Qt::Key_T);
     menu->addAction(QIcon(":/icons/iconExit16x16.png"),tr_nomac("Exit"),this,SLOT(close()));
     menuBar()->addMenu(menu);
 
@@ -561,6 +622,10 @@ void CMainWindow::setupMenuBar()
 
     menu = new QMenu(this);
     menu->setTitle(tr_nomac("&Help"));
+    menu->addAction(QIcon(":/icons/iconHelp16x16.png"),tr_nomac("http://FAQ"),this,SLOT(slotFAQ()));
+    menu->addAction(QIcon(":/icons/iconHelp16x16.png"),tr_nomac("http://Help"),this,SLOT(slotHelp()));
+    menu->addAction(QIcon(":/icons/iconHelp16x16.png"),tr_nomac("http://Support"),this,SLOT(slotSupport()));
+    menu->addSeparator();
     menu->addAction(QIcon(":/icons/iconGlobe16x16.png"),tr_nomac("About &QLandkarte GT"),this,SLOT(slotCopyright()));
     menuBar()->addMenu(menu);
 }
@@ -574,6 +639,23 @@ void CMainWindow::closeEvent(QCloseEvent * e)
         return;
     }
 
+#ifdef HAS_GEODB
+    if(!(CResources::self().useGeoDB() && CResources::self().saveGeoDBOnExit()))
+    {
+        if (maybeSave())
+        {
+            e->accept();
+        }
+        else
+        {
+            e->ignore();
+        }
+    }
+    else
+    {
+        e->accept();
+    }
+#else
     if (maybeSave())
     {
         e->accept();
@@ -582,6 +664,7 @@ void CMainWindow::closeEvent(QCloseEvent * e)
     {
         e->ignore();
     }
+#endif
 }
 
 
@@ -595,10 +678,10 @@ void CMainWindow::slotLoadMapSet()
     #ifdef WMS_CLIENT
         ,"All (*.*);;Map Collection (*.qmap);;Garmin (*.tdb);;WMS (*.xml)"
     #else
-        ,"All (*.*);;Map Collection (*.qmap);;Garmin (*.tdb)"
+        ,"All (*.*);;Map Collection (*.qmap);;Garmin (*.tdb);;BirdsEye (*.jnx)"
     #endif
         , &filter
-        , QFileDialog::DontUseNativeDialog
+        , FILE_DIALOG_FLAGS
         );
     if(filename.isEmpty()) return;
 
@@ -629,24 +712,9 @@ void CMainWindow::slotConfig()
     dlg.exec();
 }
 
-
 void CMainWindow::slotLoadData()
 {
-
-    QProcess proc1;
-    proc1.start(GPSBABEL " -V");
-    proc1.waitForFinished();
-    bool haveGPSBabel = proc1.exitCode() == 0;
-
-    QString formats;
-    if(haveGPSBabel)
-    {
-        formats = "All supported files (*.qlb *.gpx *.tcx *.loc *.gdb *.kml);;QLandkarte (*.qlb);;GPS Exchange (*.gpx);;TCX TrainingsCenterExchange (*.tcx);;Geocaching.com - EasyGPS (*.loc);;Mapsource (*.gdb);;Google Earth (*.kml)";
-    }
-    else
-    {
-        formats = "All supported files (*.qlb *.gpx *.tcx);;QLandkarte (*.qlb);;GPS Exchange (*.gpx);;TCX TrainingsCenterExchange (*.tcx)";
-    }
+    QString formats = getGeoDataFormats();
 
     QSettings cfg;
     QString filter   = cfg.value("geodata/filter","").toString();
@@ -654,7 +722,7 @@ void CMainWindow::slotLoadData()
         ,pathData
         ,formats
         ,&filter
-        , QFileDialog::DontUseNativeDialog
+        , FILE_DIALOG_FLAGS
         );
 
     if(filenames.isEmpty()) return;
@@ -692,20 +760,7 @@ void CMainWindow::slotLoadData()
 
 void CMainWindow::slotAddData()
 {
-    QProcess proc1;
-    proc1.start(GPSBABEL " -V");
-    proc1.waitForFinished();
-    bool haveGPSBabel = proc1.exitCode() == 0;
-
-    QString formats;
-    if(haveGPSBabel)
-    {
-        formats = "All supported files (*.qlb *.gpx *.tcx *.loc *.gdb *.kml);;QLandkarte (*.qlb);;GPS Exchange (*.gpx);;TCX TrainingsCenterExchange (*.tcx);;Geocaching.com - EasyGPS (*.loc);;Mapsource (*.gdb);;Google Earth (*.kml)";
-    }
-    else
-    {
-        formats = "All supported files (*.qlb *.gpx *.tcx);;QLandkarte (*.qlb);;GPS Exchange (*.gpx);;TCX TrainingsCenterExchange (*.tcx)";
-    }
+    QString formats = getGeoDataFormats();
 
     QSettings cfg;
     int i;
@@ -715,7 +770,7 @@ void CMainWindow::slotAddData()
         ,pathData
         ,formats
         ,&filter
-        , QFileDialog::DontUseNativeDialog
+        , FILE_DIALOG_FLAGS
         );
 
     for (i = 0; i < filenames.size(); ++i)
@@ -738,7 +793,7 @@ void CMainWindow::slotAddData()
 }
 
 
-void CMainWindow::loadData(QString& filename, const QString& filter)
+void CMainWindow::loadData(const QString& filename, const QString& filter)
 {
     QTemporaryFile tmpfile;
     bool loadGPXData = false;
@@ -753,16 +808,16 @@ void CMainWindow::loadData(QString& filename, const QString& filter)
         {
             CQlb qlb(this);
             qlb.load(filename);
-            CMapDB::self().loadQLB(qlb);
-            CWptDB::self().loadQLB(qlb);
-            CTrackDB::self().loadQLB(qlb);
-            CRouteDB::self().loadQLB(qlb);
-            CDiaryDB::self().loadQLB(qlb);
-            COverlayDB::self().loadQLB(qlb);
+            CMapDB::self().loadQLB(qlb, false);
+            CWptDB::self().loadQLB(qlb, false);
+            CTrackDB::self().loadQLB(qlb, false);
+            CRouteDB::self().loadQLB(qlb, false);
+            CDiaryDB::self().loadQLB(qlb, false);
+            COverlayDB::self().loadQLB(qlb, false);
         }
         else if(ext == "GPX")
         {
-            CGpx gpx(this);
+            CGpx gpx(this, CGpx::eQlgtExport);
             gpx.load(filename);
             CMapDB::self().loadGPX(gpx);
             CWptDB::self().loadGPX(gpx);
@@ -788,65 +843,50 @@ void CMainWindow::loadData(QString& filename, const QString& filter)
                 }
             }
         }
-        else if(ext == "LOC")
+        else
         {
+
             tmpfile.open();
-            loadGPXData = convertData("geo", filename, "gpx", tmpfile.fileName());
+            loadGPXData = false;
+
+            if(ext == "LOC")
+            {
+                loadGPXData = convertData("geo", filename, "gpx", tmpfile.fileName());
+            }
+            else if(ext == "GDB")
+            {
+
+                loadGPXData = convertData("gdb", filename, "gpx", tmpfile.fileName());
+            }
+            else if(ext == "KML")
+            {
+                loadGPXData = convertData("kml", filename, "gpx", tmpfile.fileName());
+            }
+            else if(ext == "PLT" || ext == "WPT" || ext == "RTE")
+            {
+                loadGPXData = convertData("ozi", filename, "gpx", tmpfile.fileName());
+            }
+            else if(ext == "TK1")
+            {
+                loadGPXData = convertData("wbt-tk1", filename, "gpx", tmpfile.fileName());
+            }
+
+
             if (!loadGPXData)
             {
                 QMessageBox::critical(0,tr("Convert error"),"Error in data conversion?",QMessageBox::Ok,QMessageBox::NoButton);
             }
-            else
-            {
-                CGpx gpx(this);
-                gpx.load(tmpfile.fileName());
-                CMapDB::self().loadGPX(gpx);
-                CWptDB::self().loadGPX(gpx);
-                CTrackDB::self().loadGPX(gpx);
-                CRouteDB::self().loadGPX(gpx);
-                CDiaryDB::self().loadGPX(gpx);
-                COverlayDB::self().loadGPX(gpx);
-            }
-        }
-        else if(ext == "GDB")
-        {
-            tmpfile.open();
-            loadGPXData = convertData("gdb", filename, "gpx", tmpfile.fileName());
-            if (!loadGPXData)
-            {
-                QMessageBox::critical(0,tr("Convert error"),"Error in data conversion?",QMessageBox::Ok,QMessageBox::NoButton);
-            }
-            else
-            {
-                CGpx gpx(this);
-                gpx.load(tmpfile.fileName());
-                CMapDB::self().loadGPX(gpx);
-                CWptDB::self().loadGPX(gpx);
-                CTrackDB::self().loadGPX(gpx);
-                CRouteDB::self().loadGPX(gpx);
-                CDiaryDB::self().loadGPX(gpx);
-                COverlayDB::self().loadGPX(gpx);
-            }
-        }
-        else if(ext == "KML")
-        {
-            tmpfile.open();
-            loadGPXData = convertData("kml", filename, "gpx", tmpfile.fileName());
-            if (!loadGPXData)
-            {
-                QMessageBox::critical(0,tr("Convert error"),"Error in data conversion?",QMessageBox::Ok,QMessageBox::NoButton);
-            }
-            else
-            {
-                CGpx gpx(this);
-                gpx.load(tmpfile.fileName());
-                CMapDB::self().loadGPX(gpx);
-                CWptDB::self().loadGPX(gpx);
-                CTrackDB::self().loadGPX(gpx);
-                CRouteDB::self().loadGPX(gpx);
-                CDiaryDB::self().loadGPX(gpx);
-                COverlayDB::self().loadGPX(gpx);
-            }
+
+            CGpx gpx(this, CGpx::eQlgtExport);
+            gpx.load(tmpfile.fileName());
+            CMapDB::self().loadGPX(gpx);
+            CWptDB::self().loadGPX(gpx);
+            CTrackDB::self().loadGPX(gpx);
+            CRouteDB::self().loadGPX(gpx);
+            CDiaryDB::self().loadGPX(gpx);
+            COverlayDB::self().loadGPX(gpx);
+
+
         }
         wksFile = filename;
     }
@@ -862,7 +902,7 @@ bool CMainWindow::convertData(const QString& inFormat, const QString& inFile, co
 {
     QString program = GPSBABEL;
     QStringList arguments;
-    arguments << "-i" << inFormat << "-f" << inFile << "-o" << outFormat << "-F" << outFile;
+    arguments << "-t" << "-w" << "-r" << "-i" << inFormat << "-f" << inFile << "-o" << outFormat << "-F" << outFile;
 
     QProcess *babelProcess = new QProcess(this);
     babelProcess->start(program, arguments);
@@ -872,7 +912,7 @@ bool CMainWindow::convertData(const QString& inFormat, const QString& inFile, co
     if (!babelProcess->waitForFinished())
         return false;
 
-    return babelProcess->exitCode() ==0;
+    return babelProcess->exitCode() == 0;
 }
 
 
@@ -916,7 +956,7 @@ void CMainWindow::slotSaveData()
         ,pathData
         ,"QLandkarte (*.qlb);;GPS Exchange (*.gpx)"
         ,&filter
-        , QFileDialog::DontUseNativeDialog
+        , FILE_DIALOG_FLAGS
         );
 
     if(filename.isEmpty()) return;
@@ -929,53 +969,95 @@ void CMainWindow::slotSaveData()
 
 void CMainWindow::slotExportData()
 {
+    QSettings cfg;
+
+    bool haveGPSBabel = isGPSBabel();
+
+    QString formats;
+    if(haveGPSBabel)
+    {
+        //formats = "All supported files (*.qlb *.gpx *.tcx *.loc *.gdb *.kml *.plt *.rte *.wpt);;QLandkarte (*.qlb);;GPS Exchange (*.gpx);;TCX TrainingsCenterExchange (*.tcx);;Geocaching.com - EasyGPS (*.loc);;Mapsource (*.gdb);;Google Earth (*.kml);;Ozi Track (*.plt);;Ozi Route (*.rte);;Ozi Waypoint (*.wpt)";
+        formats = "All supported files (*.gpx *.plt *.rte *.wpt);;GPS Exchange (*.gpx);;OziExplorer (*.plt *.rte *.wpt)";
+    }
+    else
+    {
+        formats = "All supported files (*.gpx);;GPS Exchange (*.gpx)";
+    }
+
+    QString filter = cfg.value("geodata/filter","").toString();
     QString filename = QFileDialog::getSaveFileName( 0, tr("Select output file")
         ,pathData
-        ,"GPS Exchange (*.gpx)"
-        ,0
-        , QFileDialog::DontUseNativeDialog
+        ,formats
+        ,&filter
+        , FILE_DIALOG_FLAGS
         );
 
     if(filename.isEmpty()) return;
 
-    saveData(filename, "GPS Exchange (*.gpx)", true);
+    cfg.setValue("geodata/filter",filter);
+
+    saveData(filename, filter, true);
     addRecent(filename);
 }
 
 
 void CMainWindow::saveData(QString& fn, const QString& filter, bool exportFlag)
 {
+    QTemporaryFile tmpfile;
+    tmpfile.open();
     QString filename = fn;
-    QString ext = filename.right(4);
+    QFileInfo fileInfo(filename);
+    QString ext = fileInfo.suffix().toUpper();
 
-    if(exportFlag || filter == "GPS Exchange (*.gpx)")
+    if(!exportFlag)
     {
-        if(ext != ".gpx") filename += ".gpx";
-        ext = "GPX";
-    }
-    else if(filter == "QLandkarte (*.qlb)")
-    {
-        if(ext != ".qlb") filename += ".qlb";
-        ext = "QLB";
-    }
-    else
-    {
-        if (ext == ".gpx")
+        if ((filter == "GPS Exchange (*.gpx)") || (ext == "GPX"))
         {
-            ext = "GPX";
-        }
-        else if (ext == ".qlb")
-        {
-            ext = "QLB";
+            if (ext!="GPX")
+            {
+                filename += ".gpx";
+                ext = "GPX";
+            }
         }
         else
         {
-            filename += ".qlb";
+            if(ext != "QLB")
+            {
+                filename += ".qlb";
+            }
+        ext = "QLB";
+        }
+    }
+    else
+    {
+        if ((ext == "GPX") || (filter == "GPS Exchange (*.gpx)"))
+        {
+            if(ext != "GPX")
+            {
+                filename += ".gpx";
+            }
+            //ext = "GPX";
+        }
+        else if ((ext == "PLT") || (ext == "RTE") || (ext == "WPT") || (filter == "OziExplorer (*.plt *.rte *.wpt)"))
+        {
+            if ((ext == "PLT") || (ext == "RTE") || (ext == "WPT"))
+            {
+                filename = filename.left(filename.length()-4);
+            }
+            ext = "OZI";
+        }
+        else
+        {
+            if(ext != "QLB")
+            {
+                filename += ".qlb";
+            }
             ext = "QLB";
         }
     }
 
-    pathData = QFileInfo(filename).absolutePath();
+    fileInfo.setFile(filename);
+    pathData = fileInfo.absolutePath();
 
     try
     {
@@ -990,7 +1072,7 @@ void CMainWindow::saveData(QString& fn, const QString& filter, bool exportFlag)
             COverlayDB::self().saveQLB(qlb);
             qlb.save(filename);
         }
-        else if(ext == "GPX")
+        if(ext == "GPX" || ext == "OZI")
         {
             QStringList keysWpt, keysTrk, keysRte;
 
@@ -1004,7 +1086,7 @@ void CMainWindow::saveData(QString& fn, const QString& filter, bool exportFlag)
                 }
             }
 
-            CGpx gpx(this, exportFlag);
+            CGpx gpx(this, exportFlag ? CGpx::eCleanExport : CGpx::eQlgtExport);
             CMapDB::self().saveGPX(gpx, QStringList());
             CWptDB::self().saveGPX(gpx, keysWpt);
             CTrackDB::self().saveGPX(gpx, keysTrk);
@@ -1012,7 +1094,18 @@ void CMainWindow::saveData(QString& fn, const QString& filter, bool exportFlag)
             gpx.makeExtensions();
             CDiaryDB::self().saveGPX(gpx, QStringList());
             COverlayDB::self().saveGPX(gpx, QStringList());
-            gpx.save(filename);
+            if (ext == "OZI")
+            {
+                gpx.save(tmpfile.fileName());
+            }
+            else
+            {
+                gpx.save(filename);
+            }
+        }
+        if (ext == "OZI" )
+        {
+            convertData("gpx", tmpfile.fileName(),"ozi",filename);
         }
 
         wksFile  = filename;
@@ -1031,6 +1124,64 @@ void CMainWindow::saveData(QString& fn, const QString& filter, bool exportFlag)
 }
 
 
+void CMainWindow::exportToOcm()
+{
+#ifdef HAS_DBUS
+    int cnt = 0;
+    QProcess ocm;
+    QDBusMessage msg;
+    QStringList keysWpt, keysTrk, keysRte;
+
+    CDlgExport dlg(0, &keysWpt, &keysTrk, &keysRte);
+
+    if( dlg.exec() == QDialog::Rejected)
+    {
+        return;
+    }
+
+
+    CGpx gpx(this, CGpx::eOcmExport);
+    CWptDB::self().saveGPX(gpx, keysWpt);
+    CTrackDB::self().saveGPX(gpx, keysTrk);
+    CRouteDB::self().saveGPX(gpx, keysRte);
+    gpx.makeExtensions();
+    COverlayDB::self().saveGPX(gpx, QStringList());
+
+
+    QDBusConnection dbus = QDBusConnection::sessionBus();
+    QStringList serviceNames = dbus.interface()->registeredServiceNames();
+    while(!serviceNames.contains("org.ocm.dbus"))
+    {
+        if(cnt > 2)
+        {
+            QMessageBox::warning(0,tr("Failed ..."), tr("Failed to start OCM."), QMessageBox::Abort);
+            return;
+        }
+
+//        qDebug() << "start ocm-gtk";
+        ocm.startDetached("ocm-gtk");
+        sleep(3);
+        cnt++;
+    }
+
+    QTemporaryFile file;
+    file.open();
+    //file.close();
+    gpx.save(file.fileName());
+
+    msg = QDBusMessage::createMethodCall("org.ocm.dbus", "/org/ocm/dbus", "org.ocm.dbus", "ShowOCM");
+    msg = dbus.call(msg);
+
+//    qDebug() << msg.errorName()  << msg.errorMessage();
+
+    msg = QDBusMessage::createMethodCall("org.ocm.dbus", "/org/ocm/dbus", "org.ocm.dbus", "ImportGPX");
+    msg << file.fileName();
+    msg = dbus.call(msg);
+
+//    qDebug() << msg.errorName()  << msg.errorMessage();
+#endif
+}
+
 void CMainWindow::slotPrint()
 {
     QPrinter printer;
@@ -1049,16 +1200,26 @@ void CMainWindow::slotPrint()
 void CMainWindow::slotSaveImage()
 {
 
-    QString filter;
+    QSettings cfg;
+    QString pathData = cfg.value("path/data","./").toString();
+    QString filter   = cfg.value("canvas/imagetype","Bitmap (*.png)").toString();
+
     QString filename = QFileDialog::getSaveFileName( 0, tr("Select output file")
         ,pathData
-        ,"Bitmap (*.png *.jpg *.jpeg);;"
+        ,"Bitmap (*.png)"
         ,&filter
-        , QFileDialog::DontUseNativeDialog
+        , FILE_DIALOG_FLAGS
         );
 
     if(filename.isEmpty()) return;
 
+    QFileInfo fi(filename);
+    if(fi.suffix().toLower() != "png")
+    {
+        filename += ".png";
+    }
+
+#ifdef PLOT_3D
     CMap3D * map3d = qobject_cast<CMap3D*>(canvasTab->currentWidget());
 
     if(map3d)
@@ -1066,11 +1227,16 @@ void CMainWindow::slotSaveImage()
         map3d->slotSaveImage(filename);
     }
     else
+#endif
     {
         QImage img(canvas->size(), QImage::Format_ARGB32);
         canvas->print(img);
         img.save(filename);
     }
+    pathData = fi.absolutePath();
+    cfg.setValue("path/data", pathData);
+    cfg.setValue("canvas/imagetype", filter);
+
 }
 
 
@@ -1081,15 +1247,6 @@ void CMainWindow::slotModified()
 }
 
 
-void CMainWindow::slotPrintPreview()
-{
-    QTextEdit textEdit(this);
-    textEdit.insertHtml(CDiaryDB::self().getDiary());
-    PrintPreview *preview = new PrintPreview(textEdit.document(), this);
-    preview->setWindowModality(Qt::WindowModal);
-    preview->setAttribute(Qt::WA_DeleteOnClose);
-    preview->show();
-}
 
 
 void CMainWindow::slotDataChanged()
@@ -1167,15 +1324,15 @@ void CMainWindow::slotDataChanged()
         str += tr("no overlays. ");
     }
 
-    c = CDiaryDB::self().count();
-    if(c > 0)
-    {
-        str += tr("A <a href='Diary'>diary</a> is loaded.");
-    }
-    else
-    {
-        str += tr("The diary (<a href='Diary'>new</a>) is empty.");
-    }
+//    c = CDiaryDB::self().count();
+//    if(c > 0)
+//    {
+//        str += tr("A <a href='Diary'>diary</a> is loaded.");
+//    }
+//    else
+//    {
+//        str += tr("The diary (<a href='Diary'>new</a>) is empty.");
+//    }
 
     str += "</p>";
 
@@ -1188,7 +1345,7 @@ void CMainWindow::slotOpenLink(const QString& link)
 {
     if(link == "Diary")
     {
-        CDiaryDB::self().openEditWidget();
+//        CDiaryDB::self().openEditWidget();
     }
     else if(link == "Clear")
     {
@@ -1216,7 +1373,9 @@ void CMainWindow::slotDeviceChanged()
     comboDevice->addItem(tr("QLandkarte M"), "QLandkarteM");
     comboDevice->addItem(resources->m_devType, "Garmin");
     comboDevice->addItem(tr("NMEA"), "NMEA");
+#ifdef HS_MIKROKOPTER
     comboDevice->addItem(tr("Mikrokopter"), "Mikrokopter");
+#endif
 #ifdef HAS_GPSD
     comboDevice->addItem(tr("GPSD"), "GPSD");
 #endif
@@ -1314,3 +1473,57 @@ void CMainWindow::slotTabCloseRequest(int i)
         w->deleteLater();
     }
 }
+
+void CMainWindow::slotFAQ()
+{
+    QDesktopServices::openUrl(QUrl("http://sourceforge.net/apps/mediawiki/qlandkartegt/index.php?title=FAQ"));
+}
+
+void CMainWindow::slotHelp()
+{
+    QDesktopServices::openUrl(QUrl("http://sourceforge.net/apps/mediawiki/qlandkartegt/index.php?title=Help_for_QLandkarte_GT"));
+}
+
+void CMainWindow::slotSupport()
+{
+    QDesktopServices::openUrl(QUrl("http://www.qlandkarte.org/index.php?option=com_content&view=article&id=17&Itemid=19"));
+}
+
+void CMainWindow::slotToggleToolView()
+{
+    qDebug() << "CMainWindow::slotToggleToolView()";
+    if(leftSplitter->isHidden())
+    {
+        leftSplitter->show();
+    }
+    else
+    {
+        leftSplitter->hide();
+    }
+}
+
+bool CMainWindow::isGPSBabel()
+{
+    bool haveGPSBabel = false;
+    QProcess proc1;
+    proc1.start(GPSBABEL " -V");
+    proc1.waitForFinished();
+    haveGPSBabel = proc1.error() == QProcess::UnknownError;
+    return haveGPSBabel;
+}
+
+QString CMainWindow::getGeoDataFormats() {
+
+    bool haveGPSBabel = isGPSBabel();
+
+    QString formats;
+    if(haveGPSBabel)
+    {
+        formats = "All supported files (*.qlb *.gpx *.tcx *.loc *.gdb *.kml *.plt *.rte *.wpt *.tk1);;QLandkarte (*.qlb);;GPS Exchange (*.gpx);;TCX TrainingsCenterExchange (*.tcx);;Geocaching.com - EasyGPS (*.loc);;Mapsource (*.gdb);;Google Earth (*.kml);;Ozi Track (*.plt);;Ozi Route (*.rte);;Ozi Waypoint (*.wpt);;Wintec WBT201/1000 (*.tk1)";
+    }
+    else
+    {
+        formats = "All supported files (*.qlb *.gpx *.tcx);;QLandkarte (*.qlb);;GPS Exchange (*.gpx);;TCX TrainingsCenterExchange (*.tcx)";
+    }
+    return formats;
+}
