@@ -20,6 +20,7 @@
 #include "CMapGeoTiff.h"
 #include "CMainWindow.h"
 #include "CCanvas.h"
+#include "CResources.h"
 
 #include <gdal_priv.h>
 #include <ogr_spatialref.h>
@@ -38,10 +39,6 @@ CMapGeoTiff::CMapGeoTiff(const QString& fn, CCanvas * parent)
 , yref1(0)
 , xref2(0)
 , yref2(0)
-//, lon1(0)
-//, lat1(0)
-//, lon2(0)
-//, lat2(0)
 , x(0)
 , y(0)
 , zoomFactor(1.0)
@@ -50,7 +47,7 @@ CMapGeoTiff::CMapGeoTiff(const QString& fn, CCanvas * parent)
 {
     filename = fn;
 
-    dataset = (GDALDataset*)GDALOpen(filename.toUtf8(),GA_Update);
+    dataset = (GDALDataset*)GDALOpen(filename.toUtf8(),GA_ReadOnly);
     if(dataset == 0)
     {
         QMessageBox::warning(0, tr("Error..."), tr("Failed to load file: %1").arg(filename));
@@ -71,7 +68,7 @@ CMapGeoTiff::CMapGeoTiff(const QString& fn, CCanvas * parent)
             return;
         }
 
-        qDebug() << pBand->GetColorInterpretation();
+//        qDebug() << pBand->GetColorInterpretation();
 
         if(pBand->GetColorInterpretation() ==  GCI_PaletteIndex )
         {
@@ -110,7 +107,6 @@ CMapGeoTiff::CMapGeoTiff(const QString& fn, CCanvas * parent)
     char str[1024];
     strncpy(str,dataset->GetProjectionRef(),sizeof(str));
     char * ptr = str;
-    OGRSpatialReference oSRS;
     oSRS.importFromWkt(&ptr);
     oSRS.exportToProj4(&ptr);
 
@@ -150,17 +146,10 @@ CMapGeoTiff::CMapGeoTiff(const QString& fn, CCanvas * parent)
     xref2   = xref1 + xsize_px * xscale;
     yref2   = yref1 + ysize_px * yscale;
 
-//    lon1 = xref1;
-//    lat1 = yref1;
-//    pj_transform(pjsrc,pjtar,1,0,&lon1,&lat1,0);
-//
-//    lon2 = xref2;
-//    lat2 = yref2;
-//    pj_transform(pjsrc,pjtar,1,0,&lon2,&lat2,0);
-
     x = xref1 + (xref2 - xref1) / 2;
     y = yref1 - (yref1 - yref2) / 2;
 
+    qDebug() << "xscale" << xscale << "yscale" << yscale;
     qDebug() << xref1 << yref1 << xref2 << yref2;
 
     zoomidx = 1;
@@ -200,41 +189,45 @@ void CMapGeoTiff::draw(QPainter& p)
 
     draw();
 
-    QString str;
-    if(zoomFactor < 1.0)
-    {
-        str = tr("Overzoom x%1").arg(1/zoomFactor,0,'f',0);
-    }
-    else
-    {
-        str = tr("Zoom level x%1").arg(zoomidx);
-    }
 
     p.drawImage(0,0,buffer);
 
     // render overlay
     if(!ovlMap.isNull() && !doFastDraw)
     {
-        qDebug() << size << needsRedraw;
+//        qDebug() << size << needsRedraw;
         ovlMap->draw(size, needsRedraw, p);
     }
 
+    if(CResources::self().showZoomLevel())
+    {
 
-    p.setPen(Qt::white);
-    p.setFont(QFont("Sans Serif",14,QFont::Black));
+        QString str;
+        if(zoomFactor < 1.0)
+        {
+            str = tr("Overzoom x%1").arg(1/zoomFactor,0,'f',0);
+        }
+        else
+        {
+            str = tr("Zoom level x%1").arg(zoomidx);
+        }
 
-    p.drawText(9  ,23, str);
-    p.drawText(10 ,23, str);
-    p.drawText(11 ,23, str);
-    p.drawText(9  ,24, str);
-    p.drawText(11 ,24, str);
-    p.drawText(9  ,25, str);
-    p.drawText(10 ,25, str);
-    p.drawText(11 ,25, str);
 
-    p.setPen(Qt::darkBlue);
-    p.drawText(10,24,str);
+        p.setPen(Qt::white);
+        p.setFont(QFont("Sans Serif",14,QFont::Black));
 
+        p.drawText(9  ,23, str);
+        p.drawText(10 ,23, str);
+        p.drawText(11 ,23, str);
+        p.drawText(9  ,24, str);
+        p.drawText(11 ,24, str);
+        p.drawText(9  ,25, str);
+        p.drawText(10 ,25, str);
+        p.drawText(11 ,25, str);
+
+        p.setPen(Qt::darkBlue);
+        p.drawText(10,24,str);
+    }
 }
 
 
@@ -271,7 +264,7 @@ void CMapGeoTiff::draw()
 
         //         qDebug() << xoff << yoff << pxx << pxy << w << h;
 
-        if(w != 0 && h != 0)
+        if(w > 0 && h > 0)
         {
 
             CPLErr err = CE_Failure;
@@ -304,6 +297,7 @@ void CMapGeoTiff::draw()
                 QVector<quint8> buffer(w*h);
 
                 img.fill(qRgba(255,255,255,255));
+                QRgb testPix = qRgba(GCI_RedBand, GCI_GreenBand, GCI_BlueBand, GCI_AlphaBand);
 
                 for(int b = 1; b <= rasterBandCount; ++b)
                 {
@@ -315,15 +309,23 @@ void CMapGeoTiff::draw()
 
                     if(!err)
                     {
-                        quint8 * pTar   = img.bits() - (pBand->GetColorInterpretation() - 5);
-                        quint8 * pSrc   = buffer.data();
-                        const int size  = buffer.size();
+                        int pbandColour = pBand->GetColorInterpretation();
+                        unsigned int offset;
 
-                        for(int i = 0; i < size; ++i)
+                        for (offset = 0; offset < sizeof(testPix) && *(((quint8 *)&testPix) + offset) != pbandColour; offset++);
+
+                        if(offset < sizeof(testPix))
                         {
-                            *pTar = *pSrc;
-                            pTar += 4;
-                            pSrc += 1;
+                            quint8 * pTar   = img.bits() + offset;
+                            quint8 * pSrc   = buffer.data();
+                            const int size  = buffer.size();
+
+                            for(int i = 0; i < size; ++i)
+                            {
+                                *pTar = *pSrc;
+                                pTar += sizeof(testPix);
+                                pSrc += 1;
+                            }
                         }
                     }
                 }
@@ -353,6 +355,28 @@ void CMapGeoTiff::convertM2Pt(double& u, double& v)
     v = (v - y) / (yscale * zoomFactor);
 }
 
+void CMapGeoTiff::convertPt2Pixel(double& u, double& v)
+{
+    convertPt2M(u,v);
+
+    u = (u - xref1) / xscale;
+    v = (v - yref1) / yscale;
+
+    if(u < 0 || u > xsize_px)
+    {
+        u = -1;
+        v = -1;
+        return;
+    }
+    if(v < 0 || v > ysize_px)
+    {
+        u = -1;
+        v = -1;
+        return;
+    }
+
+}
+
 
 void CMapGeoTiff::move(const QPoint& old, const QPoint& next)
 {
@@ -540,21 +564,16 @@ GDALDataset * CMapGeoTiff::getDataset()
 
 void CMapGeoTiff::getArea_n_Scaling(XY& p1, XY& p2, float& my_xscale, float& my_yscale)
 {
+    p1.u = 0;
+    p1.v = 0;
+    convertPt2Rad(p1.u, p1.v);
 
-    p1.u = x;
-    p1.v = y;
-    convertM2Rad(p1.u, p1.v);
-
-    p2.u = x;
-    p2.v = y;
-    convertM2Pt(p2.u, p2.v);
-
-    p2.u += xsize_px;
-    p2.v += ysize_px;
-
+    p2.u = size.width();
+    p2.v = size.height();
     convertPt2Rad(p2.u, p2.v);
 
-
     my_xscale   = xscale*zoomFactor;
     my_yscale   = yscale*zoomFactor;
+
+    qDebug() << p1.u << p1.v << p2.u << p2.v << my_xscale << my_yscale;
 }
