@@ -24,6 +24,9 @@
 #include <QtGui>
 #include "CMainWindow.h"
 #include "COsmTilesHash.h"
+#include "CResources.h"
+#include "CDlgMapOSMConfig.h"
+#include "CMapOSMType.h"
 #include <QDebug>
 
 CMapOSM::CMapOSM(CCanvas * parent)
@@ -39,32 +42,20 @@ CMapOSM::CMapOSM(CCanvas * parent)
 {
     currentTileListIndex = -1;
     osmTiles = 0;
-    // %1 = osm_zoom; %2 = osm_x; %3 = osm_y
-    tileList << qMakePair(QString("OpenStreetMap"),QString("tile.openstreetmap.org/%1/%2/%3.png"));
-    tileList << qMakePair(QString("OpenCycleMap"),QString("andy.sandbox.cloudmade.com/tiles/cycle/%1/%2/%3.png"));
-    //    tileList << qMakePair(QString("topo.geofabrik.de CC-NC-SA"),QString("topo.geofabrik.de/trails/%1/%2/%3.png"));
-    tileList << qMakePair(QString("OpenPisteMap"),QString("openpistemap.org/tiles/contours/%1/%2/%3.png"));
-    tileList << qMakePair(QString("WanderatlasMap"),QString("maps.ich-geh-wandern.de/contours/%1/%2/%3.png"));
-#if PRIVATE
-    tileList << qMakePair(QString("Outdooractive DE"),QString("t0.outdooractive.com/portal/map/%1/%2/%3.png"));
-    tileList << qMakePair(QString("Outdooractive AU"),QString("t0.outdooractive.com/austria/map/%1/%2/%3.png"));
-    tileList << qMakePair(QString("Outdooractive IT"),QString("t0.outdooractive.com/suedtirol/map/%1/%2/%3.png"));
-
-#endif
-
 
     cb = new QComboBox(theMainWindow->getCanvas());
-
-    for(int i = 0; i < tileList.size(); i++)
-    {
-        QPair<QString, QString> p = tileList.at(i);
-        cb->addItem(p.first);
-    }
-
     connect(cb,SIGNAL(activated( int )),this,SLOT(setNewTileUrl(int)));
 
     theMainWindow->statusBar()->insertPermanentWidget(0,cb);
 
+    // initialize builtin maps
+    mapOsm=CMapOSMType(QString("OpenStreetMap"),QString("tile.openstreetmap.org/%1/%2/%3.png"),QString("osm"));
+    mapOcm=CMapOSMType(QString("OpenCycleMap"),QString("andy.sandbox.cloudmade.com/tiles/cycle/%1/%2/%3.png"),QString("ocm"));
+    mapOpm=CMapOSMType(QString("OpenPisteMap"),QString("openpistemap.org/tiles/contours/%1/%2/%3.png"),QString("opm"));
+    mapWam=CMapOSMType(QString("WanderatlasMap"),QString("maps.ich-geh-wandern.de/contours/%1/%2/%3.png"),QString("wam"));
+
+    this->rebuildServerList();
+
     QSettings cfg;
 
     int tileListIndex = cfg.value("osm/tileListIndex",0).toInt();
@@ -73,6 +64,7 @@ CMapOSM::CMapOSM(CCanvas * parent)
 
     setNewTileUrl(tileListIndex);
     pjsrc = pj_init_plus("+proj=merc +lon_0=0 +k=1 +x_0=0 +y_0=0 +a=6378137 +b=6378137 +units=m +no_defs ");
+    oSRS.importFromProj4(getProjection());
 
     char * ptr = pj_get_def(pjsrc,0);
     qDebug() << "OSM:" << ptr;
@@ -135,8 +127,71 @@ CMapOSM::~CMapOSM()
 }
 
 
-void CMapOSM::setNewTileUrl(int index)
+bool CMapOSM::rebuildServerList()
 {
+    QString cbOldText=cb->currentText();
+
+    tileList.clear();
+
+    QSettings cfg;
+
+    // %1 = osm_zoom; %2 = osm_x; %3 = osm_y
+
+    mapOsm.setEnabled(cfg.value("osm/builtinMaps/osm", true).toBool());
+    tileList << mapOsm;
+
+    mapOcm.setEnabled(cfg.value("osm/builtinMaps/ocm", true).toBool());
+    tileList << mapOcm;
+
+    //    CMapOSMType mapGeo(QString("topo.geofabrik.de CC-NC-SA"),QString("topo.geofabrik.de/trails/%1/%2/%3.png"));
+    //    mapGeo.setBuiltin(QString("geofabrik"));
+    //    mapGeo.setEnabled(cfg.value("osm/builtinMaps/geo", true).toBool());
+    //    tileList << mapGeo;
+
+    mapOpm.setEnabled(cfg.value("osm/builtinMaps/opm", true).toBool());
+    tileList << mapOpm;
+
+    mapWam.setEnabled(cfg.value("osm/builtinMaps/wam", true).toBool());
+    tileList << mapWam;
+
+    int size = cfg.beginReadArray("osm/customMaps");
+    for (int i = 0; i < size; ++i)
+    {
+        cfg.setArrayIndex(i);
+        CMapOSMType map(QString(cfg.value("mapName").toString()),QString(cfg.value("mapString").toString()));
+        tileList << map;
+    }
+    cfg.endArray();
+
+
+    cb->clear();
+
+    if (tileList.size()==0) {
+        mapOsm.setEnabled(true);
+        cb->addItem(mapOsm.title,0);
+    } else {
+        for(int i = 0; i < tileList.size(); i++)
+        {
+            CMapOSMType p = tileList.at(i);
+            if (p.isEnabled())
+            {
+                cb->addItem(p.title,i);
+            }
+        }
+    }
+    int updatedIndex=cb->findText(cbOldText);
+    if (updatedIndex==-1) {
+        return false;
+    } else {
+        cb->setCurrentIndex(updatedIndex);
+        return true;
+    }
+}
+
+
+void CMapOSM::setNewTileUrl(int cbIndex)
+{
+    int index=cb->itemData(cbIndex).toInt();
 
     if(index >= tileList.count())
     {
@@ -155,10 +210,12 @@ void CMapOSM::setNewTileUrl(int index)
             delete osmTiles;
             osmTiles = 0;
         }
-        if (cb->currentIndex() != currentTileListIndex)
-            cb->setCurrentIndex(currentTileListIndex);
+        if (cb->currentIndex() != cbIndex)
+        {
+            cb->setCurrentIndex(cbIndex);
+        }
 
-        osmTiles = new COsmTilesHash(tileList.at(index).second);
+        osmTiles = new COsmTilesHash(tileList.at(index).path);
         connect(osmTiles,SIGNAL(newImageReady(QImage,bool)),this,SLOT(newImageReady(QImage,bool)));
 
         needsRedraw = true;
@@ -324,40 +381,43 @@ void CMapOSM::draw(QPainter& p)
 
     needsRedraw = false;
 
-    QString str;
-    if(zoomFactor < 1.0)
+    if(CResources::self().showZoomLevel())
     {
-        str = tr("Overzoom x%1").arg(1/zoomFactor,0,'f',0);
+
+        QString str;
+        if(zoomFactor < 1.0)
+        {
+            str = tr("Overzoom x%1").arg(1/zoomFactor,0,'f',0);
+        }
+        else
+        {
+            str = tr("Zoom level x%1").arg(zoomFactor);
+        }
+
+        p.setPen(Qt::white);
+        p.setFont(QFont("Sans Serif",14,QFont::Black));
+
+        p.drawText(9  ,23, str);
+        p.drawText(10 ,23, str);
+        p.drawText(11 ,23, str);
+        p.drawText(9  ,24, str);
+        p.drawText(11 ,24, str);
+        p.drawText(9  ,25, str);
+        p.drawText(10 ,25, str);
+        p.drawText(11 ,25, str);
+
+        p.setPen(Qt::darkBlue);
+        p.drawText(10,24,str);
+
+        p.setFont(QFont("Sans Serif",8,QFont::Black));
+
+        if(currentTileListIndex < 3)
+        {
+            CCanvas::drawText(tr("Map has been created by %1 under Creative Commons Attribution-ShareAlike 2.0 license").arg(tileList.at(currentTileListIndex).title), p, rect.bottomLeft() + QPoint(rect.width() / 2, -5) , QColor(Qt::darkBlue));
+            CCanvas::drawText(tr("and has been downloaded from: %1").arg(QString(tileList.at(currentTileListIndex).path).arg('z').arg('x').arg('y')), p, rect.bottomLeft() + QPoint(rect.width() / 2, +7) , QColor(Qt::darkBlue));
+        }
+
     }
-    else
-    {
-        str = tr("Zoom level x%1").arg(zoomFactor);
-    }
-
-    p.setPen(Qt::white);
-    p.setFont(QFont("Sans Serif",14,QFont::Black));
-
-    p.drawText(9  ,23, str);
-    p.drawText(10 ,23, str);
-    p.drawText(11 ,23, str);
-    p.drawText(9  ,24, str);
-    p.drawText(11 ,24, str);
-    p.drawText(9  ,25, str);
-    p.drawText(10 ,25, str);
-    p.drawText(11 ,25, str);
-
-    p.setPen(Qt::darkBlue);
-    p.drawText(10,24,str);
-
-    p.setFont(QFont("Sans Serif",8,QFont::Black));
-
-    if(currentTileListIndex < 3)
-    {
-        CCanvas::drawText(tr("Map has been created by %1 under Creative Commons Attribution-ShareAlike 2.0 license").arg(tileList.at(currentTileListIndex).first), p, rect.bottomLeft() + QPoint(rect.width() / 2, -5) , QColor(Qt::darkBlue));
-        CCanvas::drawText(tr("and has been downloaded from: %1").arg(QString(tileList.at(currentTileListIndex).second).arg('z').arg('x').arg('y')), p, rect.bottomLeft() + QPoint(rect.width() / 2, +7) , QColor(Qt::darkBlue));
-    }
-
-
 }
 
 
@@ -416,5 +476,7 @@ void CMapOSM::dimensions(double& lon1, double& lat1, double& lon2, double& lat2)
 
 void CMapOSM::config()
 {
+    CDlgMapOSMConfig * dlg = new CDlgMapOSMConfig(this);
+    dlg->show();
 
 }
