@@ -24,6 +24,9 @@
 #include "GeoMath.h"
 #include "CCanvas.h"
 #include "CMapSelectionRaster.h"
+#include "CResources.h"
+#include "CDlgMapQMAPConfig.h"
+#include "CMainWindow.h"
 
 #include <QtGui>
 
@@ -41,6 +44,7 @@ CMapQMAP::CMapQMAP(const QString& key, const QString& fn, CCanvas * parent)
 , zoomFactor(1)
 , foundMap(false)
 , quadraticZoom(false)
+, checkQuadZoom(0)
 {
     filename = fn;
 
@@ -49,6 +53,12 @@ CMapQMAP::CMapQMAP(const QString& key, const QString& fn, CCanvas * parent)
     QSettings mapdef(filename,QSettings::IniFormat);
     int nLevels = mapdef.value("main/levels",0).toInt();
 
+    info  = "<h1>" + mapdef.value("description/comment", "").toString() + "</h1>";
+
+    quadraticZoom = mapdef.value("main/quadraticZoom",quadraticZoom).toBool();
+    info += "<p>" + tr("Quadratic zoom %1").arg(quadraticZoom ? tr("enabled") : tr("disabled")) + "</p>";
+    info += QString("<p><table><tr><th>%1</th><th>%2</th><th width='100%'>%3</th></tr>").arg(tr("Map Level")).arg(tr("Zoom Level")).arg(tr("Files"));
+
     // create map level list
     CMapLevel * maplevel = 0;
     for(int n=1; n <= nLevels; ++n)
@@ -70,10 +80,48 @@ CMapQMAP::CMapQMAP(const QString& key, const QString& fn, CCanvas * parent)
             maplevels << maplevel;
         }
 
+        info += QString("<tr><td align='center'>%1</td><td align='center'>%2..%3</td><td>%4</td></tr>").arg(n).arg(min).arg(max).arg(files.join(", "));
+
         mapdef.endGroup();
     }
+    info += "</table></p>";
 
-    quadraticZoom = mapdef.value("main/quadraticZoom",quadraticZoom).toBool();
+    info += QString("<p><table><tr><th>%1</th><th width='100%'>%2</th></tr>").arg(tr("Parameter")).arg(tr("Value"));
+
+    QString strTopLeft      = mapdef.value("description/topleft").toString();
+    QString strBottomRight  = mapdef.value("description/bottomright").toString();
+
+    info += QString("<tr><td>%1</td><td>%2</td></tr>").arg(tr("Top/Left")).arg(strTopLeft.replace("\260","&#176;"));
+    info += QString("<tr><td>%1</td><td>%2</td></tr>").arg(tr("Bottom/Right")).arg(strBottomRight.replace("\260","&#176;"));
+
+    if(!maplevels.isEmpty())
+    {
+        XY p1, p2;
+        double a1,a2, width, height;
+        float u1 = 0, v1 = 0, u2 = 0, v2 = 0;
+        GPS_Math_Str_To_Deg(strTopLeft.replace("&#176;",""), u1, v1);
+        GPS_Math_Str_To_Deg(strBottomRight.replace("&#176;",""), u2, v2);
+
+        p1.u = u1 * DEG_TO_RAD;
+        p1.v = v1 * DEG_TO_RAD;
+        p2.u = u2 * DEG_TO_RAD;
+        p2.v = v1 * DEG_TO_RAD;
+        width   = distance(p1,p2,a1,a2)/1000;
+        p1.u = u1 * DEG_TO_RAD;
+        p1.v = v1 * DEG_TO_RAD;
+        p2.u = u1 * DEG_TO_RAD;
+        p2.v = v2 * DEG_TO_RAD;
+        height  = distance(p1,p2,a1,a2)/1000;
+
+        info += QString("<tr><td>%1</td><td>%2 km&#178; (%3 km x %4 km)</td></tr>").arg(tr("Area")).arg(width*height,0,'f',1).arg(width,0,'f',1).arg(height,0,'f',1);
+        if(maplevels[0]->begin() != maplevels[0]->end())
+        {
+            info += QString("<tr><td>%1</td><td>%2</td></tr>").arg(tr("Projection")).arg((*maplevels[0]->begin())->strProj);
+        }
+    }
+
+
+    info += "</table></p>";
 
     // If no configuration is stored read values from the map definition's "home" section
     // zoom() has to be called in either case to setup / initialize all other internal parameters
@@ -99,6 +147,13 @@ CMapQMAP::CMapQMAP(const QString& key, const QString& fn, CCanvas * parent)
         resize(parent->size());
     }
 
+    if(!key.isEmpty())
+    {
+        checkQuadZoom = new QCheckBox(theMainWindow->getCanvas());
+        checkQuadZoom->setText(tr("quadratic zoom"));
+        checkQuadZoom->setChecked(quadraticZoom);
+        theMainWindow->statusBar()->insertPermanentWidget(0,checkQuadZoom);
+    }
     qDebug() << "done";
 }
 
@@ -122,9 +177,47 @@ CMapQMAP::~CMapQMAP()
     midU = rect.center().x();
     midV = rect.center().y();
     convertPt2Rad(midU, midV);
+
+    if(checkQuadZoom)
+    {
+        delete checkQuadZoom;
+    }
 }
 
 
+const QString& CMapQMAP::getFilename(int u, int v)
+{
+    if(pMaplevel.isNull()) return filename;
+
+
+    QVector<CMapFile*>::const_iterator it = pMaplevel->begin();
+    while(it != pMaplevel->end())
+    {
+        const CMapFile * map = *it;
+
+        double u1 = u;
+        double v1 = v;
+
+        convertPt2M(u1,v1);
+
+        u1 = (u1 - map->xref1) / map->xscale;
+        v1 = (v1 - map->yref1) / map->yscale;
+
+        if(u1 >= 0 && u1 < map->xsize_px)
+        {
+            if(v1 >= 0 && v1 < map->ysize_px)
+            {
+
+                return map->filename;
+            }
+        }
+
+        it++;
+    }
+
+    return filename;
+}
+
 bool CMapQMAP::is32BitRgb()
 {
     return pMaplevel.isNull() ? true : pMaplevel->is32BitRgb();
@@ -163,31 +256,33 @@ void CMapQMAP::draw(QPainter& p)
 
     needsRedraw = !foundMap;
 
-    QString str;
-    if(zoomFactor < 1.0)
+    if(CResources::self().showZoomLevel())
     {
-        str = tr("Overzoom x%1").arg(1/zoomFactor,0,'f',0);
+        QString str;
+        if(zoomFactor < 1.0)
+        {
+            str = tr("Overzoom x%1").arg(1/zoomFactor,0,'f',0);
+        }
+        else
+        {
+            str = tr("Zoom level x%1").arg(zoomidx);
+        }
+
+        p.setPen(Qt::white);
+        p.setFont(QFont("Sans Serif",14,QFont::Black));
+
+        p.drawText(9  ,23, str);
+        p.drawText(10 ,23, str);
+        p.drawText(11 ,23, str);
+        p.drawText(9  ,24, str);
+        p.drawText(11 ,24, str);
+        p.drawText(9  ,25, str);
+        p.drawText(10 ,25, str);
+        p.drawText(11 ,25, str);
+
+        p.setPen(Qt::darkBlue);
+        p.drawText(10,24,str);
     }
-    else
-    {
-        str = tr("Zoom level x%1").arg(zoomidx);
-    }
-
-    p.setPen(Qt::white);
-    p.setFont(QFont("Sans Serif",14,QFont::Black));
-
-    p.drawText(9  ,23, str);
-    p.drawText(10 ,23, str);
-    p.drawText(11 ,23, str);
-    p.drawText(9  ,24, str);
-    p.drawText(11 ,24, str);
-    p.drawText(9  ,25, str);
-    p.drawText(10 ,25, str);
-    p.drawText(11 ,25, str);
-
-    p.setPen(Qt::darkBlue);
-    p.drawText(10,24,str);
-
 }
 
 
@@ -335,6 +430,7 @@ void CMapQMAP::draw()
                     QVector<quint8> buffer(w*h);
 
                     img.fill(qRgba(255,255,255,255));
+                    QRgb testPix = qRgba(GCI_RedBand, GCI_GreenBand, GCI_BlueBand, GCI_AlphaBand);
 
                     for(int b = 1; b <= map->rasterBandCount; ++b)
                     {
@@ -346,15 +442,23 @@ void CMapQMAP::draw()
 
                         if(!err)
                         {
-                            quint8 * pTar   = img.bits() - (pBand->GetColorInterpretation() - 5);
-                            quint8 * pSrc   = buffer.data();
-                            const int size  = buffer.size();
+                            int pbandColour = pBand->GetColorInterpretation();
+                            unsigned int offset;
 
-                            for(int i = 0; i < size; ++i)
+                            for (offset = 0; offset < sizeof(testPix) && *(((quint8 *)&testPix) + offset) != pbandColour; offset++);
+
+                            if(offset < sizeof(testPix))
                             {
-                                *pTar = *pSrc;
-                                pTar += 4;
-                                pSrc += 1;
+                                quint8 * pTar   = img.bits() + offset;
+                                quint8 * pSrc   = buffer.data();
+                                const int size  = buffer.size();
+
+                                for(int i = 0; i < size; ++i)
+                                {
+                                    *pTar = *pSrc;
+                                    pTar += sizeof(testPix);
+                                    pSrc += 1;
+                                }
                             }
                         }
                     }
@@ -403,6 +507,38 @@ void CMapQMAP::convertM2Pt(double& u, double& v)
     v = (v - pt.v) / (map->yscale * zoomFactor);
 }
 
+void CMapQMAP::convertPt2Pixel(double& u, double& v)
+{
+    QVector<CMapFile*>::const_iterator it = pMaplevel->begin();
+    while(it != pMaplevel->end())
+    {
+        const CMapFile * map = *it;
+
+        double u1 = u;
+        double v1 = v;
+
+        convertPt2M(u1,v1);
+
+        u1 = (u1 - map->xref1) / map->xscale;
+        v1 = (v1 - map->yref1) / map->yscale;
+
+        if(u1 >= 0 && u1 < map->xsize_px)
+        {
+            if(v1 >= 0 && v1 < map->ysize_px)
+            {
+                u = u1;
+                v = v1;
+                return;
+            }
+        }
+
+        it++;
+    }
+
+    u = -1;
+    v = -1;
+
+}
 
 void CMapQMAP::move(const QPoint& old, const QPoint& next)
 {
@@ -437,6 +573,8 @@ void CMapQMAP::zoom(bool zoomIn, const QPoint& p0)
     p1.v = p0.y();
     convertPt2Rad(p1.u, p1.v);
 
+    quadraticZoom = checkQuadZoom->isChecked();
+
     if(quadraticZoom)
     {
 
@@ -527,7 +665,15 @@ void CMapQMAP::zoom(qint32& level)
     }
 
     pMaplevel   = *maplevel;
-    pjsrc       = (*pMaplevel->begin())->pj;
+    if(pMaplevel->begin() != pMaplevel->end())
+    {
+        pjsrc       = (*pMaplevel->begin())->pj;
+        oSRS        = (*pMaplevel->begin())->oSRS;
+    }
+    else
+    {
+        pjsrc = 0;
+    }
     zoomFactor  = level - (*maplevel)->min + 1;
     setFastDrawTimer();
     emit sigChanged();
@@ -545,6 +691,8 @@ void CMapQMAP::zoom(double lon1, double lat1, double lon2, double lat2)
         return;
     }
 
+    quadraticZoom = checkQuadZoom->isChecked();
+
     double u[3];
     double v[3];
     double dU, dV;
@@ -578,7 +726,7 @@ void CMapQMAP::zoom(double lon1, double lat1, double lon2, double lat2)
                 pMaplevel   = *maplevel;
                 pjsrc       = map->pj;
 
-                zoomidx = pMaplevel->min + z - 1;
+                zoomidx = pMaplevel->min + z - 1;                
                 if(quadraticZoom)
                 {
                     zoomidx = pow(2.0, ceil(log(zoomidx*1.0)/log(2.0)));
@@ -641,11 +789,21 @@ void CMapQMAP::select(IMapSelection& ms, const QRect& rect)
     sel.lat2 = rect.bottom();
     convertPt2Rad(sel.lon2, sel.lat2);
 
-    sel.key = QString("%1%2%3").arg(sel.mapkey).arg(sel.lon1).arg(sel.lat1);
-
-    QString pos1, pos2;
-    GPS_Math_Deg_To_Str(sel.lon1 * RAD_TO_DEG, sel.lat1 * RAD_TO_DEG, pos1);
-    GPS_Math_Deg_To_Str(sel.lon2 * RAD_TO_DEG, sel.lat2 * RAD_TO_DEG, pos2);
-
-    sel.description += "\n" + pos1 + "\n" + pos2;
 }
+
+quint32 CMapQMAP::scalePixelGrid(quint32 nPixel)
+{
+    CMapLevel * level       = maplevels[0];
+    const CMapFile * file1  = *level->begin();
+    const CMapFile * file2  = *pMaplevel->begin();
+    return quint32((nPixel * file1->xscale)/(zoomFactor * file2->xscale) + 0.5);
+}
+
+void CMapQMAP::config()
+{
+
+    CDlgMapQMAPConfig * dlg = new CDlgMapQMAPConfig(this);
+    dlg->show();
+
+}
+
