@@ -205,12 +205,12 @@ void CMapSearchWidget::slotMaskSelection(const QPixmap& pixmap)
 }
 
 
-void CMapSearchWidget::setArea(const CMapSelectionRaster& ms)
+void CMapSearchWidget::setArea(CMapSelectionRaster& ms)
 {
     if(canvas) canvas->deleteLater();
 
     area = ms;
-    labelArea->setText(area.description);
+    labelArea->setText(area.getDescription());
     checkGui();
 }
 
