@@ -58,6 +58,7 @@ CMegaMenu::CMegaMenu(CCanvas * canvas)
     actionGroup = theMainWindow->getActionGroupProvider();
     actions     = actionGroup->getActions();
 
+
 }
 
 
@@ -131,6 +132,12 @@ void CMegaMenu::switchByKeyWord(const QString& key)
         actions->funcSwitchToRoute();
         actions->funcMoveArea();
     }
+    else if (key == "GeoDB")
+    {
+        actions->funcSwitchToMain();
+        actions->funcMoveArea();
+    }
+
 
 }
 
@@ -151,14 +158,22 @@ void CMegaMenu::initStyleOption(QStyleOptionMenuItem *option, const QAction *act
 
     option->initFrom(this);
     option->palette = palette();
+    option->palette.setCurrentColorGroup(QPalette::Normal);
+
     option->palette.setBrush(QPalette::Normal, QPalette::Button, Qt::NoBrush);
     option->palette.setBrush(QPalette::Inactive, QPalette::Button, Qt::NoBrush);
+
     option->state = QStyle::State_None;
 
     if (window()->isActiveWindow())
     {
         option->state |= QStyle::State_Active;
     }
+    if(!isCurrent)
+    {
+        option->palette.setBrush(QPalette::Normal, QPalette::Window, QColor(0,0,0,0));
+    }
+
     if (isEnabled() && action->isEnabled() && (!action->menu() || action->menu()->isEnabled()))
     {
         option->state |= QStyle::State_Enabled;
@@ -227,11 +242,17 @@ void CMegaMenu::paintEvent(QPaintEvent *e)
 
     QPainter p(this);
 
+    QPalette palette = theMainWindow->menuBar()->palette();
+    p.fillRect(rect(), palette.brush(QPalette::Normal, QPalette::Window));
+    QPixmap pix = *pixmap();
+    p.drawPixmap(0,0, pix.scaled(size(), Qt::IgnoreAspectRatio, Qt::SmoothTransformation));
+
     QFont f = font();
     f.setBold(true);
     p.setFont(f);
 
     p.setClipRegion(rectTitle);
+    p.setPen(palette.brush(QPalette::Normal, QPalette::WindowText).color());
     p.drawText(rectTitle, Qt::AlignCenter, title);
 
     p.setFont(font());
