@@ -21,6 +21,7 @@
 #include "CCanvas.h"
 #include "CMapDB.h"
 #include "CWptDB.h"
+#include "CSearchDB.h"
 #include "CTrackDB.h"
 #include "CDlgEditWpt.h"
 #include "GeoMath.h"
@@ -33,8 +34,10 @@
 CMouseMoveMap::CMouseMoveMap(CCanvas * parent)
 : IMouse(parent)
 , moveMap(false)
+, leftButtonPressed(false)
+, altKeyPressed(false)
 {
-    cursor = QCursor(QPixmap(":/cursors/cursorMoveMap"),0,0);
+    cursor = QCursor(QPixmap(":/cursors/cursorMoveMap.png"),0,0);
 }
 
 
@@ -47,19 +50,21 @@ CMouseMoveMap::~CMouseMoveMap()
 void CMouseMoveMap::mouseMoveEvent(QMouseEvent * e)
 {
     mousePos = e->pos();
-
     if(moveMap)
     {
         //CMapDB::self().getMap().move(oldPoint, e->pos());
         CUndoStackView::getInstance()->push(new CMapUndoCommandMove(&CMapDB::self().getMap(),oldPoint, e->pos()));
-        oldPoint = e->pos();
         canvas->update();
     }
 
+    oldPoint = e->pos();
+
     mouseMoveEventWpt(e);
     mouseMoveEventTrack(e);
+    mouseMoveEventRoute(e);
     mouseMoveEventOverlay(e);
     mouseMoveEventSearch(e);
+    mouseMoveEventMapSel(e);
 }
 
 
@@ -68,34 +73,41 @@ void CMouseMoveMap::mousePressEvent(QMouseEvent * e)
     if(e->button() == Qt::LeftButton)
     {
 
+        oldPoint = e->pos();
+
         CTrack * track = CTrackDB::self().highlightedTrack();
 
         if(!selWpt.isNull())
         {
-            CWptDB::self().selWptByKey(selWpt->key());
+            CWptDB::self().selWptByKey(selWpt->getKey(), false);
             mousePressEventWpt(e);
         }
         else if(track && selTrkPt)
         {
-            track->setPointOfFocus(selTrkPt->idx);
+            track->setPointOfFocus(selTrkPt->idx, true, false);
         }
         else if(!selSearch.isNull())
         {
+            CSearchDB::self().selSearchByKey(selSearch->getKey());
             mousePressEventSearch(e);
         }
         else
         {
-            CUndoStackView::getInstance()->beginMacro(tr("Move map"));
-            cursor = QCursor(QPixmap(":/cursors/cursorMove"));
-            QApplication::setOverrideCursor(cursor);
-            moveMap     = true;
-            oldPoint    = e->pos();
-
-            CMapDB::self().getMap().fastDrawOn();
+            leftButtonPressed = true;
+            if (!moveMap)
+            {
+                CUndoStackView::getInstance()->beginMacro(tr("Move map"));
+                cursor = QCursor(QPixmap(":/cursors/cursorMove.png"));
+                QApplication::setOverrideCursor(cursor);
+                moveMap     = true;
+                CMapDB::self().getMap().fastDrawOn();
+            }
         }
     }
     else if(e->button() == Qt::RightButton)
     {
+        mousePos = e->pos();
+        oldPoint = e->pos();
         canvas->raiseContextMenu(e->pos());
     }
 }
@@ -103,26 +115,75 @@ void CMouseMoveMap::mousePressEvent(QMouseEvent * e)
 
 void CMouseMoveMap::mouseReleaseEvent(QMouseEvent * e)
 {
-    if(moveMap && (e->button() == Qt::LeftButton))
+    if(e->button() == Qt::LeftButton)
     {
-        CUndoStackView::getInstance()->endMacro();
-        moveMap = false;
-        CMapDB::self().getMap().fastDrawOff();
+        leftButtonPressed = false;
+        if(moveMap && (!altKeyPressed))
+        {
+            CUndoStackView::getInstance()->endMacro();
+            moveMap = false;
+            CMapDB::self().getMap().fastDrawOff();
+            cursor = QCursor(QPixmap(":/cursors/cursorMoveMap.png"),0,0);
+            QApplication::restoreOverrideCursor();
+            canvas->update();
+        }
 
-        cursor = QCursor(QPixmap(":/cursors/cursorMoveMap"),0,0);
-        QApplication::restoreOverrideCursor();
+    }
+}
+
+void CMouseMoveMap::keyPressEvent(QKeyEvent * e)
+{
+#ifdef ALTKEY_MOVES_MAP
+    if (e->key() == Qt::Key_Alt)
+    {
+        altKeyPressed = true;
+        if (!moveMap)
+        {
+            CUndoStackView::getInstance()->beginMacro(tr("Move map"));
+            cursor = QCursor(QPixmap(":/cursors/cursorMove.png"));
+            QApplication::setOverrideCursor(cursor);
+            moveMap     = true;
+            CMapDB::self().getMap().fastDrawOn();
+        }
+    }
+#endif
+}
+
+void CMouseMoveMap::mouseDoubleClickEvent(QMouseEvent * e)
+{
+    if(!selWpt.isNull())
+    {
+        CWptDB::self().selWptByKey(selWpt->getKey(), true);
         canvas->update();
     }
 }
 
+void CMouseMoveMap::keyReleaseEvent(QKeyEvent * e)
+{
+#ifdef ALTKEY_MOVES_MAP
+    if (e->key() == Qt::Key_Alt)
+    {
+        altKeyPressed = false;
+        if(moveMap && (!leftButtonPressed))
+        {
+            CUndoStackView::getInstance()->endMacro();
+            moveMap = false;
+            CMapDB::self().getMap().fastDrawOff();
+            cursor = QCursor(QPixmap(":/cursors/cursorMoveMap.png"),0,0);
+            QApplication::restoreOverrideCursor();
+            canvas->update();
+        }
+    }
+#endif
+}
 
 void CMouseMoveMap::draw(QPainter& p)
 {
-    p.setRenderHint(QPainter::Antialiasing,true);
+    drawPos1(p);
     drawSelWpt(p);
     drawSelTrkPt(p);
+    drawSelRtePt(p);
     drawSelSearch(p);
-    p.setRenderHint(QPainter::Antialiasing,false);
 }
 
 
@@ -133,9 +194,14 @@ void CMouseMoveMap::contextMenu(QMenu& menu)
         menu.addSeparator();
         menu.addAction(QPixmap(":/icons/iconClipboard16x16.png"),tr("Copy Pos. Waypoint"),this,SLOT(slotCopyPositionWpt()));
         menu.addAction(QPixmap(":/icons/iconEdit16x16.png"),tr("Edit Waypoint ..."),this,SLOT(slotEditWpt()));
-        if(!selWpt->sticky)
+
+        if(selWpt->isMovable())
         {
             menu.addAction(QPixmap(":/icons/iconWptMove16x16.png"),tr("Move Waypoint"),this,SLOT(slotMoveWpt()));
+        }
+
+        if(!selWpt->sticky)
+        {
             menu.addAction(QPixmap(":/icons/iconClear16x16.png"),tr("Delete Waypoint"),this,SLOT(slotDeleteWpt()));
         }
     }
@@ -152,6 +218,117 @@ void CMouseMoveMap::contextMenu(QMenu& menu)
                 menu.addAction(QPixmap(":/icons/iconClipboard16x16.png"),tr("Copy Pos. Trackpoint"),this,SLOT(slotCopyPositionTrack()));
         menu.addAction(QPixmap(":/icons/iconEdit16x16.png"),tr("Edit Track ..."),this,SLOT(slotEditTrack()));
     }
+    menu.addSeparator();
+
+
+
+    IMap& map = CMapDB::self().getMap();
+    double u = mousePos.x();
+    double v = mousePos.y();
+
+    if(!map.isLonLat())
+    {
+        map.convertPt2M(u,v);
+        QString posMeter = tr("N %1m E %2m").arg(u, 0,'f',0).arg(v,0,'f',0);
+        menu.addAction(QIcon(":/icons/iconClipboard16x16.png"), posMeter, this, SLOT(slotCopyPosMeter()));
+    }
+
+    map.convertM2Rad(u,v);
+    u *= RAD_TO_DEG;
+    v *= RAD_TO_DEG;
+    QString posDeg;
+    GPS_Math_Deg_To_Str(u, v, posDeg);
+    menu.addAction(QIcon(":/icons/iconClipboard16x16.png"), posDeg, this, SLOT(slotCopyPosDegree()));
+
+    u = mousePos.x();
+    v = mousePos.y();
+    map.convertPt2Pixel(u,v);
+
+
+    if(u >= 0 && v >= 0)
+    {
+        QString fn = QFileInfo(map.getFilename(mousePos.x(), mousePos.y())).fileName();
+
+
+        QString posPixel = tr("Pixel %1x%2 (%3)").arg(u, 0,'f',0).arg(v,0,'f',0).arg(fn);
+        menu.addAction(QIcon(":/icons/iconClipboard16x16.png"), posPixel, this, SLOT(slotCopyPosPixel()));
+
+        if(pos1Pixel.x() >= 0 && pos1Pixel.y() >= 0)
+        {
+            double u1 = pos1Pixel.x();
+            double v1 = pos1Pixel.y();
+
+            QString posPixelSize = tr("Pos1 -> Pos %1x%2 w:%3 h:%4").arg(u1, 0,'f',0).arg(v1,0,'f',0).arg(u - u1,0,'f',0).arg(v - v1, 0,'f',0);
+            menu.addAction(QIcon(":/icons/iconClipboard16x16.png"), posPixelSize, this, SLOT(slotCopyPosPixelSize()));
+        }
+
+        menu.addAction(QIcon(":/icons/wpt/flag_pin_red15x15.png"), tr("Set as Pos1"), this, SLOT(slotSetPos1()));
+
+    }
+
+}
+
+
+void CMouseMoveMap::slotCopyPosDegree()
+{
+    IMap& map = CMapDB::self().getMap();
+    double u = mousePos.x();
+    double v = mousePos.y();
+
+    map.convertPt2Rad(u,v);
+    u *= RAD_TO_DEG;
+    v *= RAD_TO_DEG;
+    QString position;
+    GPS_Math_Deg_To_Str(u, v, position);
+
+    QClipboard *clipboard = QApplication::clipboard();
+    clipboard->setText(position);
+
+}
+
+void CMouseMoveMap::slotCopyPosMeter()
+{
+    IMap& map = CMapDB::self().getMap();
+    double u = mousePos.x();
+    double v = mousePos.y();
+
+    map.convertPt2M(u,v);
+    QString position = tr("N %1m E %2m").arg(u, 0,'f',0).arg(v,0,'f',0);
+
+    QClipboard *clipboard = QApplication::clipboard();
+    clipboard->setText(position);
+}
+
+void CMouseMoveMap::slotCopyPosPixel()
+{
+    IMap& map = CMapDB::self().getMap();
+
+    double u = mousePos.x();
+    double v = mousePos.y();
+
+    map.convertPt2Pixel(u,v);
+    QString position = QString("%1 %2").arg(u, 0,'f',0).arg(v,0,'f',0);
+
+    QClipboard *clipboard = QApplication::clipboard();
+    clipboard->setText(position);
+
+}
+
+void CMouseMoveMap::slotCopyPosPixelSize()
+{
+    IMap& map = CMapDB::self().getMap();
+
+    double u1 = pos1Pixel.x();
+    double v1 = pos1Pixel.y();
+    double u2 = mousePos.x();
+    double v2 = mousePos.y();
+
+    map.convertPt2Pixel(u2,v2);
+    QString position = QString("%1 %2 %3 %4").arg(u1, 0,'f',0).arg(v1,0,'f',0).arg(u2 - u1, 0,'f',0).arg(v2 - v1,0,'f',0);
+
+    QClipboard *clipboard = QApplication::clipboard();
+    clipboard->setText(position);
+
 }
 
 
@@ -180,7 +357,7 @@ void CMouseMoveMap::slotDeleteWpt()
 {
     if(selWpt.isNull()) return;
 
-    QString key = selWpt->key();
+    QString key = selWpt->getKey();
     CWptDB::self().delWpt(key);
 }
 
@@ -211,7 +388,7 @@ void CMouseMoveMap::slotAddWpt()
     double v = mousePos.y();
     map.convertPt2Rad(u,v);
     float ele = dem.getElevation(u,v);
-    CWptDB::self().newWpt(u, v, ele);
+    CWptDB::self().newWpt(u, v, ele,"");
 
 }
 
@@ -239,23 +416,20 @@ void CMouseMoveMap::slotEditTrack()
     CTrack * track = CTrackDB::self().highlightedTrack();
     if(track)
     {
-        track->setPointOfFocus(selTrkPt->idx);
+        track->setPointOfFocus(selTrkPt->idx, true, false);
     }
 }
+
 void CMouseMoveMap::slotOpenGoogleMaps()	//TODO: Open Google Maps
 {
-        QString position;
+    QString position;
     GPS_Math_Deg_To_Str(selTrkPt->lon, selTrkPt->lat, position);
 
 
-        QDateTime utime = QDateTime::fromTime_t(selTrkPt->timestamp);
+    QDateTime utime = QDateTime::fromTime_t(selTrkPt->timestamp);
     utime.setTimeSpec(Qt::LocalTime);
     QString time = utime.toString();
 
-/*
-        QMessageBox msgBox;
-        msgBox.setText(position);
-        msgBox.exec();
-*/
-        QDesktopServices::openUrl(QUrl("http://maps.google.com/maps?t=h&z=18&om=1&q="+position+"("+time+")", QUrl::TolerantMode));
+    QDesktopServices::openUrl(QUrl("http://maps.google.com/maps?t=h&z=18&om=1&q="+position+"("+time+")", QUrl::TolerantMode));
 }
+
