@@ -34,6 +34,8 @@
 
 #include <QtGui>
 
+bool COverlayDistance::showBullets = true;
+
 bool operator==(const XY& p1, const XY& p2)
 {
     return (p1.u == p2.u) && (p1.v == p2.v);
@@ -42,11 +44,9 @@ bool operator==(const XY& p1, const XY& p2)
 QPointer<COverlayDistanceEditWidget> overlayDistanceEditWidget;
 
 COverlayDistance::COverlayDistance(const QString& name, const QString& comment, double speed, const QList<pt_t>& pts, QObject * parent)
-: IOverlay(parent, "Distance", QPixmap(":/icons/iconDistance16x16"))
+: IOverlay(parent, "Distance", ":/icons/iconDistance16x16.png")
 , points(pts)
 , thePoint(0)
-, name(name)
-, comment(comment)
 , distance(0)
 , speed(speed)
 , doSpecialCursor(false)
@@ -56,6 +56,17 @@ COverlayDistance::COverlayDistance(const QString& name, const QString& comment,
 , isEdit(false)
 {
 
+    if(name.isEmpty())
+    {
+        setName(tr("Tour %1").arg(keycnt));
+    }
+    else
+    {
+        setName(name);
+    }
+
+    setComment(comment);
+
     rectDel  = QRect(0,0,16,16);
     rectMove = QRect(32,0,16,16);
     rectAdd1 = QRect(0,32,16,16);
@@ -89,7 +100,8 @@ void COverlayDistance::save(QDataStream& s)
         s << pt.u << pt.v;
     }
     s << speed;
-    s << key();
+    s << getKey();
+    s << getParentWpt();
 }
 
 
@@ -97,6 +109,7 @@ void COverlayDistance::load(QDataStream& s)
 {
     pt_t pt;
     int size;
+    QString key;
 
     points.clear();
 
@@ -108,7 +121,9 @@ void COverlayDistance::load(QDataStream& s)
         points << pt;
     }
     s >> speed;
-    s >> _key_;
+    s >> key;
+
+    setKey(key);
 
 }
 
@@ -126,16 +141,25 @@ QString COverlayDistance::getInfo()
     }
     if(!comment.isEmpty())
     {
-        info += comment + "\n";
+        if(comment.length() < 60)
+        {
+            info += comment + "\n";
+        }
+        else
+        {
+            info += comment.left(57) + "...\n";
+        }
     }
 
+
     info += tr("Length: %1 %2").arg(val).arg(unit);
 
     if(speed > 0)
     {
-        info += "\n" + QString::number(speed * IUnit::self().speedfactor)  + IUnit::self().speedunit + " -> ";
+        info += "\n" + QString::number(speed * IUnit::self().speedfactor)  + IUnit::self().speedunit + " " + QChar(0x21E8) + " ";
 
-        double ttime = val.toDouble() * 3600 / (speed * IUnit::self().speedfactor);
+
+        double ttime = distance * 3.6/ (speed * IUnit::self().speedfactor);
         quint32 days = ttime / 86400;
 
         QTime time;
@@ -302,7 +326,7 @@ void COverlayDistance::mouseMoveEvent(QMouseEvent * e)
             QPoint pt2(u2, v2);
 
 
-            CMapDB::self().getMap().getClosePolyline(pt2, 10, leadline);
+            CMapDB::self().getMap().getClosePolyline(pt1, pt2, 10, leadline);
 
             if(!leadline.isEmpty())
             {
@@ -483,7 +507,10 @@ void COverlayDistance::mousePressEvent(QMouseEvent * e)
             calcDistance();
             theMainWindow->getCanvas()->update();
 
-            emit sigChanged();
+            if(addType == eNone)
+            {
+                emit sigChanged();
+            }
             return;
         }
 
@@ -515,7 +542,7 @@ void COverlayDistance::mousePressEvent(QMouseEvent * e)
 
             if(points.isEmpty())
             {
-                QStringList keys(key());
+                QStringList keys(getKey());
                 COverlayDB::self().delOverlays(keys);
             }
             calcDistance();
@@ -526,7 +553,7 @@ void COverlayDistance::mousePressEvent(QMouseEvent * e)
         }
         else if(rectMove.contains(pos1))
         {
-            QApplication::setOverrideCursor(QCursor(QPixmap(":/cursors/cursorMoveWpt"),0,0));
+            QApplication::setOverrideCursor(QCursor(QPixmap(":/cursors/cursorMoveWpt.png"),0,0));
             doMove      = true;
             doFuncWheel = false;
 
@@ -602,6 +629,8 @@ void COverlayDistance::mousePressEvent(QMouseEvent * e)
             addType     = eNone;
             subline.clear();
 
+            COverlayDB::self().emitSigChanged();
+
             QApplication::restoreOverrideCursor();
             return;
         }
@@ -620,17 +649,86 @@ void COverlayDistance::mouseReleaseEvent(QMouseEvent * e)
 
 }
 
-
-void COverlayDistance::draw(QPainter& p)
+void COverlayDistance::drawArrows(const QPolygon& line, const QRect& viewport, QPainter& p)
 {
-    if(points.isEmpty()) return;
+    QPointF arrow[4] =
+    {
+        QPointF( 20.0, 7.0),     //front
+        QPointF( 0.0, 0.0),      //upper tail
+        QPointF( 5.0, 7.0),      //mid tail
+        QPointF( 0.0, 15.0)      //lower tail
+    };
+
+    QPoint  pt, pt1, ptt;
+
+    // draw direction arrows
+    bool    start = true;
+    double  heading;
+
+    //generate arrow pic
+    QImage arrow_pic(21,16, QImage::Format_ARGB32);
+    arrow_pic.fill( qRgba(0,0,0,0));
+    QPainter t_paint(&arrow_pic);
+    USE_ANTI_ALIASING(t_paint, true);
+    t_paint.setPen(QPen(Qt::white, 2));
+    t_paint.setBrush(p.brush());
+    t_paint.drawPolygon(arrow, 4);
+    t_paint.end();
+
+
+    foreach(pt,line)
+    {
+        if(start)        // no arrow on  the first loop
+        {
+            start = false;
+        }
+        else
+        {
+            if(!viewport.contains(pt))
+            {
+                continue;
+            }
+            if((abs(pt.x() - pt1.x()) + abs(pt.y() - pt1.y())) < 7)
+            {
+                continue;
+            }
+                         // keep distance
+            if((abs(pt.x() - ptt.x()) + abs(pt.y() - ptt.y())) > 100)
+            {
+                if(0 != pt.x() - pt1.x() && (pt.y() - pt1.y()))
+                {
+                    heading = ( atan2((double)(pt.y() - pt1.y()), (double)(pt.x() - pt1.x())) * 180.) / PI;
+
+                    p.save();
+                    // draw arrow between bullets
+                    p.translate((pt.x() + pt1.x())/2,(pt.y() + pt1.y())/2);
+                    p.rotate(heading);
+                    p.drawImage(-11, -7, arrow_pic);
+                    p.restore();
+                         //remember last point
+                    ptt = pt;
+                }
+            }
+        }
+        pt1 = pt;
+    }
+
+}
+
+
+void COverlayDistance::draw(QPainter& p, const QRect& viewport)
+{
+    if(points.isEmpty() || !isVisible) return;
 
     IMap& map = CMapDB::self().getMap();
 
-    QPixmap icon_blue(":/icons/small_bullet_blue.png");
+    QPen pen1, pen2;
+    QPixmap icon(":/icons/small_bullet_darkgray.png");
     QPixmap icon_red(":/icons/small_bullet_red.png");
     QPixmap icon_BigRed(":/icons/bullet_red.png");
     XY pt1, pt2;
+    QPoint pt;
+
 
     int i;
     int start   = 0;
@@ -667,6 +765,10 @@ void COverlayDistance::draw(QPainter& p)
     pt1 = points[start];
     map.convertRad2Pt(pt1.u, pt1.v);
 
+    QPolygon polyline;
+
+    polyline << QPoint(pt1.u, pt1.v);
+
     // draw the lines
     for(i = start + 1; i < stop; i++)
     {
@@ -674,38 +776,60 @@ void COverlayDistance::draw(QPainter& p)
         pt2 = points[i];
         map.convertRad2Pt(pt2.u, pt2.v);
 
+        int d = abs(pt1.u - pt2.u) + abs(pt1.v - pt2.v);
+        if(d < 10)
+        {
+            continue;
+        }
+
         if(i != skip)
         {
-            if(highlight)
-            {
-                p.setPen(QPen(Qt::white, 7));
-                p.drawLine(pt1.u, pt1.v, pt2.u, pt2.v);
-                p.setPen(QPen(Qt::blue, 5));
-                p.drawLine(pt1.u, pt1.v, pt2.u, pt2.v);
-                p.setPen(QPen(Qt::white, 1));
-                p.drawLine(pt1.u, pt1.v, pt2.u, pt2.v);
-            }
-            else
-            {
-                p.setPen(QPen(Qt::white, 5));
-                p.drawLine(pt1.u, pt1.v, pt2.u, pt2.v);
-                p.setPen(QPen(Qt::darkBlue, 3));
-                p.drawLine(pt1.u, pt1.v, pt2.u, pt2.v);
-                p.setPen(QPen(Qt::white, 1));
-                p.drawLine(pt1.u, pt1.v, pt2.u, pt2.v);
-            }
+            polyline << QPoint(pt2.u, pt2.v);
         }
         pt1 = pt2;
     }
 
-    // draw the points
-    for(i = start; i < stop; i++)
+    if(highlight)
     {
-        pt2 = points[i];
+        pen1 = QPen(QColor(255,200,0,180),13);
+        pen1.setCapStyle(Qt::RoundCap);
+        pen1.setJoinStyle(Qt::RoundJoin);
 
-        map.convertRad2Pt(pt2.u, pt2.v);
-        p.drawPixmap(pt2.u - 4, pt2.v - 4, icon_blue);
+        pen2 = QPen(QColor(0,150,0,128),11);
+        pen2.setCapStyle(Qt::RoundCap);
+        pen2.setJoinStyle(Qt::RoundJoin);
+        pen2.setStyle(Qt::DotLine);
     }
+    else
+    {
+        pen1 = QPen(QColor(255,200,0,180),7);
+        pen1.setCapStyle(Qt::RoundCap);
+        pen1.setJoinStyle(Qt::RoundJoin);
+
+        pen2 = QPen(QColor(0,150,0,255),5);
+        pen2.setCapStyle(Qt::RoundCap);
+        pen2.setJoinStyle(Qt::RoundJoin);
+        pen2.setStyle(Qt::DotLine);
+    }
+
+    p.setPen(pen1);
+    p.drawPolyline(polyline);
+    p.setPen(pen2);
+    p.drawPolyline(polyline);
+
+
+    // draw the points
+    if(showBullets)
+    {
+        foreach(pt, polyline)
+        {
+            p.drawPixmap(pt.x() - 4, pt.y() - 4, icon);
+        }
+    }
+
+    p.setBrush(QColor(0,150,0,255));
+    drawArrows(polyline, viewport, p);
+
 
     // overlay _the_ point with a red bullet
     if(thePoint)
@@ -720,28 +844,21 @@ void COverlayDistance::draw(QPainter& p)
     if(!subline.isEmpty())
     {
 
-        p.setPen(QPen(Qt::magenta, 3));
+        QPen pen;
+        pen.setBrush(QBrush(QColor(255,0,255,150)));
+        pen.setWidth(20);
+        pen.setCapStyle(Qt::RoundCap);
+        pen.setJoinStyle(Qt::RoundJoin);
+
+        p.setPen(pen);
         p.drawPolyline(leadline);
 
-        if(highlight)
-        {
-            p.setPen(QPen(Qt::white, 7));
-            p.drawPolyline(subline);
-            p.setPen(QPen(Qt::blue, 5));
-            p.drawPolyline(subline);
-            p.setPen(QPen(Qt::white, 1));
-            p.drawPolyline(subline);
-        }
-        else
-        {
-            p.setPen(QPen(Qt::white, 5));
-            p.drawPolyline(subline);
-            p.setPen(QPen(Qt::darkBlue, 3));
-            p.drawPolyline(subline);
-            p.setPen(QPen(Qt::white, 1));
-            p.drawPolyline(subline);
-        }
-
+        p.setPen(QPen(Qt::white, 7));
+        p.drawPolyline(subline);
+        p.setPen(QPen(Qt::red, 5));
+        p.drawPolyline(subline);
+        p.setPen(QPen(Qt::white, 1));
+        p.drawPolyline(subline);
 
         p.setPen(Qt::black);
         for(i = 1; i < (subline.size() - 1); i++)
@@ -760,8 +877,8 @@ void COverlayDistance::draw(QPainter& p)
         if(doFuncWheel)
         {
 
-            p.setPen(QColor(100,100,255,200));
-            p.setBrush(QColor(255,255,255,200));
+            p.setPen(CCanvas::penBorderBlue);
+            p.setBrush(CCanvas::brushBackWhite);
             p.drawEllipse(pt2.u - 35, pt2.v - 35, 70, 70);
 
             p.save();
@@ -783,7 +900,7 @@ void COverlayDistance::draw(QPainter& p)
                 p.setRenderHint(QPainter::SmoothPixmapTransform, true);
                 p.translate(rectAdd1.center());
                 p.rotate(-angleNext + 180);
-                p.drawPixmap(QPoint(-8, -8), QPixmap(":/icons/iconAddPoint16x16.png"));
+                p.drawPixmap(QPoint(-8, -8), QPixmap(":/icons/iconAddPointEnd16x16.png"));
                 p.restore();
             }
 
@@ -802,7 +919,7 @@ void COverlayDistance::draw(QPainter& p)
                 p.setRenderHint(QPainter::SmoothPixmapTransform, true);
                 p.translate(rectAdd2.center());
                 p.rotate(-anglePrev + 180);
-                p.drawPixmap(QPoint(-8, -8), QPixmap(":/icons/iconAddPoint16x16.png"));
+                p.drawPixmap(QPoint(-8, -8), QPixmap(":/icons/iconAddPointEnd16x16.png"));
                 p.restore();
             }
 
@@ -810,8 +927,8 @@ void COverlayDistance::draw(QPainter& p)
         }
         else
         {
-            p.setPen(QColor(100,100,255,200));
-            p.setBrush(QColor(255,255,255,200));
+            p.setPen(CCanvas::penBorderBlue);
+            p.setBrush(CCanvas::brushBackWhite);
             p.drawEllipse(pt2.u - 8, pt2.v - 8, 16, 16);
         }
     }
@@ -859,20 +976,35 @@ void COverlayDistance::calcDistance()
 void COverlayDistance::customMenu(QMenu& menu)
 {
     menu.addAction(QPixmap(":/icons/iconEdit16x16.png"),tr("Edit..."),this,SLOT(slotEdit()));
+    menu.addAction(QPixmap(":/icons/iconReload16x16.png"),tr("Revert"),this,SLOT(slotRevert()));
+    menu.addSeparator();
     menu.addAction(QPixmap(":/icons/iconTrack16x16.png"),tr("Make Track"),this,SLOT(slotToTrack()));
     menu.addAction(QPixmap(":/icons/iconRoute16x16.png"),tr("Make Route"),this,SLOT(slotToRoute()));
-
+    menu.addSeparator();
+    QAction * actShow = menu.addAction(tr("Show"),this,SLOT(slotShow()));
+    actShow->setCheckable(true);
+    actShow->setChecked(isVisible);
+    QAction * actPoints = menu.addAction(tr("Show Bullets"),this,SLOT(slotShowBullets()));
+    actPoints->setCheckable(true);
+    actPoints->setChecked(showBullets);
 }
 
+void COverlayDistance::slotShow()
+{
+    isVisible = !isVisible;
+    emit sigChanged();
+}
+
+void COverlayDistance::slotShowBullets()
+{
+    showBullets = !showBullets;
+    emit sigChanged();
+}
 
 void COverlayDistance::slotToTrack()
 {
     if(points.isEmpty()) return;
 
-    CTrack * track  = new CTrack(&CTrackDB::self());
-
-    track->name = name;
-
     double dist, d, delta = 10.0, a1 , a2;
     XY pt1, pt2, ptx;
     CTrack::pt_t pt;
@@ -884,9 +1016,13 @@ void COverlayDistance::slotToTrack()
         return;
     }
 
+    CTrack * track  = new CTrack(&CTrackDB::self());
+    track->setName(name);
+
     delta   = dlg.getDelta();
     eleMode = dlg.getEleMode();
 
+
     if(delta == -1)
     {
 
@@ -951,6 +1087,10 @@ void COverlayDistance::slotToTrack()
 
     CTrackDB::self().addTrack(track, false);
     CMegaMenu::self().switchByKeyWord("Tracks");
+
+    isVisible = false;
+    emit sigChanged();
+
 }
 
 
@@ -969,12 +1109,14 @@ void COverlayDistance::slotToRoute()
         pt = points[i];
         pt.u = pt.u * RAD_TO_DEG;
         pt.v = pt.v * RAD_TO_DEG;
-        route->addPosition(pt.u, pt.v);
+        route->addPosition(pt.u, pt.v, QString("p%1").arg(i + 1));
     }
 
     CRouteDB::self().addRoute(route, false);
-
     CMegaMenu::self().switchByKeyWord("Routes");
+
+    isVisible = false;
+    emit sigChanged();
 }
 
 
@@ -985,6 +1127,18 @@ void COverlayDistance::slotEdit()
     theMainWindow->setTempWidget(overlayDistanceEditWidget, tr("Overlay"));
 }
 
+void COverlayDistance::slotRevert()
+{
+    QList<pt_t> rev;
+    QList<pt_t> pts = points;
+
+    while(pts.size())
+    {
+        rev << pts.takeLast();
+    }
+
+    COverlayDB::self().addDistance(name + "_rev", comment, speed, rev);
+}
 
 void COverlayDistance::makeVisible()
 {
@@ -1002,6 +1156,9 @@ void COverlayDistance::makeVisible()
         if(pt.v > north) north = pt.v;
     }
     CMapDB::self().getMap().zoom(west, north, east, south);
+
+    isVisible = true;
+    emit sigChanged();
 }
 
 
