@@ -26,27 +26,27 @@
 #include <QtGui>
 
 COverlayText::COverlayText(const QString& text, const QRect& rect, QObject * parent)
-: IOverlay(parent, "Text", QPixmap(":/icons/iconText16x16"))
+: IOverlay(parent, "Text", ":/icons/iconText16x16.png")
 , rect(rect)
 , doMove(false)
 , doSize(false)
 , doSpecialCursor(false)
-, sometext(text)
-
 {
     rectMove = QRect(rect.topLeft()     + QPoint(2,2)  , QSize(16, 16));
     rectEdit = QRect(rect.topLeft()     + QPoint(20,2) , QSize(16, 16));
     rectDel  = QRect(rect.topRight()    - QPoint(18,-2), QSize(16, 16));
     rectSize = QRect(rect.bottomRight() - QPoint(16,16), QSize(16, 16));
 
-    rectDoc  = QRect(rect.topLeft()     + QPoint(5,20)  , rect.size() - QSize(10, 40));
+    rectDoc  = QRect(rect.topLeft()     + QPoint(5,5)  , rect.size() - QSize(10, 10));
 
     rectMouse = rect;
     rectMouse.setTopLeft(rectMouse.topLeft() - QPoint(8,8));
     rectMouse.setBottomRight(rectMouse.bottomRight() + QPoint(8,8));
 
+    comment = text;
+
     doc = new QTextDocument(this);
-    doc->setHtml(sometext);
+    doc->setHtml(comment);
     doc->setPageSize(rectDoc.size());
 
 }
@@ -82,7 +82,7 @@ QString COverlayText::getInfo()
 }
 
 
-void COverlayText::draw(QPainter& p)
+void COverlayText::draw(QPainter& p, const QRect& viewport)
 {
     if(highlight)
     {
@@ -92,15 +92,15 @@ void COverlayText::draw(QPainter& p)
     else
     {
         p.setBrush(Qt::white);
-        p.setPen(Qt::black);
+        p.setPen(QPen(Qt::darkGray,2));
     }
-    p.drawRect(rect);
+    PAINT_ROUNDED_RECT(p,rect);
 
     if(selected == this)
     {
         p.setBrush(Qt::white);
-        p.setPen(QPen(Qt::red, 2));
-        p.drawRect(rect);
+        p.setPen(QPen(Qt::red, 3));
+        PAINT_ROUNDED_RECT(p,rect);
 
         p.drawPixmap(rectMove, QPixmap(":/icons/iconMoveMap16x16.png"));
         p.drawPixmap(rectSize, QPixmap(":/icons/iconSize16x16.png"));
@@ -130,7 +130,7 @@ void COverlayText::mouseMoveEvent(QMouseEvent * e)
         rectMouse.setTopLeft(rectMouse.topLeft() - QPoint(8,8));
         rectMouse.setBottomRight(rectMouse.bottomRight() + QPoint(8,8));
 
-        rectDoc  = QRect(rect.topLeft()     + QPoint(5,20)  , rect.size() - QSize(10, 40));
+        rectDoc     = QRect(rect.topLeft()     + QPoint(5,5)  , rect.size() - QSize(10, 10));
         doc->setPageSize(rectDoc.size());
 
         theMainWindow->getCanvas()->update();
@@ -147,7 +147,7 @@ void COverlayText::mouseMoveEvent(QMouseEvent * e)
         rectMouse.setTopLeft(rectMouse.topLeft() - QPoint(8,8));
         rectMouse.setBottomRight(rectMouse.bottomRight() + QPoint(8,8));
 
-        rectDoc  = QRect(rect.topLeft()     + QPoint(5,20)  , rect.size() - QSize(10, 40));
+        rectDoc     = QRect(rect.topLeft()     + QPoint(5,5)  , rect.size() - QSize(10, 10));
         doc->setPageSize(rectDoc.size());
 
         theMainWindow->getCanvas()->update();
@@ -183,18 +183,19 @@ void COverlayText::mousePressEvent(QMouseEvent * e)
     }
     else if(rectEdit.contains(e->pos()))
     {
-        CDlgEditText dlg(sometext, theMainWindow->getCanvas());
+        CDlgEditText dlg(comment, theMainWindow->getCanvas());
         dlg.exec();
-        doc->setHtml(sometext);
+        doc->setHtml(comment);
         theMainWindow->getCanvas()->update();
         emit sigChanged();
     }
     else if(rectDel.contains(e->pos()))
     {
-        QStringList keys(key());
+        QStringList keys(getKey());
         COverlayDB::self().delOverlays(keys);
         QApplication::restoreOverrideCursor();
         doSpecialCursor = false;
+        theMainWindow->getCanvas()->setMouseMode(CCanvas::eMouseMoveArea);
     }
 }
 
@@ -211,11 +212,13 @@ void COverlayText::mouseReleaseEvent(QMouseEvent * e)
 
 void COverlayText::save(QDataStream& s)
 {
-    s << rect << sometext << _key_;
+    s << rect << comment << getKey();
 }
 
 
 void COverlayText::load(QDataStream& s)
 {
-    s >> rect >> sometext >> _key_;
+    QString key;
+    s >> rect >> comment >> key;
+    setKey(key);
 }
