@@ -20,10 +20,15 @@
 #include "CPlot.h"
 #include "CPlotAxis.h"
 #include "CResources.h"
+#include "CCanvas.h"
+
+#include "config.h"
+#include "CTrackDB.h"
+#include "CTrack.h"
 
 #include <QtGui>
 
-CPlot::CPlot(CPlotData::axis_type_e type, QWidget * parent)
+CPlot::CPlot(CPlotData::axis_type_e type, mode_e mode, QWidget * parent)
 : QWidget(parent)
 , fontWidth(0)
 , fontHeight(0)
@@ -36,8 +41,24 @@ CPlot::CPlot(CPlotData::axis_type_e type, QWidget * parent)
 , fm(QFont())
 , initialYMax(0)
 , initialYMin(0)
+, mode(mode)
+, showScale(true)
+, thinLine(false)
+, cursorFocus(false)
+, posMouse(-1,-1)
 {
+    if(mode == eIcon)
+    {
+        setMouseTracking(true);
+    }
     setSizePolicy(QSizePolicy::MinimumExpanding,QSizePolicy::MinimumExpanding);
+
+    if(mode == eIcon)
+    {
+        showScale = false;
+        thinLine = true;
+    }
+
     m_pData = new CPlotData(type, this);
     createActions();
 }
@@ -150,7 +171,7 @@ void CPlot::addTag(CPlotData::point_t& tag)
 void CPlot::paintEvent(QPaintEvent * )
 {
     QPainter p(this);
-    p.setRenderHint(QPainter::Antialiasing, true);
+    USE_ANTI_ALIASING(p, true);
     draw(p);
 }
 
@@ -171,8 +192,8 @@ void CPlot::setSizes()
     fm = QFontMetrics(CResources::self().getMapFont());
     left = 0;
 
-    scaleWidthX1    = m_pData->x().getScaleWidth( fm );
-    scaleWidthY1    = m_pData->y().getScaleWidth( fm );
+    scaleWidthX1    = showScale ? m_pData->x().getScaleWidth( fm ) : 0;
+    scaleWidthY1    = showScale ? m_pData->y().getScaleWidth( fm ) : 0;
 
     scaleWidthY1    = scaleWidthX1 > scaleWidthY1 ? scaleWidthX1 : scaleWidthY1;
 
@@ -213,8 +234,16 @@ void CPlot::setLRTB()
     bottom = size().height();
     bottom -= m_pData->xlabel.isEmpty() ? 0 : fontHeight;
     // tick marks
-    bottom -= fontHeight;
+    if(scaleWidthX1)
+    {
+        bottom -= fontHeight;
+    }
     bottom -= deadAreaY;
+
+    if(!m_pData->xlabel.isEmpty())
+    {
+        bottom -= deadAreaY;
+    }
 }
 
 
@@ -241,7 +270,7 @@ void CPlot::setSizeXLabel()
     {
         rectX1Label.setWidth( right - left );
         rectX1Label.setHeight( fontHeight );
-        y = ( size().height() - rectX1Label.height());
+        y = ( size().height() - rectX1Label.height()) - deadAreaY;
         rectX1Label.moveTopLeft( QPoint( left, y ) );
     }
 }
@@ -283,7 +312,29 @@ void CPlot::setSizeDrawArea()
 
 void CPlot::draw(QPainter& p)
 {
-    p.fillRect(rect(),Qt::white);
+    if(mode == eNormal)
+    {
+        p.fillRect(rect(),Qt::white);
+    }
+    else if(mode == eIcon)
+    {
+        QRect r = rect();
+        r.adjust(2,2,-2,-2);
+        if(cursorFocus)
+        {
+            p.setPen(CCanvas::penBorderBlue);
+            p.setBrush(QColor(255,255,255,255));
+        }
+        else
+        {
+            p.setPen(CCanvas::penBorderBlack);
+            p.setBrush(QColor(255,255,255,150));
+        }
+
+
+        PAINT_ROUNDED_RECT(p,r);
+
+    }
 
     if(m_pData->lines.isEmpty() || m_pData->badData)
     {
@@ -297,8 +348,11 @@ void CPlot::draw(QPainter& p)
     drawData(p);
     p.setClipping(false);
     drawLabels(p);
-    drawXScale(p);
-    drawYScale(p);
+    if(showScale)
+    {
+        drawXScale(p);
+        drawYScale(p);
+    }
     drawGridX(p);
     drawGridY(p);
     drawXTic(p);
@@ -309,6 +363,17 @@ void CPlot::draw(QPainter& p)
 
     drawLegend(p);
 
+    if(mode == eIcon)
+    {
+        int x = posMouse.x();
+        if(x != -1)
+        {
+            p.setPen(QPen(Qt::red,2));
+            p.drawLine(x, rectGraphArea.top(), x, rectGraphArea.bottom());
+        }
+
+    }
+
 }
 
 
@@ -520,6 +585,15 @@ QPen pens[] =
 
 };
 
+QPen pensThin[] =
+{
+    QPen(Qt::blue,2)
+    , QPen(Qt::red,1)
+    , QPen(Qt::darkYellow,1)
+    , QPen(Qt::darkGreen,1)
+
+};
+
 QColor colors[] =
 {
     QColor(0,0,255)
@@ -577,7 +651,7 @@ void CPlot::drawData(QPainter& p)
         p.setBrush(gradient);
         p.drawPolygon(background);
 
-        p.setPen(pens[penIdx++]);
+        p.setPen(thinLine ? pensThin[penIdx++] : pens[penIdx++]);
         p.setBrush(Qt::NoBrush);
         p.drawPolyline(foreground);
 
@@ -587,7 +661,7 @@ void CPlot::drawData(QPainter& p)
     {
         QPolygonF& marks                = m_pData->marks.points;
         QPolygonF::const_iterator point = marks.begin();
-        p.setPen(QPen(Qt::red,2));
+        p.setPen(QPen(Qt::darkRed,2));
 
         while(point != marks.end())
         {
@@ -603,7 +677,7 @@ void CPlot::drawData(QPainter& p)
 
     if(!m_pData->point1.point.isNull())
     {
-        p.setPen(QPen(Qt::darkGreen));
+        p.setPen(QPen(Qt::red,2));
         ptx = left   + xaxis.val2pt( m_pData->point1.point.x() );
         pty = bottom - yaxis.val2pt( m_pData->point1.point.y() );
 
@@ -651,6 +725,7 @@ void CPlot::drawTags(QPainter& p)
     CPlotAxis& yaxis = m_pData->y();
 
     QFontMetrics fm(p.font());
+    QColor textColor = CResources::self().wptTextColor();
 
     QVector<CPlotData::point_t>::const_iterator tag = m_pData->tags.begin();
     while(tag != m_pData->tags.end())
@@ -662,10 +737,13 @@ void CPlot::drawTags(QPainter& p)
         {
             rect = fm.boundingRect(tag->label);
             rect.moveCenter(QPoint(ptx, fontHeight / 2));
-            p.setPen(Qt::darkBlue);
+            rect.adjust(-1,-1,1,1);
+
+            p.setPen(textColor);
             p.drawText(rect, Qt::AlignCenter, tag->label);
 
-            p.drawPixmap(ptx - tag->icon.width() / 2, fontHeight, tag->icon);
+            QPixmap icon = tag->icon.scaled(15,15, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+            p.drawPixmap(ptx - icon.width() / 2, fontHeight, icon);
 
             p.setPen(QPen(Qt::white, 3));
             if (fontHeight + 16 < pty)
@@ -687,6 +765,10 @@ void CPlot::drawTags(QPainter& p)
 
 void CPlot::contextMenuEvent(QContextMenuEvent *event)
 {
+    if(mode != eNormal)
+    {
+        return ;
+    }
     QMenu menu(this);
     menu.addAction(hZoomAct);
     menu.addAction(vZoomAct);
@@ -733,20 +815,27 @@ void CPlot::slotSave()
 
     QSettings cfg;
     QString pathData = cfg.value("path/data","./").toString();
+    QString filter   = cfg.value("trackstat/imagetype","Bitmap (*.png)").toString();
+
 
-    QString filter;
     QString filename = QFileDialog::getSaveFileName( 0, tr("Select output file")
         ,pathData
-        ,"Bitmap (*.png *.jpg *.jpeg);;"
+        ,"Bitmap (*.png)"
         ,&filter
-        , QFileDialog::DontUseNativeDialog
+        , FILE_DIALOG_FLAGS
         );
 
     if(filename.isEmpty()) return;
 
+    QFileInfo fi(filename);
+    if(fi.suffix().toLower() != "png")
+    {
+        filename += ".png";
+    }
+
     QImage img(size(), QImage::Format_ARGB32);
     QPainter p;
-    p.setRenderHint(QPainter::Antialiasing, true);
+    USE_ANTI_ALIASING(p, true);
 
     p.begin(&img);
     p.fillRect(rect(), QBrush(Qt::white));
@@ -754,6 +843,11 @@ void CPlot::slotSave()
     p.end();
 
     img.save(filename);
+
+    pathData = fi.absolutePath();
+    cfg.setValue("path/data", pathData);
+    cfg.setValue("trackstat/imagetype", filter);
+
 }
 
 
@@ -779,40 +873,104 @@ void CPlot::wheelEvent ( QWheelEvent * e )
 
 void CPlot::mouseMoveEvent(QMouseEvent * e)
 {
-    checkClick = false;
+    if(mode == eIcon)
+    {
+        posMouse = QPoint(-1,-1);
+        CTrack * trk = CTrackDB::self().highlightedTrack();
+        if(trk == 0)
+        {
+            return;
+        }
 
-    CPlotAxis &xaxis = m_pData->x();
-    xaxis.move(startMovePos.x() - e->pos().x());
+        QPoint pos = e->pos();
+        double dist = getXValByPixel(pos.x());
 
-    CPlotAxis &yaxis = m_pData->y();
-    yaxis.move(e->pos().y() - startMovePos.y());
+        if(dist < 0 || dist > trk->getTotalDistance())
+        {
+            return;
+        }
 
-    startMovePos = e->pos();
+        posMouse = e->pos();
+
+        emit activePointSignal(dist);
+
+
+    }
+    else{
+        checkClick = false;
+
+        CPlotAxis &xaxis = m_pData->x();
+        xaxis.move(startMovePos.x() - e->pos().x());
+
+        CPlotAxis &yaxis = m_pData->y();
+        yaxis.move(e->pos().y() - startMovePos.y());
+
+        startMovePos = e->pos();
+    }
     update();
 }
 
 
 void CPlot::mouseReleaseEvent(QMouseEvent * e)
 {
-    if (e->button() == Qt::LeftButton)
+    if(mode == eNormal)
     {
-        QApplication::restoreOverrideCursor();
+        if (e->button() == Qt::LeftButton)
+        {
+            QApplication::restoreOverrideCursor();
+        }
+        if (checkClick && e->button() == Qt::LeftButton)
+        {
+            QPoint pos = e->pos();
+            double dist = getXValByPixel(pos.x());
+            emit activePointSignal(dist);
+        }
     }
-    if (checkClick && e->button() == Qt::LeftButton)
+    else
     {
-        QPoint pos = e->pos();
-        double dist = getXValByPixel(pos.x());
-        emit activePointSignal(dist);
+        emit sigClicked();
     }
 }
 
 
 void CPlot::mousePressEvent(QMouseEvent * e)
 {
-    if (e->button() == Qt::LeftButton)
+    if(mode == eNormal)
     {
-        QApplication::setOverrideCursor(QCursor(QPixmap(":/cursors/cursorMove")));
-        startMovePos = e->pos();
-        checkClick = true;
+        if (e->button() == Qt::LeftButton)
+        {
+            QApplication::setOverrideCursor(QCursor(QPixmap(":/cursors/cursorMove.png")));
+            startMovePos = e->pos();
+            checkClick = true;
+        }
     }
+
+}
+
+void CPlot::leaveEvent(QEvent * event)
+{
+    cursorFocus = false;
+    posMouse = QPoint(-1, -1);
+    QApplication::restoreOverrideCursor();
+    update();
+}
+
+void CPlot::enterEvent(QEvent * event)
+{
+    cursorFocus = true;
+    QApplication::setOverrideCursor(Qt::PointingHandCursor);
+    update();
+}
+
+void CPlot::slotTrkPt(CTrack::pt_t * pt)
+{
+    if(pt == 0)
+    {
+        posMouse = QPoint(-1,-1);
+        return;
+    }
+    int x = m_pData->x().val2pt(pt->distance);
+    int y = m_pData->y().val2pt(pt->altitude);
+    posMouse = QPoint(x, y);
+    update();
 }
