@@ -23,14 +23,21 @@
 #include <QWidget>
 
 #include "CPlotData.h"
+#include "CTrack.h"
 
 class CPlot : public QWidget
 {
     Q_OBJECT
         public:
-        CPlot(CPlotData::axis_type_e type, QWidget * parent);
+
+        enum mode_e {eNormal, eIcon};
+
+        CPlot(CPlotData::axis_type_e type, mode_e mode, QWidget * parent);
         virtual ~CPlot();
 
+
+        void setShowScale(bool show){showScale = show;}
+        void setThinLine(bool thin){thinLine = thin;}
         void setYLabel(const QString& str);
         void setXLabel(const QString& str);
 
@@ -44,8 +51,15 @@ class CPlot : public QWidget
 
         double getXValByPixel(int px);
 
-        signals:
+        void draw(QPainter& p);
+
+    signals:
         void activePointSignal(double dist);
+        void sigClicked();
+
+    public slots:
+        void slotTrkPt(CTrack::pt_t * pt);
+
 
     protected slots:
         void slotSave();
@@ -58,9 +72,10 @@ class CPlot : public QWidget
         void wheelEvent ( QWheelEvent * e );
         void paintEvent(QPaintEvent * e);
         void resizeEvent(QResizeEvent * e);
+        void leaveEvent(QEvent * event);
+        void enterEvent(QEvent * event);
 
         /// draw the actual plot
-        void draw(QPainter& p);
         void drawLabels(QPainter& p);
         void drawXScale(QPainter& p);
         void drawYScale(QPainter& p);
@@ -117,6 +132,15 @@ class CPlot : public QWidget
 
         double initialYMax;
         double initialYMin;
+
+        mode_e mode;
+        bool showScale;
+        bool thinLine;
+
+        bool cursorFocus;
+
+        QPoint posMouse;
+
     public slots:
         void resetZoom();
 };
