@@ -20,7 +20,9 @@
 #include "CResources.h"
 #include "CDeviceGarmin.h"
 #include "CDeviceQLandkarteM.h"
+#ifdef HS_MIKROKOPTER
 #include "CDeviceMikrokopter.h"
+#endif
 #include "CDeviceNMEA.h"
 #ifdef HAS_GPSD
 #include "CDeviceGPSD.h"
@@ -30,6 +32,7 @@
 #include "CUnitNautic.h"
 #include "CUnitImperial.h"
 #include "CMapTDB.h"
+#include "config.h"
 
 #include <QtGui>
 
@@ -40,17 +43,29 @@ CResources::CResources(QObject * parent)
 , pathMaps("./")
 , m_useHttpProxy(false)
 , m_httpProxyPort(8080)
-, m_eBrowser(eFirefox)
-#ifdef WIN32
-, cmdFirefox("start firefox \"%s\"")
-#else
-, cmdFirefox("firefox \"%s\" &")
-#endif
-, cmdKonqueror("kfmclient exec \"%s\"")
 , time_offset(0)
 , m_device(0)
 , m_devIPPort(4242)
 , m_flipMouseWheel(false)
+#ifdef HAS_GEODB
+, m_useGeoDB(true)
+, m_saveGeoDBOnExit(false)
+#ifndef Q_WS_MAC
+, m_pathGeoDB(QDir::homePath())
+#else
+, m_pathGeoDB(QDir::home().filePath(CONFIGDIR))
+#endif
+#endif
+, m_showTrackProfile(true)
+, m_showNorth(true)
+, m_showScale(true)
+, m_showToolTip(true)
+, m_showTrackMax(true)
+, m_showZoomLevel(true)
+, m_useAntiAliasing(true)
+, m_reducePoiIcons(true)
+, m_WptTextColor(Qt::black)
+
 {
     m_self = this;
 
@@ -66,20 +81,23 @@ CResources::CResources(QObject * parent)
 
     //m_doMetric        = cfg.value("environment/doMetric",true).toBool();
     m_flipMouseWheel  = cfg.value("environment/flipMouseWheel",m_flipMouseWheel).toBool();
+#ifdef HAS_GEODB
+    m_useGeoDB  = cfg.value("environment/GeoDB",m_useGeoDB).toBool();
+    m_saveGeoDBOnExit  = cfg.value("environment/saveGeoDBOnExit",m_saveGeoDBOnExit).toBool();
+    m_pathGeoDB = QDir(cfg.value("environment/pathGeoDB", m_pathGeoDB.absolutePath()).toString());
+#endif
 
     m_useHttpProxy    = cfg.value("network/useProxy",m_useHttpProxy).toBool();
     m_httpProxy       = cfg.value("network/proxy/url",m_httpProxy).toString();
     m_httpProxyPort   = cfg.value("network/proxy/port",m_httpProxyPort).toUInt();
 
-    m_eBrowser        = (browser_e)cfg.value("network/browser",m_eBrowser).toInt();
-    cmdOther          = cfg.value("network/browser/other","my command \"%s\"").toString();
-
     emit sigProxyChanged();
 
     m_devKey          = cfg.value("device/key",m_devKey).toString();
     m_devIPAddress    = cfg.value("device/ipAddr",m_devIPAddress).toString();
     m_devIPPort       = cfg.value("device/ipPort",m_devIPPort).toUInt();
     m_devSerialPort   = cfg.value("device/serialPort",m_devSerialPort).toString();
+    m_devBaudRate     = cfg.value("device/baudRate",m_devBaudRate).toString();
     m_devType         = cfg.value("device/type",m_devType).toString();
     m_devCharset      = cfg.value("device/charset",m_devCharset).toString();
 
@@ -111,6 +129,32 @@ CResources::CResources(QObject * parent)
         qWarning("Unknown unit type. Using 'metric'");
         unit = new CUnitMetric(this);
     }
+
+    m_showTrackProfile  = cfg.value("environment/showTrackProfile",m_showTrackProfile).toBool();
+    m_showNorth     = cfg.value("environment/showNorth",m_showNorth).toBool();
+    m_showScale     = cfg.value("environment/showScale",m_showScale).toBool();
+    m_showToolTip   = cfg.value("environment/showToolTip",m_showToolTip).toBool();
+    m_showTrackMax  = cfg.value("environment/showTrackMax",m_showTrackMax).toBool();
+    m_showZoomLevel = cfg.value("environment/showZoomLevel",m_showZoomLevel).toBool();
+    m_useAntiAliasing = cfg.value("environment/useAntiAliasing",m_useAntiAliasing).toBool();
+    m_reducePoiIcons = cfg.value("environment/reducePoiIcons",m_reducePoiIcons).toBool();
+
+    m_WptTextColor = QColor(cfg.value("environment/wptTextColor", m_WptTextColor.name()).toString());
+
+    QDir dirWeb(QDir::home().filePath(CONFIGDIR));
+    dirWeb.mkdir("WebStuff");
+    dirWeb.cd("WebStuff");
+
+    QPixmap(":/webstuff/frame_top.png").save(dirWeb.filePath("frame_top.png"));
+    QPixmap(":/webstuff/frame_bottom.png").save(dirWeb.filePath("frame_bottom.png"));
+    QPixmap(":/webstuff/frame_left.png").save(dirWeb.filePath("frame_left.png"));
+    QPixmap(":/webstuff/frame_right.png").save(dirWeb.filePath("frame_right.png"));
+    QPixmap(":/webstuff/frame_top_left.png").save(dirWeb.filePath("frame_top_left.png"));
+    QPixmap(":/webstuff/frame_top_right.png").save(dirWeb.filePath("frame_top_right.png"));
+    QPixmap(":/webstuff/frame_bottom_left.png").save(dirWeb.filePath("frame_bottom_left.png"));
+    QPixmap(":/webstuff/frame_bottom_right.png").save(dirWeb.filePath("frame_bottom_right.png"));
+    QPixmap(":/webstuff/scale.png").save(dirWeb.filePath("scale.png"));
+
 }
 
 
@@ -124,19 +168,21 @@ CResources::~CResources()
     cfg.setValue("environment/mapfont/italic",m_mapfont.italic());
 
     cfg.setValue("environment/flipMouseWheel",m_flipMouseWheel);
-
+#ifdef HAS_GEODB
+    cfg.setValue("environment/GeoDB",m_useGeoDB);
+    cfg.setValue("environment/saveGeoDBOnExit",m_saveGeoDBOnExit);
+    cfg.setValue("environment/pathGeoDB",m_pathGeoDB.absolutePath());
+#endif
     cfg.setValue("network/useProxy",m_useHttpProxy);
     cfg.setValue("network/proxy/url",m_httpProxy);
     cfg.setValue("network/proxy/port",m_httpProxyPort);
 
-    cfg.setValue("network/browser",m_eBrowser);
-    cfg.setValue("network/browser/other",cmdOther);
 
     cfg.setValue("device/key",m_devKey);
     cfg.setValue("device/ipAddr",m_devIPAddress);
     cfg.setValue("device/ipPort",m_devIPPort);
     cfg.setValue("device/serialPort",m_devSerialPort);
-    cfg.setValue("device/serialPort",m_devSerialPort);
+    cfg.setValue("device/baudRate",m_devBaudRate);
     cfg.setValue("device/type",m_devType);
     cfg.setValue("device/charset",m_devCharset);
 
@@ -149,6 +195,16 @@ CResources::~CResources()
     cfg.setValue("device/playSound",m_playSound);
 
     cfg.setValue("environment/unittype",unit->type);
+    cfg.setValue("environment/showTrackProfile",m_showTrackProfile);
+    cfg.setValue("environment/showNorth",m_showNorth);
+    cfg.setValue("environment/showScale",m_showScale);
+    cfg.setValue("environment/showToolTip",m_showToolTip);
+    cfg.setValue("environment/showTrackMax",m_showTrackMax);
+    cfg.setValue("environment/showZoomLevel",m_showZoomLevel);
+    cfg.setValue("environment/useAntiAliasing",m_useAntiAliasing);
+    cfg.setValue("environment/reducePoiIcons",m_reducePoiIcons);
+
+    cfg.setValue("environment/wptTextColor", m_WptTextColor.name());
 }
 
 
@@ -195,17 +251,19 @@ IDevice * CResources::device()
             //m_device = new CDeviceTBDOE(m_devIPAddress,m_devIPPort,this);
             m_device = new CDeviceQLandkarteM(m_devIPAddress,m_devIPPort,this);
         }
+#ifdef HS_MIKROKOPTER
         if(m_devKey == "Mikrokopter")
         {
             m_device = new CDeviceMikrokopter(m_devSerialPort, this);
         }
+#endif
         else if(m_devKey == "Garmin" && !m_devType.isEmpty())
         {
             m_device = new CDeviceGarmin(m_devType, m_devSerialPort, this);
         }
         else if(m_devKey == "NMEA")
         {
-            m_device = new CDeviceNMEA(m_devSerialPort, this);
+            m_device = new CDeviceNMEA(m_devSerialPort, m_devBaudRate, this);
         }
 #ifdef HAS_GPSD
         else if(m_devKey == "GPSD")
@@ -238,26 +296,3 @@ QString CResources::charset()
 }
 
 
-void CResources::openLink(const QString& link)
-{
-    QString cmd;
-    if(m_eBrowser == eFirefox)
-    {
-        cmd.sprintf(cmdFirefox.toAscii(),link.toAscii().data());
-    }
-    else if(m_eBrowser == eKonqueror)
-    {
-        cmd.sprintf(cmdKonqueror.toAscii(),link.toAscii().data());
-    }
-    else if(m_eBrowser == eOther)
-    {
-        cmd.sprintf(cmdOther.toAscii(),link.toAscii().data());
-    }
-    else
-    {
-        return;
-    }
-
-    system(cmd.toAscii());
-
-}
