@@ -22,6 +22,8 @@
 #include <QObject>
 #include <QFont>
 #include <QPointer>
+#include <QDir>
+#include <QColor>
 
 class IDevice;
 class IUnit;
@@ -51,14 +53,27 @@ class CResources : public QObject
         /// the font used for text on the map
         const QFont& getMapFont(){return m_mapfont;}
 
-        /// open an URL in a webbrowser
-        void openLink(const QString& link);
 
         /// root path of all maps
         QString pathMaps;
 
+#ifdef HAS_GEODB
+        bool useGeoDB(){return m_useGeoDB;}
+        bool saveGeoDBOnExit(){return m_saveGeoDBOnExit;}
+        QDir pathGeoDB(){return m_pathGeoDB;}
+#endif
         bool flipMouseWheel(){return m_flipMouseWheel;}
+        bool showTrackProfilePreview(){return m_showTrackProfile;}
+        bool showNorthIndicator(){return m_showNorth;}
+        bool showScale(){return m_showScale;}
+        bool showToolTip(){return m_showToolTip;}
+        bool showTrackMax(){return m_showTrackMax;}
+        bool showZoomLevel(){return m_showZoomLevel;}
         bool playSound(){return m_playSound;}
+        bool useAntiAliasing(){return m_useAntiAliasing;}
+        bool reducePoiIcons(){return m_reducePoiIcons;}
+
+        QColor wptTextColor(){return m_WptTextColor;}
 
         signals:
         void sigProxyChanged();
@@ -88,14 +103,6 @@ class CResources : public QObject
         /// font used by the map
         QFont m_mapfont;
 
-        /// the installed browser type
-        browser_e m_eBrowser;
-        /// command string to start Firefox
-        QString cmdFirefox;
-        /// command string to start Konqueror
-        QString cmdKonqueror;
-        /// user defined command string
-        QString cmdOther;
 
         /// this offset is needed to correct time in seconds until Dec. 30th, 1989 12:00 to POSIX standard
         quint32 time_offset;
@@ -112,6 +119,7 @@ class CResources : public QObject
         QString m_devIPAddress;
         quint16 m_devIPPort;
         QString m_devSerialPort;
+        QString m_devBaudRate;
 
         QString m_devType;
         QString m_devCharset;
@@ -122,6 +130,24 @@ class CResources : public QObject
         /// play sound after finishing transfers
         bool m_playSound;
 
+#ifdef HAS_GEODB
+        bool m_useGeoDB;
+        bool m_saveGeoDBOnExit;
+        QDir m_pathGeoDB;
+#endif
+
+
+        bool m_showTrackProfile;
+        bool m_showNorth;
+        bool m_showScale;
+        bool m_showToolTip;
+        bool m_showTrackMax;
+        bool m_showZoomLevel;
+        bool m_useAntiAliasing;
+        bool m_reducePoiIcons;
+
+        QColor m_WptTextColor;
+
         /// unit translator object
         QPointer<IUnit> unit;
 };
