@@ -19,6 +19,8 @@
 #ifndef CROUTE_H
 #define CROUTE_H
 
+#include "IItem.h"
+
 #include <QObject>
 #include <QPixmap>
 #include <QList>
@@ -27,29 +29,32 @@
 #include <QFile>
 #include <projects.h>
 
-class CRoute : public QObject
+class QDomDocument;
+
+class CRoute : public IItem
 {
     Q_OBJECT;
     public:
         CRoute(QObject * parent);
         virtual ~CRoute();
 
-        enum type_e {eEnd, eBase, eRtePts};
+        enum type_e {eEnd, eBase, eRtePts, eRteSec};
+        struct pt_t
+        {
+            float lon;
+            float lat;
 
-        /// set route name
-        void setName(const QString& n){name = n; emit sigChanged();}
-        /// get route name
-        const QString& getName(){return name;}
-        /// get unique track key
-        const QString& key();
+            QString action;
 
-        double getDistance(){return dist;}
+            operator const XY ()
+            {
+                XY p;
+                p.u = lon;
+                p.v = lat;
+                return p;
+            }
+        };
 
-        const QPixmap& getIcon(){return icon;}
-
-        const QString& getIconName(){return iconname;}
-
-        void setIcon(const QString& symname);
 
         /// set the highlight flag
         void setHighlight(bool yes){highlight = yes;}
@@ -60,14 +65,35 @@ class CRoute : public QObject
             @param lon the longitude in degree
             @param lat the latitude in degree
         */
-        void addPosition(const double lon, const double lat);
+        void addPosition(const double lon, const double lat, const QString& action);
 
         QPolygon& getPolyline(){return polyline;}
+        QPolygon& getPoints(){return points;}
 
-        QList<XY>& getRoutePoints(){return routeDegree;}
+
+        QVector<pt_t>& getPriRtePoints(){return priRoute;}
+        QVector<pt_t>& getSecRtePoints(){return secRoute;}
 
         QRectF getBoundingRectF();
 
+        /// get a summary of item's data to display on screen or in the toolview
+        QString getInfo();
+
+        double getDistance(){return dist;}
+
+        /// set the icon defined by a string
+        void setIcon(const QString& str);
+
+        QPixmap getIcon();
+
+        void loadSecondaryRoute(QDomDocument& xml);
+
+        void reset();
+
+        quint32 getTime(){return ttime;}
+
+        void setCalcPending(){calcRoutePending = true;}
+
         signals:
         void sigChanged();
 
@@ -76,35 +102,30 @@ class CRoute : public QObject
         friend QDataStream& operator >>(QDataStream& s, CRoute& route);
         friend QDataStream& operator <<(QDataStream& s, CRoute& route);
 
-        void genKey();
         void calcDistance();
 
-        static quint32 keycnt;
-
-        /// unique key to address tarck
-        QString _key_;
-        /// creation timestamp
-        quint32 timestamp;
-
-        /// route name (used as lookup key, too)
-        QString name;
-        /// the route as position points
-        QList<XY> routeDegree;
+        /// primary route, just the basic points like A to B via C
+        QVector<pt_t> priRoute;
         /// the actual route distance
         double dist;
 
-        QString iconname;
-
-        /// the icon used to draw a route
-        QPixmap icon;
+        quint32 ttime;
 
         bool highlight;
 
         /// the Qt polyline for faster processing
         QPolygon polyline;
 
+        QPolygon points;
+
         bool firstTime;
 
+        /// secondary route with all intermediate points from auto routing
+        QVector<pt_t> secRoute;
+
+
+        bool calcRoutePending;
+
 };
 
 QDataStream& operator >>(QDataStream& s, CRoute& route);
