@@ -31,12 +31,20 @@
 
 CRouteDB * CRouteDB::m_self = 0;
 
-bool CRouteDB::keyLessThanAlpha(CRouteDB::keys_t&  s1, CRouteDB::keys_t&  s2)
+bool CRouteDB::keyLessThanAlpha(keys_t&  s1, keys_t&  s2)
 {
+    qDebug() << s1.name << s2.name;
     return s1.name.toLower() < s2.name.toLower();
 }
 
 
+bool CRouteDB::keyLessThanTime(keys_t&  s1, keys_t&  s2)
+{
+    qDebug() << s1.time << s2.time;
+    return s1.time < s2.time;
+}
+
+
 CRouteDB::CRouteDB(QTabWidget * tb, QObject * parent)
 : IDB(tb, parent)
 , cnt(0)
@@ -59,8 +67,8 @@ void CRouteDB::addRoute(CRoute * route, bool silent)
         route->setName(tr("Route%1").arg(cnt++));
     }
 
-    delRoute(route->key(), silent);
-    routes[route->key()] = route;
+    delRoute(route->getKey(), silent);
+    routes[route->getKey()] = route;
 
     connect(route,SIGNAL(sigChanged()),SIGNAL(sigChanged()));
     if(!silent)
@@ -75,7 +83,8 @@ void CRouteDB::addRoute(CRoute * route, bool silent)
 void CRouteDB::delRoute(const QString& key, bool silent)
 {
     if(!routes.contains(key)) return;
-    delete routes.take(key);
+    CRoute * rte = routes.take(key);
+    rte->deleteLater();
     if(!silent)
     {
         emit sigChanged();
@@ -89,15 +98,17 @@ void CRouteDB::delRoutes(const QStringList& keys)
     QString key;
     foreach(key,keys)
     {
-        if(!routes.contains(key)) continue;
-        delete routes.take(key);
+        delRoute(key, true);
+    }
+    if(!keys.isEmpty())
+    {
+        emit sigChanged();
+        emit sigModified();
     }
-    emit sigChanged();
-    emit sigModified();
 }
 
 
-CRoute * CRouteDB::getRoute(const QString& key)
+CRoute * CRouteDB::getRouteByKey(const QString& key)
 {
     if(routes.contains(key))
     {
@@ -122,9 +133,10 @@ void CRouteDB::highlightRoute(const QString& key)
     if(routes.contains(key))
     {
         routes[key]->setHighlight(true);
+        emit sigHighlightRoute(routes[key]);
+
     }
 
-    emit sigHighlightRoute(routes[key]);
     emit sigChanged();
 
 }
@@ -157,10 +169,12 @@ QRectF CRouteDB::getBoundingRectF(const QString key)
 /// load database data from gpx
 void CRouteDB::loadGPX(CGpx& gpx)
 {
+    bool hasItems = false;
     const QDomNodeList& rtes = gpx.elementsByTagName("rte");
     uint N = rtes.count();
     for(uint n = 0; n < N; ++n)
     {
+        hasItems = true;
         const QDomNode& rte = rtes.item(n);
 
         CRoute * r = 0;
@@ -185,17 +199,30 @@ void CRouteDB::loadGPX(CGpx& gpx)
             }
         }
 
+        if(rte.namedItem("parent").isElement())
+        {
+            r->setParentWpt(rte.namedItem("parent").toElement().text());
+        }
+
+
         QDomElement rtept = rte.firstChildElement("rtept");
 
         while (!rtept.isNull())
         {
+            QString name;
             XY pt;
             QDomNamedNodeMap attr = rtept.attributes();
 
+            if(rtept.namedItem("name").isElement())
+            {
+                name = rtept.namedItem("name").toElement().text();
+            }
+
             pt.u = attr.namedItem("lon").nodeValue().toDouble();
             pt.v = attr.namedItem("lat").nodeValue().toDouble();
 
-            r->addPosition(pt.u,pt.v);
+            r->addPosition(pt.u,pt.v, name);
+
 
             if(rtept.namedItem("sym").isElement())
             {
@@ -206,19 +233,22 @@ void CRouteDB::loadGPX(CGpx& gpx)
             rtept = rtept.nextSiblingElement("rtept");
         }
 
-        if(routes.contains(r->key()))
+        if(routes.contains(r->getKey()))
         {
-            delete routes.take(r->key());
+            delete routes.take(r->getKey());
         }
 
         r->calcDistance();
-        routes[r->key()] = r;
+        routes[r->getKey()] = r;
 
         connect(r,SIGNAL(sigChanged()),SIGNAL(sigChanged()));
 
     }
 
-    emit sigChanged();
+    if(hasItems)
+    {
+        emit sigChanged();
+    }
 }
 
 
@@ -229,7 +259,7 @@ void CRouteDB::saveGPX(CGpx& gpx, const QStringList& keys)
     QMap<QString,CRoute*>::iterator route = routes.begin();
     while(route != routes.end())
     {
-        if(!keys.isEmpty() && !keys.contains((*route)->key()))
+        if(!keys.isEmpty() && !keys.contains((*route)->getKey()))
         {
             ++route;
             continue;
@@ -244,37 +274,65 @@ void CRouteDB::saveGPX(CGpx& gpx, const QStringList& keys)
         QDomText _name_ = gpx.createTextNode((*route)->getName());
         name.appendChild(_name_);
 
+        if(!(*route)->getParentWpt().isEmpty())
+        {
+            QDomElement parent = gpx.createElement("parent");
+            parent.setAttribute("xmlns", "http://opencachemanage.sourceforge.net/schema1");
+            gpxRoute.appendChild(parent);
+            QDomText _parent_ = gpx.createTextNode((*route)->getParentWpt());
+            parent.appendChild(_parent_);
+        }
+
         unsigned cnt = 0;
-        QList<XY>& rtepts = (*route)->getRoutePoints();
-        QList<XY>::const_iterator rtept = rtepts.begin();
+        QVector<CRoute::pt_t> rtepts;
+        if(gpx.getExportMode() == CGpx::eQlgtExport)
+        {
+            rtepts = (*route)->getPriRtePoints();
+        }
+        else
+        {
+            rtepts = (*route)->getSecRtePoints().isEmpty() ? (*route)->getPriRtePoints() : (*route)->getSecRtePoints();
+        }
+        QVector<CRoute::pt_t>::const_iterator rtept = rtepts.begin();
         while(rtept != rtepts.end())
         {
+            if((gpx.getExportMode() != CGpx::eQlgtExport) && rtept->action.isEmpty())
+            {
+                rtept++;
+                continue;
+            }
+
             QDomElement gpxRtept = gpx.createElement("rtept");
             gpxRoute.appendChild(gpxRtept);
 
-            gpxRtept.setAttribute("lat",QString::number(rtept->v,'f',6));
-            gpxRtept.setAttribute("lon",QString::number(rtept->u,'f',6));
+            gpxRtept.setAttribute("lat",QString::number(rtept->lat,'f',6));
+            gpxRtept.setAttribute("lon",QString::number(rtept->lon,'f',6));
 
-            QString str = QString("%1").arg(++cnt,3,10,QChar('0'));
+            QString str     = QString("%1").arg(++cnt,3,10,QChar('0'));
 
             QDomElement name = gpx.createElement("name");
             gpxRtept.appendChild(name);
             QDomText _name_ = gpx.createTextNode(str);
             name.appendChild(_name_);
 
+            QString action = rtept->action;
+//            action.remove(QRegExp("<head.*[^>]*><\\/head>"));
+//            action.remove(QRegExp("<[^>]*>"));
+//            action = action.simplified();
+
             QDomElement cmt = gpx.createElement("cmt");
             gpxRtept.appendChild(cmt);
-            QDomText _cmt_ = gpx.createTextNode(str);
+            QDomText _cmt_ = gpx.createTextNode(action);
             cmt.appendChild(_cmt_);
 
             QDomElement desc = gpx.createElement("desc");
             gpxRtept.appendChild(desc);
-            QDomText _desc_ = gpx.createTextNode(str);
+            QDomText _desc_ = gpx.createTextNode(action);
             desc.appendChild(_desc_);
 
             QDomElement sym = gpx.createElement("sym");
             gpxRtept.appendChild(sym);
-            QDomText _sym_ = gpx.createTextNode((*route)->getIconName());
+            QDomText _sym_ = gpx.createTextNode((*route)->getIconString());
             sym.appendChild(_sym_);
 
             ++rtept;
@@ -286,7 +344,7 @@ void CRouteDB::saveGPX(CGpx& gpx, const QStringList& keys)
 
 
 /// load database data from QLandkarte binary
-void CRouteDB::loadQLB(CQlb& qlb)
+void CRouteDB::loadQLB(CQlb& qlb, bool newKey)
 {
     QDataStream stream(&qlb.routes(),QIODevice::ReadOnly);
     stream.setVersion(QDataStream::Qt_4_5);
@@ -295,11 +353,18 @@ void CRouteDB::loadQLB(CQlb& qlb)
     {
         CRoute * route = new CRoute(this);
         stream >> *route;
+        if(newKey)
+        {
+            route->setKey(route->getKey() + QString("%1").arg(QDateTime::currentDateTime().toTime_t()));
+        }
         route->calcDistance();
         addRoute(route, true);
     }
 
-    emit sigChanged();
+    if(qlb.routes().size())
+    {
+        emit sigChanged();
+    }
 }
 
 
@@ -374,34 +439,46 @@ void CRouteDB::clear()
 
 void CRouteDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
 {
+
     IMap& map = CMapDB::self().getMap();
 
-    p.setRenderHint(QPainter::Antialiasing,false);
+    // extended vieport rectangle to cut line segments properly
+    QRect extRect = rect.adjusted(-10, -10, 10, 10);
 
     QMap<QString,CRoute*>::iterator route       = routes.begin();
     QMap<QString,CRoute*>::iterator highlighted = routes.end();
 
     while(route != routes.end())
     {
-        QPolygon& line = (*route)->getPolyline();
+        QPolygon& line      = (*route)->getPolyline();
+        QPolygon& points    = (*route)->getPoints();
+        bool firstTime      = (*route)->firstTime;
 
-        bool firstTime = (*route)->firstTime;
 
-        QList<XY>& rtepts         = (*route)->getRoutePoints();
-        QList<XY>::iterator rtept = rtepts.begin();
 
         if ( needsRedraw || firstTime)
         {
+            bool isPriRoute = (*route)->secRoute.isEmpty();
+
             line.clear();
+            points.clear();
+            QVector<CRoute::pt_t>& rtepts = isPriRoute ? (*route)->getPriRtePoints() : (*route)->getSecRtePoints();
+            QVector<CRoute::pt_t>::iterator rtept = rtepts.begin();
             while(rtept != rtepts.end())
             {
-                double u = rtept->u * DEG_TO_RAD;
-                double v = rtept->v * DEG_TO_RAD;
+                double u = rtept->lon * DEG_TO_RAD;
+                double v = rtept->lat * DEG_TO_RAD;
 
                 map.convertRad2Pt(u,v);
-                line << QPoint(u,v);;
+                line << QPoint(u,v);
+                if(!rtept->action.isEmpty() || isPriRoute)
+                {
+                    points << QPoint(u,v);
+                }
+
                 ++rtept;
             }
+
         }
 
         if(!rect.intersects(line.boundingRect()))
@@ -417,22 +494,18 @@ void CRouteDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
         }
         else
         {
+
             // draw normal route
-            QPen pen(Qt::darkMagenta,7);
+            QPen pen(QColor(192,0,192,128),5);
             pen.setCapStyle(Qt::RoundCap);
             pen.setJoinStyle(Qt::RoundJoin);
             p.setPen(pen);
-            p.drawPolyline(line);
+            drawLine(line, extRect, p);
             p.setPen(Qt::white);
-            p.drawPolyline(line);
+            drawLine(line, extRect, p);
+
+            drawArrows(line, rect, p);
 
-            // draw bubbles
-            QPoint pt;
-            QPixmap bullet = (*route)->getIcon();
-            foreach(pt,line)
-            {
-                p.drawPixmap(pt.x() - 8 ,pt.y() - 8, bullet);
-            }
         }
 
         (*route)->firstTime = false;
@@ -445,26 +518,147 @@ void CRouteDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
         route = highlighted;
 
         QPolygon& line = (*route)->getPolyline();
+        QPolygon& points = (*route)->getPoints();
 
         // draw skunk line
-        QPen pen(Qt::magenta,7);
+        QPen pen(QColor(255,0,255,128),19);
         pen.setCapStyle(Qt::RoundCap);
         pen.setJoinStyle(Qt::RoundJoin);
         p.setPen(pen);
-        p.drawPolyline(line);
+        drawLine(line, extRect, p);
         p.setPen(Qt::white);
-        p.drawPolyline(line);
+        drawLine(line, extRect, p);
 
         // draw bubbles
         QPoint pt;
         QPixmap bullet = (*route)->getIcon();
-        foreach(pt,line)
+        foreach(pt,points)
         {
             p.drawPixmap(pt.x() - 8 ,pt.y() - 8, bullet);
         }
+
+        drawArrows(line, rect, p);
+    }
+
+}
+
+void CRouteDB::drawArrows(const QPolygon& line, const QRect& viewport, QPainter& p)
+{
+    QPointF arrow[4] =
+    {
+        QPointF( 20.0, 7.0),     //front
+        QPointF( 0.0, 0.0),      //upper tail
+        QPointF( 5.0, 7.0),      //mid tail
+        QPointF( 0.0, 15.0)      //lower tail
+    };
+
+
+    QPoint  pt, pt1, ptt;
+
+    // draw direction arrows
+    bool    start = true;
+    double  heading;
+
+    //generate arrow pic
+    QImage arrow_pic(21,16, QImage::Format_ARGB32);
+    arrow_pic.fill( qRgba(0,0,0,0));
+    QPainter t_paint(&arrow_pic);
+    USE_ANTI_ALIASING(t_paint, true);
+    t_paint.setPen(QPen(Qt::white, 2));
+    t_paint.setBrush(QColor(192,0,192,255));
+    t_paint.drawPolygon(arrow, 4);
+    t_paint.end();
+
+
+    foreach(pt,line)
+    {
+        if(start)        // no arrow on  the first loop
+        {
+            start = false;
+        }
+        else
+        {
+            if(!viewport.contains(pt))
+            {
+                continue;
+            }
+            if((abs(pt.x() - pt1.x()) + abs(pt.y() - pt1.y())) < 7)
+            {
+                continue;
+            }
+                         // keep distance
+            if((abs(pt.x() - ptt.x()) + abs(pt.y() - ptt.y())) > 100)
+            {
+                if(0 != pt.x() - pt1.x() && (pt.y() - pt1.y()))
+                {
+                    heading = ( atan2((double)(pt.y() - pt1.y()), (double)(pt.x() - pt1.x())) * 180.) / PI;
+
+                    p.save();
+                    // draw arrow between bullets
+                    p.translate((pt.x() + pt1.x())/2,(pt.y() + pt1.y())/2);
+                    p.rotate(heading);
+                    p.drawImage(-11, -7, arrow_pic);
+                    p.restore();
+                         //remember last point
+                    ptt = pt;
+                }
+            }
+        }
+        pt1 = pt;
+    }
+
+}
+
+void CRouteDB::drawLine(const QPolygon& line, const QRect& extViewport, QPainter& p)
+{
+    QPolygon subline;
+    QList<QPolygon> lines;
+
+    int i;
+    QPoint pt, ptt, pt1;
+    const int size = line.size();
+
+    pt = line[0];
+    subline << pt;
+
+    for(i = 1; i < size; i++)
+    {
+        pt1 = line[i];
+
+        if(!extViewport.contains(pt1) && !extViewport.contains(pt))
+        {
+            pt = pt1;
+            if(subline.size() > 1)
+            {
+                lines << subline;
+            }
+            subline.clear();
+            subline << pt;
+            continue;
+        }
+
+        ptt = pt1 - pt;
+        if(ptt.manhattanLength() < 5)
+        {
+            continue;
+        }
+
+        subline << pt1;
+        pt = pt1;
+    }
+
+    if(subline.size() > 1)
+    {
+        lines << subline;
+    }
+
+    for(i = 0; i < lines.count(); i++)
+    {
+        p.drawPolyline(lines[i]);
     }
 }
 
+
 QList<CRouteDB::keys_t> CRouteDB::keys()
 {
     QList<keys_t> k;
@@ -480,9 +674,73 @@ QList<CRouteDB::keys_t> CRouteDB::keys()
         k2.key      = k1;
         k2.name     = route->name;
         k2.icon     = route->getIcon();
+        k2.time     = route->getTimestamp();
 
         k << k2;
     }
 
+    CRouteToolWidget::sortmode_e sortmode = CRouteToolWidget::getSortMode();
+
+    qDebug() << "--";
+    switch(sortmode)
+    {
+        case CRouteToolWidget::eSortByName:
+            qSort(k.begin(), k.end(), CRouteDB::keyLessThanAlpha);
+            break;
+        case CRouteToolWidget::eSortByTime:
+            qSort(k.begin(), k.end(), CRouteDB::keyLessThanTime);
+            break;
+    }
+
+
     return k;
 }
+
+void CRouteDB::makeVisible(const QStringList& keys)
+{
+    QRectF r;
+    QString key;
+    foreach(key, keys)
+    {
+
+        CRoute * rte =  routes[key];
+
+        if(r.isNull())
+        {
+            r = rte->getBoundingRectF();
+        }
+        else
+        {
+            r |= rte->getBoundingRectF();
+        }
+
+    }
+
+    if (!r.isNull ())
+    {
+        CMapDB::self().getMap().zoom(r.left() * DEG_TO_RAD, r.top() * DEG_TO_RAD, r.right() * DEG_TO_RAD, r.bottom() * DEG_TO_RAD);
+    }
+
+}
+
+void CRouteDB::loadSecondaryRoute(const QString& key, QDomDocument& xml)
+{
+    if(routes.contains(key))
+    {
+        routes[key]->loadSecondaryRoute(xml);
+        emit sigChanged();
+        emit sigModified();
+        emit sigModified(key);
+    }
+}
+
+void CRouteDB::reset(const QString& key)
+{
+    if(routes.contains(key))
+    {
+        routes[key]->reset();
+        emit sigChanged();
+        emit sigModified();
+        emit sigModified(key);
+    }
+}
