@@ -21,6 +21,9 @@
 #include "GeoMath.h"
 #include "CMapDB.h"
 #include "CResources.h"
+#include "IUnit.h"
+#include "CMainWindow.h"
+#include "CCanvas.h"
 
 #include <QtGui>
 #include <QtNetwork/QHttp>
@@ -31,7 +34,6 @@
 #endif
 
 QDir CTrack::path(_MKSTR(MAPPATH) "/Track");
-quint32 CTrack::keycnt = 0;
 
 struct trk_head_entry_t
 {
@@ -78,16 +80,20 @@ QDataStream& operator >>(QDataStream& s, CTrack& track)
             case CTrack::eBase:
             {
 
+                QString key;
+
                 QDataStream s1(&entry->data, QIODevice::ReadOnly);
                 s1.setVersion(QDataStream::Qt_4_5);
 
-                s1 >> track._key_;
+                s1 >> key;
                 s1 >> track.timestamp;
                 s1 >> track.name;
                 s1 >> track.comment;
                 s1 >> track.colorIdx;
+                s1 >> track.parentWpt;
 
                 track.setColor(track.colorIdx);
+                track.setKey(key);
 
                 break;
             }
@@ -186,6 +192,33 @@ QDataStream& operator >>(QDataStream& s, CTrack& track)
                 track.setExt1Data();
                 break;
             }
+#ifdef GPX_EXTENSIONS
+            case CTrack::eTrkGpxExt:
+            {
+                QDataStream s1(&entry->data, QIODevice::ReadOnly);
+                s1.setVersion(QDataStream::Qt_4_5);
+                quint32 nTrkPts1 = 0;
+
+                s1 >> nTrkPts1;
+                if(nTrkPts1 != nTrkPts)
+                {
+                    QMessageBox::warning(0, QObject::tr("Corrupt track ..."), QObject::tr("Number of trackpoints is not equal the number of extended data trackpoints."), QMessageBox::Ignore,QMessageBox::Ignore);
+                    break;
+                }
+
+                track.tr_ext.set.clear();
+                s1 >> track.tr_ext.set;
+
+                QList<CTrack::pt_t>::iterator pt1 = track.track.begin();
+                while (pt1 != track.track.end())
+                {
+                    pt1->gpx_exts.values.clear();
+                    s1 >> pt1->gpx_exts.values;
+                    pt1++;
+                }
+                break;
+            }
+#endif
             default:;
         }
 
@@ -208,11 +241,12 @@ QDataStream& operator <<(QDataStream& s, CTrack& track)
     QDataStream s1(&entryBase.data, QIODevice::WriteOnly);
     s1.setVersion(QDataStream::Qt_4_5);
 
-    s1 << track.key();
+    s1 << track.getKey();
     s1 << track.timestamp;
     s1 << track.name;
     s1 << track.comment;
     s1 << track.colorIdx;
+    s1 << track.getParentWpt();
 
     entries << entryBase;
 
@@ -301,6 +335,32 @@ QDataStream& operator <<(QDataStream& s, CTrack& track)
 
         entries << entryTrkExt1;
     }
+#ifdef GPX_EXTENSIONS
+    //---------------------------------------
+    // prepare extended gpx trackpoint data
+    //---------------------------------------
+    if(track.tr_ext.set.size())
+    {
+        trk_head_entry_t entryTrkGpxExt;
+        entryTrkGpxExt.type = CTrack::eTrkGpxExt;
+        QDataStream s5(&entryTrkGpxExt.data, QIODevice::WriteOnly);
+        s5.setVersion(QDataStream::Qt_4_5);
+
+        trkpt = trkpts.begin();
+
+        s5 << (quint32)trkpts.size();
+        s5 << track.tr_ext.set;
+
+
+        while(trkpt != trkpts.end())
+        {
+            s5 << trkpt->gpx_exts.values;
+            ++trkpt;
+        }
+
+        entries << entryTrkGpxExt;
+    }
+#endif
     //---------------------------------------
     // prepare terminator
     //---------------------------------------
@@ -433,8 +493,7 @@ bool trackpointLessThan(const CTrack::pt_t &p1, const CTrack::pt_t &p2)
 
 
 CTrack::CTrack(QObject * parent)
-: QObject(parent)
-, timestamp(QDateTime::currentDateTime().toUTC().toTime_t ())
+: IItem(parent)
 , color(Qt::darkBlue)
 , bullet(":/icons/small_bullet_darkblue.png")
 , colorIdx(4)
@@ -444,9 +503,12 @@ CTrack::CTrack(QObject * parent)
 , firstTime(true)
 , m_hide(false)
 , geonames(0)
+, visiblePointCount(0)
 {
     ref = 1;
 
+    setColor(4);
+
     slotSetupLink();
     connect(&CResources::self(), SIGNAL(sigProxyChanged()), this, SLOT(slotSetupLink()));
 }
@@ -474,8 +536,6 @@ void CTrack::slotSetupLink()
     geonames->setHost("ws.geonames.org");
     connect(geonames,SIGNAL(requestStarted(int)),this,SLOT(slotRequestStarted(int)));
     connect(geonames,SIGNAL(requestFinished(int,bool)),this,SLOT(slotRequestFinished(int,bool)));
-
-
 }
 
 void CTrack::replaceElevationByLocal()
@@ -492,7 +552,7 @@ void CTrack::replaceElevationByLocal()
 }
 
 void CTrack::replaceElevationByRemote()
-{    
+{
     int idx = 0, id;
     const int size = track.size();
 
@@ -538,6 +598,8 @@ void CTrack::slotRequestFinished(int id, bool error)
 
     QString asw = geonames->readAll().simplified();
 
+//    qDebug() << asw;
+
     if(asw.isEmpty())
     {
         return;
@@ -551,7 +613,10 @@ void CTrack::slotRequestFinished(int id, bool error)
         int idx = id2idx[id];
         foreach(val, vals)
         {
-            track[idx++].ele = val.toDouble();
+            if(idx < track.size())
+            {
+                track[idx++].ele = val.toDouble();
+            }
         }
 
         id2idx.remove(id);
@@ -598,21 +663,11 @@ void CTrack::setColor(unsigned i)
     colorIdx    = i;
     color       = lineColors[i];
     bullet      = QPixmap(bulletColors[i]);
+
+    setIcon(color.name());
 }
 
 
-void CTrack::genKey()
-{
-    _key_ = QString("%1%2%3").arg(timestamp).arg(name).arg(keycnt++);
-}
-
-
-const QString& CTrack::key()
-{
-    if(_key_.isEmpty()) genKey();
-    return _key_;
-}
-
 
 CTrack& CTrack::operator<<(pt_t& pt)
 {
@@ -658,12 +713,17 @@ void CTrack::rebuild(bool reindex)
     QList<pt_t>::iterator pt1 = track.begin();
     QList<pt_t>::iterator pt2 = track.begin();
 
+    visiblePointCount = 0;
     totalTime       = 0;
     totalDistance   = 0;
     totalAscend     = 0;
     totalDescend    = 0;
     avgspeed0       = 0;
     avgspeed1       = 0;
+    float maxEle    = -WPT_NOFLOAT;
+    float minEle    =  WPT_NOFLOAT;
+    float maxSpeed  = -WPT_NOFLOAT;
+    float minSpeed  =  WPT_NOFLOAT;
 
     // reindex track if desired
     if(reindex)
@@ -678,6 +738,11 @@ void CTrack::rebuild(bool reindex)
         pt1 = track.begin();
     }
 
+//    if(!track.isEmpty() && (track.first().timestamp != 0))
+//    {
+//        timestamp = track.first().timestamp;
+//    }
+
     // skip leading deleted points
     while((pt1 != track.end()) && (pt1->flags & pt_t::eDeleted))
     {
@@ -706,6 +771,14 @@ void CTrack::rebuild(bool reindex)
     pt1->dem        = dem.getElevation(pt1->lon * DEG_TO_RAD, pt1->lat * DEG_TO_RAD);
     pt1->slope      = 0.0;
     t1              = pt1->timestamp;
+    t2              = t1;   //for the case that the track has only 1 point
+
+    ++visiblePointCount;
+
+    if(pt1->ele   > maxEle)   {maxEle   = pt1->ele;   ptMaxEle   = *pt1;}
+    if(pt1->ele   < minEle)   {minEle   = pt1->ele;   ptMinEle   = *pt1;}
+    if(pt1->speed > maxSpeed) {maxSpeed = pt1->speed; ptMaxSpeed = *pt1;}
+    if(pt1->speed < minSpeed) {minSpeed = pt1->speed; ptMinSpeed = *pt1;}
 
     // process track
     while(++pt2 != track.end())
@@ -723,6 +796,8 @@ void CTrack::rebuild(bool reindex)
             continue;
         }
 
+        ++visiblePointCount;
+
         int dt = -1;
         if(pt1->timestamp != 0x00000000 && pt1->timestamp != 0xFFFFFFFF)
         {
@@ -740,16 +815,19 @@ void CTrack::rebuild(bool reindex)
         pt2->distance   = pt1->distance + pt2->delta;
         if ((pt1->ele != WPT_NOFLOAT) && (pt2->ele != WPT_NOFLOAT))
         {
-            slope           = pt2->ele - pt1->ele;
+            slope = pt2->ele - pt1->ele;
         }
         else
         {
             slope = 0.;
         }
+
         pt2->slope    = qRound(slope / pt2->delta * 10000)/100.0;
         if (qAbs(pt2->slope )>100)
+        {
             pt2->slope = pt1->slope;
-        // qDebug() << slope << pt2->delta << pt2->slope;
+        }
+
         if(slope > 0)
         {
             totalAscend  += slope;
@@ -763,7 +841,6 @@ void CTrack::rebuild(bool reindex)
         if(ext1Data && pt2->velocity != WPT_NOFLOAT)
         {
             pt2->speed  =  pt2->velocity;
-            //             pt2->speed  = (dt > 0) ? pt2->delta / dt : 0;
         }
         else
         {
@@ -778,6 +855,13 @@ void CTrack::rebuild(bool reindex)
         avgspeed1       = avgspeed0;
         pt2->avgspeed   = avgspeed0;
 
+        if(pt2->ele   > maxEle)   {maxEle   = pt2->ele;   ptMaxEle   = *pt2;}
+        if(pt2->ele   < minEle)   {minEle   = pt2->ele;   ptMinEle   = *pt2;}
+        if(pt2->speed > maxSpeed) {maxSpeed = pt2->speed; ptMaxSpeed = *pt2;}
+        if(pt2->speed < minSpeed) {minSpeed = pt2->speed; ptMinSpeed = *pt2;}
+
+        pt2->timeSinceStart = t2 - t1;
+
         pt1 = pt2;
     }
 
@@ -788,7 +872,7 @@ void CTrack::rebuild(bool reindex)
 }
 
 
-void CTrack::setPointOfFocus(int idx)
+void CTrack::setPointOfFocus(int idx, bool eraseSelection, bool moveMap)
 {
     // reset previous selections
     QList<CTrack::pt_t>& trkpts           = track;
@@ -796,16 +880,48 @@ void CTrack::setPointOfFocus(int idx)
     while(trkpt != trkpts.end())
     {
         trkpt->flags &= ~CTrack::pt_t::eFocus;
+        if(eraseSelection)
+        {
+            trkpt->flags &= ~CTrack::pt_t::eSelected;
+        }
         ++trkpt;
     }
     if(idx < track.count())
     {
         trkpts[idx].flags |= CTrack::pt_t::eFocus;
         trkpts[idx].flags |= CTrack::pt_t::eSelected;
+
+        if(moveMap)
+        {
+            theMainWindow->getCanvas()->move(trkpts[idx].lon, trkpts[idx].lat);
+        }
+
     }
     emit sigChanged();
 }
 
+CTrack::pt_t * CTrack::getPointOfFocus(double dist)
+{
+    QList<CTrack::pt_t>::const_iterator trkpt = track.begin();
+    quint32 idx = 0;
+    while(trkpt != track.end())
+    {
+        if(trkpt->flags & CTrack::pt_t::eDeleted)
+        {
+            ++trkpt; continue;
+        }
+
+        if(dist < trkpt->distance)
+        {
+            return &track[idx];
+        }
+        idx = trkpt->idx;
+        ++trkpt;
+    }
+
+    return 0;
+}
+
 
 QDateTime CTrack::getStartTimestamp()
 {
@@ -840,6 +956,55 @@ QDateTime CTrack::getEndTimestamp()
     return QDateTime();
 }
 
+/// get a summary of item's data to display on screen or in the toolview
+QString CTrack::getInfo()
+{
+    QString val1, unit1, val2, unit2;
+    QString str     = getName();
+    double distance = getTotalDistance();
+
+    IUnit::self().meter2distance(getTotalDistance(), val1, unit1);
+    str += tr("\nlength: %1 %2").arg(val1).arg(unit1);
+    str += tr(", points: %1 (%2)").arg(visiblePointCount).arg(getTrackPoints().count());
+
+    quint32 ttime = getTotalTime();
+    quint32 days  = ttime / 86400;
+
+    QTime time;
+    time = time.addSecs(ttime);
+    if(days)
+    {
+        str += tr("\ntime: %1:").arg(days) + time.toString("HH:mm:ss");
+    }
+    else
+    {
+        str += tr("\ntime: ") + time.toString("HH:mm:ss");
+    }
+
+    IUnit::self().meter2speed(distance / ttime, val1, unit1);
+    str += tr(", speed: %1 %2").arg(val1).arg(unit1);
+
+    str += tr("\nstart: %1").arg(getStartTimestamp().isNull() ? tr("-") : getStartTimestamp().toString());
+    str += tr("\nend: %1").arg(getEndTimestamp().isNull() ? tr("-") : getEndTimestamp().toString());
+
+    IUnit::self().meter2elevation(getAscend(), val1, unit1);
+    IUnit::self().meter2elevation(getDescend(), val2, unit2);
+
+    str += tr("\n%1%2 %3, %4%5 %6").arg(QChar(0x2191)).arg(val1).arg(unit1).arg(QChar(0x2193)).arg(val2).arg(unit2);
+
+    return str;
+}
+
+/// set the icon defined by a string
+void CTrack::setIcon(const QString& str)
+{
+    iconPixmap = QPixmap(16,16);
+    iconPixmap.fill(str);
+
+    iconString = str;
+}
+
+
 
 QDataStream& operator >>(QDataStream& s, CFlags& flag)
 {
@@ -856,3 +1021,4 @@ QDataStream& operator <<(QDataStream& s, CFlags& flag)
     s << flag.flag();
     return s;
 }
+
