@@ -26,7 +26,9 @@
 #include <QPolygon>
 #include <QDateTime>
 #include <QMap>
+#include <QList>
 #include "CWpt.h"
+#include "IItem.h"
 
 #ifdef GPX_EXTENSIONS
 #include "CGpxExtension.h"       //TODO: include von gpx ext
@@ -58,7 +60,7 @@ class CFlags
 QDataStream& operator >>(QDataStream& s, CFlags& flag);
 QDataStream& operator <<(QDataStream& s, CFlags& flag);
 
-class CTrack : public QObject
+class CTrack : public IItem
 {
     Q_OBJECT;
     public:
@@ -66,7 +68,7 @@ class CTrack : public QObject
 
         virtual ~CTrack();
         int ref;
-        enum type_e {eEnd,eBase,eTrkPts,eTrain,eTrkExt1};
+        enum type_e {eEnd,eBase,eTrkPts,eTrain,eTrkExt1,eTrkGpxExt};
 
 #ifdef GPX_EXTENSIONS
         CGpxExtTr tr_ext;        //TODO: CGpxExtPt -> tr_ext
@@ -84,7 +86,7 @@ class CTrack : public QObject
 
             pt_t() : idx(-1), lon(WPT_NOFLOAT), lat(WPT_NOFLOAT), ele(WPT_NOFLOAT), timestamp(0), timestamp_msec(0),
                 speed(WPT_NOFLOAT), avgspeed(0), delta(WPT_NOFLOAT), azimuth(WPT_NOFLOAT), distance(WPT_NOFLOAT),
-                ascend(0), descend(0), heartReateBpm(-1), cadenceRpm(-1), slope(0),
+                ascend(0), descend(0), heartReateBpm(-1), cadenceRpm(-1), slope(0), timeSinceStart(0),
                 fix(""), sat(0), velocity(WPT_NOFLOAT), heading(WPT_NOFLOAT),
                 vdop(WPT_NOFLOAT), hdop(WPT_NOFLOAT), pdop(WPT_NOFLOAT),
                 flags(0), px_valid(FALSE), dem(WPT_NOFLOAT), editItem(NULL){}
@@ -124,6 +126,8 @@ class CTrack : public QObject
             /// secondary data: slope in %
             float slope;
 
+            quint32 timeSinceStart;
+
             // extended data 1
             QString fix;
             qint32  sat;
@@ -164,12 +168,6 @@ class CTrack : public QObject
         const QColor& getColor(){return color;}
         const QPixmap& getBullet(){return bullet;}
         unsigned getColorIdx(){return colorIdx;}
-        /// set track name
-        void setName(const QString& n){name = n;}
-        /// get track name
-        const QString& getName(){return name;}
-        /// get unique track key
-        const QString& key();
 
         /// set the highlight flag
         void setHighlight(bool yes){highlight = yes;}
@@ -187,9 +185,11 @@ class CTrack : public QObject
         /// get the total distance of the track in [m]
         double getTotalDistance(){return totalDistance;}
         /// get the total time covered by the track in seconds
-        int getTotalTime(){return totalTime;}
+        quint32 getTotalTime(){return totalTime;}
         /// select tarckpoint by index
-        void setPointOfFocus(int idx);
+        void setPointOfFocus(int idx, bool eraseSelection, bool moveMap);
+        /// set point of focus to a point with a given distance from start
+        pt_t * getPointOfFocus(double dist);
         ///
         QDateTime getStartTimestamp();
         QDateTime getEndTimestamp();
@@ -205,9 +205,6 @@ class CTrack : public QObject
         static const QColor lineColors[];
         static const QString bulletColors[];
 
-        /// track name
-        QString name;
-
         bool hasTraineeData() { return traineeData;}
         void setTraineeData() { traineeData = true;}
         bool hasExt1Data() { return ext1Data;}
@@ -219,6 +216,14 @@ class CTrack : public QObject
         void replaceElevationByRemote();
         void replaceElevationByLocal();
 
+        /// get a summary of item's data to display on screen or in the toolview
+        QString getInfo();
+        /// set the icon defined by a string
+        void setIcon(const QString& str);
+
+
+        void setTimestamp(quint32 ts){timestamp = ts;}
+
         signals:
         void sigChanged();
 
@@ -232,17 +237,9 @@ class CTrack : public QObject
         friend class CTrackDB;
         friend QDataStream& operator >>(QDataStream& s, CTrack& track);
         friend QDataStream& operator <<(QDataStream& s, CTrack& track);
-        void genKey();
 
         static QDir path;
-        static quint32 keycnt;
 
-        /// unique key to address tarck
-        QString _key_;
-        /// creation timestamp
-        quint32 timestamp;
-        /// a comment string
-        QString comment;
         /// a track URL
         QString url;
         /// the track line color
@@ -273,6 +270,11 @@ class CTrack : public QObject
         float avgspeed0;
         float avgspeed1;
 
+        pt_t ptMaxEle;
+        pt_t ptMinEle;
+        pt_t ptMaxSpeed;
+        pt_t ptMinSpeed;
+
         bool traineeData;
         bool ext1Data;
 
@@ -284,6 +286,8 @@ class CTrack : public QObject
 
         QMap<int,int> id2idx;
 
+        quint32 visiblePointCount;
+
 };
 
 QDataStream& operator >>(QDataStream& s, CTrack& track);
