@@ -29,6 +29,7 @@
 #include "CDlgCombineTracks.h"
 #include "CMapDB.h"
 #include "IMap.h"
+#include "IUnit.h"
 
 #include <QtGui>
 #include "CUndoStackModel.h"
@@ -66,7 +67,7 @@ CTrackDB::CTrackDB(QTabWidget * tb, QObject * parent)
     m_self      = this;
 
     QSettings cfg;
-    showBullets = cfg.value("tracks/showBullets", showBullets).toBool();
+    showBullets = cfg.value("track/showBullets", showBullets).toBool();
     toolview    = new CTrackToolWidget(tb);
     undoStack   = CUndoStackModel::getInstance();
 
@@ -76,7 +77,7 @@ CTrackDB::CTrackDB(QTabWidget * tb, QObject * parent)
 CTrackDB::~CTrackDB()
 {
     QSettings cfg;
-    cfg.setValue("tracks/showBullets", showBullets);
+    cfg.setValue("track/showBullets", showBullets);
 }
 
 
@@ -84,6 +85,7 @@ void CTrackDB::clear()
 {
     cnt = 0;
     delTracks(tracks.keys());
+    CTrack::resetKeyCnt();
     emit sigChanged();
 }
 
@@ -115,7 +117,9 @@ QRectF CTrackDB::getBoundingRectF()
 }
 
 
-void CTrackDB::loadQLB(CQlb& qlb)
+
+
+void CTrackDB::loadQLB(CQlb& qlb, bool newKey)
 {
     QDataStream stream(&qlb.tracks(),QIODevice::ReadOnly);
     stream.setVersion(QDataStream::Qt_4_5);
@@ -124,31 +128,17 @@ void CTrackDB::loadQLB(CQlb& qlb)
     {
         CTrack * track = new CTrack(this);
         stream >> *track;
-        addTrack(track, true);
-    }
-
-    emit sigChanged();
-
-}
-
-
-void CTrackDB::loadQLB(CQlb& qlb, bool asDuplicat)
-{
-    QDataStream stream(&qlb.tracks(),QIODevice::ReadOnly);
-    stream.setVersion(QDataStream::Qt_4_5);
-
-    while(!stream.atEnd())
-    {
-        CTrack * track = new CTrack(this);
-        stream >> *track;
-        if(asDuplicat)
+        if(newKey)
         {
-            track->genKey();
+            track->setKey(track->getKey() + QString("%1").arg(QDateTime::currentDateTime().toTime_t()));
         }
         addTrack(track, true);
     }
 
-    emit sigChanged();
+    if(qlb.tracks().size())
+    {
+        emit sigChanged();
+    }
 
 }
 
@@ -166,10 +156,12 @@ void CTrackDB::saveQLB(CQlb& qlb)
 
 void CTrackDB::loadGPX(CGpx& gpx)
 {
+    bool hasItems = false;
     QDomElement tmpelem;
     QDomElement trk = gpx.firstChildElement("gpx").firstChildElement("trk");
     while (!trk.isNull())
     {
+        hasItems = true;
         CTrack* track = new CTrack(this);
                                  //preset a random color
         track->setColor((rand() % 13)+1);
@@ -199,6 +191,12 @@ void CTrackDB::loadGPX(CGpx& gpx)
             // When the URL is somehow supported, we may need those
         }
 
+        tmpelem = trkmap.value("parent");
+        if(!tmpelem.isNull())
+        {
+            track->setParentWpt(tmpelem.text());
+        }
+
         // For now we are ignoring the following elements:
         // * cmt - GPS comment (string)
         // * src - data source (string)
@@ -412,7 +410,11 @@ void CTrackDB::loadGPX(CGpx& gpx)
         trk = trk.nextSiblingElement("trk");
     }
 
-    emit sigChanged();
+    CTrack::resetKeyCnt();
+    if(hasItems)
+    {
+        emit sigChanged();
+    }
 }
 
 
@@ -422,6 +424,7 @@ void CTrackDB::saveGPX(CGpx& gpx, const QStringList& keys)
     QDomElement root = gpx.documentElement();
     QMap<QString,CTrack*>::iterator track = tracks.begin();
 
+    quint32 dummyTimestamp = 0;
 
     QList<keys_t> _keys = this->keys();
     QList<keys_t>::const_iterator _key = _keys.begin();
@@ -430,7 +433,7 @@ void CTrackDB::saveGPX(CGpx& gpx, const QStringList& keys)
     {
         CTrack * track = tracks[_key->key];
 
-        if(!keys.isEmpty() && !keys.contains(track->key()))
+        if(!keys.isEmpty() && !keys.contains(track->getKey()))
         {
             ++_key;
             continue;
@@ -444,6 +447,15 @@ void CTrackDB::saveGPX(CGpx& gpx, const QStringList& keys)
         QDomText _name_ = gpx.createTextNode(track->getName());
         name.appendChild(_name_);
 
+        if(!track->getParentWpt().isEmpty())
+        {
+            QDomElement parent = gpx.createElement("parent");
+            parent.setAttribute("xmlns", "http://opencachemanage.sourceforge.net/schema1");
+            trk.appendChild(parent);
+            QDomText _parent_ = gpx.createTextNode(track->getParentWpt());
+            parent.appendChild(_parent_);
+        }
+
         QDomElement ext = gpx.createElement("extensions");
         trk.appendChild(ext);
 
@@ -457,6 +469,7 @@ void CTrackDB::saveGPX(CGpx& gpx, const QStringList& keys)
         QDomText _color_ = gpx.createTextNode(colname);
         color.appendChild(_color_);
 
+
         QDomElement trkseg = gpx.createElement("trkseg");
         trk.appendChild(trkseg);
 
@@ -465,7 +478,7 @@ void CTrackDB::saveGPX(CGpx& gpx, const QStringList& keys)
         while(pt != pts.end())
         {
             QDomElement trkpt = gpx.createElement("trkpt");
-            if (gpx.getExportFlag() && (pt->flags.flag() & CTrack::pt_t::eDeleted))
+            if ((gpx.getExportMode() != CGpx::eQlgtExport) && (pt->flags.flag() & CTrack::pt_t::eDeleted))
             {
                 // skip deleted points when exporting
                 ++pt;
@@ -487,13 +500,20 @@ void CTrackDB::saveGPX(CGpx& gpx, const QStringList& keys)
 
             if(pt->timestamp != 0x000000000 && pt->timestamp != 0xFFFFFFFF)
             {
-                QDateTime t = QDateTime::fromTime_t(pt->timestamp).toUTC();
-                t = t.addMSecs(pt->timestamp_msec);
-                QDomElement time = gpx.createElement("time");
-                trkpt.appendChild(time);
-                QDomText _time_ = gpx.createTextNode(t.toString("yyyy-MM-dd'T'hh:mm:ss.zzz'Z'"));
-                time.appendChild(_time_);
+                dummyTimestamp = pt->timestamp;
             }
+            else
+            {
+                dummyTimestamp++;
+            }
+
+            QDateTime t = QDateTime::fromTime_t(dummyTimestamp).toUTC();
+            t = t.addMSecs(pt->timestamp_msec);
+            QDomElement time = gpx.createElement("time");
+            trkpt.appendChild(time);
+            QDomText _time_ = gpx.createTextNode(t.toString("yyyy-MM-dd'T'hh:mm:ss.zzz'Z'"));
+            time.appendChild(_time_);
+
 
             if(pt->hdop != WPT_NOFLOAT)
             {
@@ -534,19 +554,19 @@ void CTrackDB::saveGPX(CGpx& gpx, const QStringList& keys)
             }
 
             // gpx extensions
-            if((!gpx.getExportFlag() && pt->flags.flag() != 0) ||
-                pt->heading != WPT_NOFLOAT ||
-                pt->velocity != WPT_NOFLOAT)
+            if(gpx.getExportMode() == CGpx::eQlgtExport)
             {
+                bool hasExtensions = false;
                 QDomElement extensions = gpx.createElement("extensions");
-                trkpt.appendChild(extensions);
 
-                if(!gpx.getExportFlag() && pt->flags.flag() != 0)
+
+                if(pt->flags.flag() != 0)
                 {
                     QDomElement flags = gpx.createElement("ql:flags");
                     extensions.appendChild(flags);
                     QDomText _flags_ = gpx.createTextNode(QString::number(pt->flags.flag()));
                     flags.appendChild(_flags_);
+                    hasExtensions = true;
                 }
 
                 if(pt->heading != WPT_NOFLOAT)
@@ -555,6 +575,7 @@ void CTrackDB::saveGPX(CGpx& gpx, const QStringList& keys)
                     extensions.appendChild(heading);
                     QDomText _heading_ = gpx.createTextNode(QString::number(pt->heading));
                     heading.appendChild(_heading_);
+                    hasExtensions = true;
                 }
 
                 if(pt->velocity != WPT_NOFLOAT)
@@ -563,6 +584,12 @@ void CTrackDB::saveGPX(CGpx& gpx, const QStringList& keys)
                     extensions.appendChild(velocity);
                     QDomText _velocity_ = gpx.createTextNode(QString::number(pt->velocity));
                     velocity.appendChild(_velocity_);
+                    hasExtensions = true;
+                }
+
+                if(hasExtensions)
+                {
+                    trkpt.appendChild(extensions);
                 }
             }
 
@@ -582,8 +609,8 @@ void CTrackDB::addTrack(CTrack* track, bool silent)
         track->setName(tr("Track%1").arg(cnt++));
     }
     track->rebuild(false);
-    delTrack(track->key(), silent);
-    tracks[track->key()] = track;
+    delTrack(track->getKey(), silent);
+    tracks[track->getKey()] = track;
 
     connect(track,SIGNAL(sigChanged()),SIGNAL(sigChanged()));
     if(!silent)
@@ -598,6 +625,7 @@ void CTrackDB::delTrack(const QString& key, bool silent)
 {
     if(!tracks.contains(key)) return;
     undoStack->push(new CTrackUndoCommandDelete(this,key,silent));
+
 }
 
 
@@ -606,14 +634,25 @@ void CTrackDB::delTracks(const QStringList& keys)
     undoStack->beginMacro("delTracks");
     foreach(QString key,keys)
     {
-        delTrack(key,false);
+        delTrack(key,true);
     }
     undoStack->endMacro();
+    if(!keys.isEmpty())
+    {
+        emit sigChanged();
+        emit sigModified();
+    }
 }
 
 
 void CTrackDB::highlightTrack(const QString& key)
 {
+
+    if(highlightedTrack() && (key == highlightedTrack()->getKey()))
+    {
+        return;
+    }
+
     QMap<QString,CTrack*>::iterator track = tracks.begin();
     while(track != tracks.end())
     {
@@ -750,14 +789,90 @@ void CTrackDB::splitTrack(int idx)
 
     addTrack(track1, true);
     addTrack(track2, true);
-    delTrack(theTrack->key(), true);
+    delTrack(theTrack->getKey(), true);
 
     emit sigChanged();
     emit sigModified();
 }
 
+void CTrackDB::drawLine(const QPolygon& line, const QRect& extViewport, QPainter& p)
+{
+    QPolygon subline;
+    QList<QPolygon> lines;
 
-void CTrackDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
+    int i;
+    QPoint pt, ptt, pt1;
+    const int size = line.size();
+
+    pt = line[0];
+    subline << pt;
+
+    for(i = 1; i < size; i++)
+    {
+        pt1 = line[i];
+
+        if(!extViewport.contains(pt1) && !extViewport.contains(pt))
+        {
+            pt = pt1;
+            if(subline.size() > 1)
+            {
+                lines << subline;
+            }
+            subline.clear();
+            subline << pt;
+            continue;
+        }
+
+        ptt = pt1 - pt;
+        if(ptt.manhattanLength() < 5)
+        {
+            continue;
+        }
+
+        subline << pt1;
+        pt = pt1;
+    }
+
+    if(subline.size() > 1)
+    {
+        lines << subline;
+    }
+
+    for(i = 0; i < lines.count(); i++)
+    {
+        p.drawPolyline(lines[i]);
+    }
+
+}
+
+static void drawMarker(QPainter& p, const QString& text, CTrack::pt_t& pt)
+{
+    IMap& map = CMapDB::self().getMap();
+
+    double u = pt.lon * DEG_TO_RAD;
+    double v = pt.lat * DEG_TO_RAD;
+
+    map.convertRad2Pt(u,v);
+
+    QPen pen1(Qt::white,5);
+    pen1.setCapStyle(Qt::RoundCap);
+    pen1.setJoinStyle(Qt::RoundJoin);
+
+    QPen pen2(Qt::black,2);
+    pen2.setCapStyle(Qt::RoundCap);
+    pen2.setJoinStyle(Qt::RoundJoin);
+
+    p.setPen(pen1);
+    p.drawLine(u,v, u + 10, v - 10);
+    p.drawLine(u + 10, v - 10, u + 80, v - 10);
+    p.setPen(pen2);
+    p.drawLine(u,v, u + 10, v - 10);
+    p.drawLine(u + 10, v - 10, u + 80, v - 10);
+    CCanvas::drawText(text, p, QPoint(u + 45, v - 10),Qt::black );
+
+}
+
+void CTrackDB::drawArrows(const QPolygon& line, const QRect& viewport, QPainter& p)
 {
     QPointF arrow[4] =
     {
@@ -767,13 +882,70 @@ void CTrackDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
         QPointF( 0.0, 15.0)      //lower tail
     };
 
+    QPoint  pt, pt1, ptt;
+
+    // draw direction arrows
+    bool    start = true;
+    double  heading;
+
+    //generate arrow pic
+    QImage arrow_pic(21,16, QImage::Format_ARGB32);
+    arrow_pic.fill( qRgba(0,0,0,0));
+    QPainter t_paint(&arrow_pic);
+    USE_ANTI_ALIASING(t_paint, true);
+    t_paint.setPen(QPen(Qt::white, 2));
+    t_paint.setBrush(p.brush());
+    t_paint.drawPolygon(arrow, 4);
+    t_paint.end();
+
+
+    foreach(pt,line)
+    {
+        if(start)        // no arrow on  the first loop
+        {
+            start = false;
+        }
+        else
+        {
+            if(!viewport.contains(pt))
+            {
+                continue;
+            }
+            if((abs(pt.x() - pt1.x()) + abs(pt.y() - pt1.y())) < 7)
+            {
+                continue;
+            }
+                         // keep distance
+            if((abs(pt.x() - ptt.x()) + abs(pt.y() - ptt.y())) > 100)
+            {
+                if(0 != pt.x() - pt1.x() && (pt.y() - pt1.y()))
+                {
+                    heading = ( atan2((double)(pt.y() - pt1.y()), (double)(pt.x() - pt1.x())) * 180.) / PI;
+
+                    p.save();
+                    // draw arrow between bullets
+                    p.translate((pt.x() + pt1.x())/2,(pt.y() + pt1.y())/2);
+                    p.rotate(heading);
+                    p.drawImage(-11, -7, arrow_pic);
+                    p.restore();
+                         //remember last point
+                    ptt = pt;
+                }
+            }
+        }
+        pt1 = pt;
+    }
+
+}
+
+
+void CTrackDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
+{
+
     QPoint focus(-1,-1);
     QVector<QPoint> selected;
     IMap& map = CMapDB::self().getMap();
 
-    /// @todo it would be nice to use antialiasing here, but right now performance is bad
-    p.setRenderHint(QPainter::Antialiasing, !map.getFastDrawFlag());
-    p.setRenderHint(QPainter::Antialiasing, false);
 
     //     QMap<QString,CTrack*> tracks                = CTrackDB::self().getTracks();
     QMap<QString,CTrack*>::iterator track       = tracks.begin();
@@ -781,6 +953,9 @@ void CTrackDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
 
     QPixmap bullet_red(":/icons/bullet_red.png");
 
+    // extended vieport rectangle to cut line segments properly
+    QRect extRect = rect.adjusted(-10, -10, 10, 10);
+
     while(track != tracks.end())
     {
 
@@ -855,55 +1030,12 @@ void CTrackDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
             pen2.setJoinStyle(Qt::RoundJoin);
 
             p.setPen(pen1);
-            p.drawPolyline(line);
+            drawLine(line, extRect, p);
             p.setPen(pen2);
-            p.drawPolyline(line);
+            drawLine(line, extRect, p);
 
-            // draw direction arrows
-            QPoint  pt, pt1, ptt;
-            bool    start = true;
-            double  heading;
-
-            //generate arrow pic
-            QImage arrow_pic(21,16, QImage::Format_ARGB32);
-            arrow_pic.fill( qRgba(0,0,0,0));
-            QPainter t_paint(&arrow_pic);
-            t_paint.setRenderHint(QPainter::Antialiasing, true);
-            t_paint.setPen(QPen(Qt::white, 1));
-            t_paint.setBrush((*track)->getColor());
-            t_paint.drawPolygon(arrow, 4);
-            t_paint.end();
-
-
-            foreach(pt,line)
-            {
-                if(start)        // no arrow on  the first loop
-                {
-                    start = false;
-                }
-                else
-                {
-                    if((abs(pt.x() - pt1.x()) + abs(pt.y() - pt1.y())) < 7) continue;
-                                 // keep distance
-                    if((abs(pt.x() - ptt.x()) + abs(pt.y() - ptt.y())) > 50)
-                    {
-                        if(0 != pt.x() - pt1.x() && (pt.y() - pt1.y()))
-                        {
-                            heading = ( atan2((double)(pt.y() - pt1.y()), (double)(pt.x() - pt1.x())) * 180.) / PI;
-
-                            p.save();
-                            // draw arrow between bullets
-                            p.translate((pt.x() + pt1.x())/2,(pt.y() + pt1.y())/2);
-                            p.rotate(heading);
-                            p.drawImage(-11, -7, arrow_pic);
-                            p.restore();
-                                 //remember last point
-                            ptt = pt;
-                        }
-                    }
-                }
-                pt1 = pt;
-            }
+            p.setBrush((*track)->getColor());
+            drawArrows(line, rect, p);
         }
 
         (*track)->firstTime = false;
@@ -913,6 +1045,8 @@ void CTrackDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
     // if there is a highlighted track, draw it
     if(highlighted != tracks.end())
     {
+        QPoint pt1, pt;
+
         track = highlighted;
 
         QPixmap bullet = (*track)->getBullet();
@@ -920,68 +1054,36 @@ void CTrackDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
         QPolygon& line = (*track)->getPolyline();
 
         // draw skunk line
-        QPen pen1(Qt::white,11);
+        QPen pen1(QColor(255,255,255,128),15);
         pen1.setCapStyle(Qt::RoundCap);
         pen1.setJoinStyle(Qt::RoundJoin);
 
-        QPen pen2((*track)->getColor(),7);
+        QColor color = (*track)->getColor();
+        color.setAlpha(128);
+        QPen pen2(color,11);
         pen2.setCapStyle(Qt::RoundCap);
         pen2.setJoinStyle(Qt::RoundJoin);
 
         p.setPen(pen1);
-        p.drawPolyline(line);
+        drawLine(line, extRect, p);
         p.setPen(pen2);
-        p.drawPolyline(line);
-
-        // draw bubbles and direction arrows
-        QPoint  pt, pt1, ptt;
-        bool    start = true;
-        double  heading;
-
-        //generate arrow pic
-        QImage arrow_pic(21,15, QImage::Format_ARGB32);
-        arrow_pic.fill( qRgba(0,0,0,0));
-        QPainter t_paint(&arrow_pic);
-        t_paint.setRenderHint(QPainter::Antialiasing, true);
-        t_paint.setPen(QPen(Qt::white, 2));
-        t_paint.setBrush((*track)->getColor());
-        t_paint.drawPolygon(arrow, 4);
-        t_paint.end();
+        drawLine(line, extRect, p);
 
 
-        foreach(pt,line)
+        if(showBullets)
         {
-            if((abs(pt.x() - pt1.x()) + abs(pt.y() - pt1.y())) < 7) continue;
-            if(showBullets)
+            foreach(pt,line)
             {
+                if(!rect.contains(pt)) continue;
+                if((abs(pt.x() - pt1.x()) + abs(pt.y() - pt1.y())) < 7) continue;
                 p.drawPixmap(pt.x() - 3 ,pt.y() - 3, bullet);
+                pt1 = pt;
             }
-
-            if(start)            // no arrow on  the first loop
-            {
-                start = false;
-            }
-            else
-            {
-                                 // keep distance
-                if((abs(pt.x() - ptt.x()) + abs(pt.y() - ptt.y())) > 50)
-                {
-                    if(0 != pt.x() - pt1.x() && (pt.y() - pt1.y()))
-                    {
-                        heading = ( atan2((double)(pt.y() - pt1.y()), (double)(pt.x() - pt1.x())) * 180.) / PI;
-                        p.save();
-                        // draw arrow between bullets
-                        p.translate((pt.x() + pt1.x())/2, (pt.y() + pt1.y())/2);
-                        p.rotate(heading);
-                        p.drawImage(-11, -7, arrow_pic);
-                        p.restore();
-                        ptt = pt;//remember last point
-                    }
-                }
-            }
-            pt1 = pt;
         }
 
+        p.setBrush((*track)->getColor());
+        drawArrows(line, rect, p);
+
         pt1 = QPoint();
         foreach(pt,selected)
         {
@@ -999,9 +1101,29 @@ void CTrackDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
             p.drawLine(focus + QPoint(0,-20),focus + QPoint(0,20));
             p.drawLine(focus + QPoint(-20,0),focus + QPoint(20,0));
         }
-    }
 
-    p.setRenderHint(QPainter::Antialiasing, false);
+
+        QString val, unit;
+
+        if(CResources::self().showTrackMax())
+        {
+            if((*track)->ptMaxEle.ele != WPT_NOFLOAT)
+            {
+                IUnit::self().meter2elevation((*track)->ptMaxEle.ele, val, unit);
+                drawMarker(p, tr("Hmax=%1%2").arg(val).arg(unit), (*track)->ptMaxEle);
+            }
+            if((*track)->ptMinEle.ele != WPT_NOFLOAT)
+            {
+                IUnit::self().meter2elevation((*track)->ptMinEle.ele, val, unit);
+                drawMarker(p, tr("Hmin=%1%2").arg(val).arg(unit), (*track)->ptMinEle);
+            }
+            if((*track)->ptMaxSpeed.speed != WPT_NOFLOAT)
+            {
+                IUnit::self().meter2speed((*track)->ptMaxSpeed.speed, val, unit);
+                drawMarker(p, tr("Vmax=%1%2").arg(val).arg(unit), (*track)->ptMaxSpeed);
+            }
+        }
+    }
 }
 
 
@@ -1113,6 +1235,10 @@ void CTrackDB::emitSigChanged()
 void CTrackDB::emitSigModified()
 {
     emit sigModified();
+    if(highlightedTrack())
+    {
+        emit sigModified(highlightedTrack()->getKey());
+    }
 }
 
 
@@ -1158,7 +1284,15 @@ QList<CTrackDB::keys_t> CTrackDB::keys()
         k2.key      = k1;
         k2.name     = track->name;
         k2.comment  = track->comment.left(32);
-        k2.time     = track->track.first().timestamp;
+        if(track->track.isEmpty())
+        {
+            k2.time     = track->timestamp;
+        }
+        else
+        {
+            k2.time     = track->track.first().timestamp;
+        }
+
 
         icon.fill(track->getColor());
         k2.icon     = icon;
@@ -1188,3 +1322,34 @@ CTrack * CTrackDB::getTrackByKey(const QString& key)
     return tracks[key];
 
 }
+
+void CTrackDB::makeVisible(const QStringList& keys)
+{
+    QRectF r;
+    QString key;
+    foreach(key, keys)
+    {
+
+        CTrack * trk =  tracks[key];
+
+        if(r.isNull())
+        {
+            r = trk->getBoundingRectF();
+        }
+        else
+        {
+            r |= trk->getBoundingRectF();
+        }
+
+    }
+
+    if (!r.isNull ())
+    {
+        CMapDB::self().getMap().zoom(r.left() * DEG_TO_RAD, r.top() * DEG_TO_RAD, r.right() * DEG_TO_RAD, r.bottom() * DEG_TO_RAD);
+    }
+
+    if(keys.size() == 1)
+    {
+        highlightTrack(keys[0]);
+    }
+}
