@@ -40,7 +40,6 @@ class CTrackDB : public IDB
 
         void loadGPX(CGpx& gpx);
         void saveGPX(CGpx& gpx, const QStringList& keys);
-        void loadQLB(CQlb& qlb);
         void loadQLB(CQlb& qlb, bool asDuplicat);
         void saveQLB(CQlb& qlb);
 
@@ -102,6 +101,10 @@ class CTrackDB : public IDB
         static bool keyLessThanAlpha(keys_t&  s1, keys_t&  s2);
         static bool keyLessThanTime(keys_t&  s1, keys_t&  s2);
 
+        void makeVisible(const QStringList& keys);
+
+        bool contains(const QString& key){return tracks.contains(key);}
+
         signals:
         void sigHighlightTrack(CTrack * track);
 
@@ -111,6 +114,9 @@ class CTrackDB : public IDB
         friend class CTrackEditWidget;
 
         CTrackDB(QTabWidget * tb, QObject * parent);
+        void drawLine(const QPolygon& line, const QRect& extViewport, QPainter& p);
+        void drawArrows(const QPolygon& line, const QRect& viewport, QPainter& p);
+
         quint32 cnt;
 
         static CTrackDB * m_self;
