@@ -31,6 +31,7 @@ class CTrack;
 class CTrackStatProfileWidget;
 class CTrackStatSpeedWidget;
 class CTrackStatTraineeWidget;
+class CTrackStatDistanceWidget;
 class QMenu;
 
 #ifdef GPX_EXTENSIONS
@@ -72,6 +73,7 @@ class CTrackEditWidget : public QWidget, private Ui::ITrackEditWidget
         void slotToggleStatDistance();
         void slotToggleStatTime();
         void slotToggleTrainee();
+        void slotShowProfile();
 
 #ifdef GPX_EXTENSIONS
         //TODO: Deklaration der Methode fr die Extensions Graphen
@@ -87,6 +89,8 @@ class CTrackEditWidget : public QWidget, private Ui::ITrackEditWidget
     protected slots:
         void slotContextMenu(const QPoint& pos);
         void slotSplit();
+        void slotColorChanged(int idx);
+        void slotNameChanged(const QString&);
 
     protected:
         void keyPressEvent(QKeyEvent * e);
@@ -116,28 +120,19 @@ class CTrackEditWidget : public QWidget, private Ui::ITrackEditWidget
         QPointer<CTrackStatSpeedWidget> trackStatSpeedDist;
         QPointer<CTrackStatProfileWidget> trackStatProfileTime;
         QPointer<CTrackStatSpeedWidget> trackStatSpeedTime;
+        QPointer<CTrackStatDistanceWidget> trackStatDistanceTime;
         QPointer<CTrackStatTraineeWidget> trackStatTrainee;
 
 #ifdef GPX_EXTENSIONS
-                                 //TODO: Namen der extensions
-        QList<QString> names_of_ext;
-        int num_of_ext;          //TODO: Anzahl der extensions
-
         QList<QCheckBox *> c_boxes;
 
-                                 //TODO: QPointer for tabs to be handled
-        QPointer<CTrackStatExtensionWidget> tab;
-
-                                 //TODO: QList with all extension tabs made for further handling
-        QList<CTrackStatExtensionWidget *> tabs;
+        //QList with all extension tabs made for further handling
+        QList<CTrackStatExtensionWidget *> trackStatExtensions;
 
         QSpacerItem *Vspace;     //TODO: Spacer Item
 
-        QLabel *label;
-
         int tabstat;
         int no_ext_info_stat;
-        int count;
 #endif
 
         QMenu * contextMenu;
