@@ -42,7 +42,7 @@ CTrackToolWidget::CTrackToolWidget(QTabWidget * parent)
 {
     setupUi(this);
     setObjectName("Tracks");
-    parent->addTab(this,QIcon(":/icons/iconTrack16x16"),"");
+    parent->addTab(this,QIcon(":/icons/iconTrack16x16.png"),"");
     parent->setTabToolTip(parent->indexOf(this), tr("Tracks"));
 
     connect(&CTrackDB::self(), SIGNAL(sigChanged()), this, SLOT(slotDBChanged()));
@@ -53,11 +53,14 @@ CTrackToolWidget::CTrackToolWidget(QTabWidget * parent)
 
     contextMenu     = new QMenu(this);
     actEdit         = contextMenu->addAction(QPixmap(":/icons/iconEdit16x16.png"),tr("Edit..."),this,SLOT(slotEdit()));
-    actFilter       = contextMenu->addAction(QPixmap(":/icons/iconFilter16x16.png"),tr("Filter..."),this,SLOT(slotFilter()));
+    actFilter       = contextMenu->addAction(QPixmap(":/icons/iconFilter16x16.png"),tr("Filter..."),this,SLOT(slotFilter()));        
     actRevert       = contextMenu->addAction(QPixmap(":/icons/iconReload16x16.png"),tr("Revert"),this,SLOT(slotRevert()));
+    contextMenu->addSeparator();
     actDistance     = contextMenu->addAction(QPixmap(":/icons/iconDistance16x16.png"),tr("Make Overlay"),this,SLOT(slotToOverlay()));
+    contextMenu->addSeparator();
     actHide         = contextMenu->addAction(tr("Show"),this,SLOT(slotShow()));
     actShowBullets  = contextMenu->addAction(tr("Show Bullets"),this,SLOT(slotShowBullets()));
+    contextMenu->addSeparator();
     actZoomToFit    = contextMenu->addAction(QPixmap(":/icons/iconZoomArea16x16.png"),tr("Zoom to fit"),this,SLOT(slotZoomToFit()));
     actDel          = contextMenu->addAction(QPixmap(":/icons/iconClear16x16.png"),tr("Delete"),this,SLOT(slotDelete()));
 
@@ -81,6 +84,7 @@ CTrackToolWidget::CTrackToolWidget(QTabWidget * parent)
     toolSortAlpha->setChecked(cfg.value("track/sortAlpha", true).toBool());
     toolSortTime->setChecked(cfg.value("track/sortTime", true).toBool());
 
+    listTracks->installEventFilter(this);
 }
 
 
@@ -97,6 +101,8 @@ void CTrackToolWidget::slotDBChanged()
 {
     if(originator) return;
 
+//    qDebug() << "void CTrackToolWidget::slotDBChanged()";
+
     if(toolSortAlpha->isChecked())
     {
         sortmode = eSortByName;
@@ -110,6 +116,7 @@ void CTrackToolWidget::slotDBChanged()
     QFontMetrics fm(listTracks->font());
     QPixmap icon(15,N_LINES*fm.height());
     listTracks->clear();
+    listTracks->setIconSize(icon.size());
 
     QListWidgetItem * highlighted = 0;
 
@@ -138,41 +145,9 @@ void CTrackToolWidget::slotDBChanged()
         }
         p.end();
 
-        QString val1, unit1, val2, unit2;
 
-        QString str     = track->getName();
-        double distance = track->getTotalDistance();
-
-        IUnit::self().meter2distance(track->getTotalDistance(), val1, unit1);
-        str += tr("\nlength: %1 %2").arg(val1).arg(unit1);
-        str += tr(", points: %1").arg(track->getTrackPoints().count());
-
-        quint32 ttime = track->getTotalTime();
-        quint32 days  = ttime / 86400;
-
-        QTime time;
-        time = time.addSecs(ttime);
-        if(days)
-        {
-            str += tr("\ntime: %1:").arg(days) + time.toString("HH:mm:ss");
-        }
-        else
-        {
-            str += tr("\ntime: ") + time.toString("HH:mm:ss");
-        }
-
-        IUnit::self().meter2speed(distance / ttime, val1, unit1);
-        str += tr(", speed: %1 %2").arg(val1).arg(unit1);
-
-        str += tr("\nstart: %1").arg(track->getStartTimestamp().isNull() ? tr("-") : track->getStartTimestamp().toString());
-        str += tr("\nend: %1").arg(track->getEndTimestamp().isNull() ? tr("-") : track->getEndTimestamp().toString());
-
-        IUnit::self().meter2elevation(track->getAscend(), val1, unit1);
-        IUnit::self().meter2elevation(track->getDescend(), val2, unit2);
-
-        str += tr("\n%1%2 %3, %4%5 %6").arg(QChar(0x2191)).arg(val1).arg(unit1).arg(QChar(0x2193)).arg(val2).arg(unit2);
-        item->setText(str);
-        item->setData(Qt::UserRole, track->key());
+        item->setText(track->getInfo());
+        item->setData(Qt::UserRole, track->getKey());
         item->setIcon(icon);
 
         if(track->isHighlighted())
@@ -210,7 +185,11 @@ void CTrackToolWidget::slotItemClicked(QListWidgetItem * item)
 
 void CTrackToolWidget::slotSelectionChanged()
 {
-    qDebug() << "void CTrackToolWidget::slotSelectionChanged()" << listTracks->selectedItems().isEmpty() << listTracks->hasFocus();
+    if(originator)
+    {
+        return;
+    }
+//    qDebug() << "void CTrackToolWidget::slotSelectionChanged()" << listTracks->selectedItems().isEmpty() << listTracks->hasFocus();
     if(listTracks->hasFocus() && listTracks->selectedItems().isEmpty())
     {
         CTrackDB::self().highlightTrack("");
@@ -289,17 +268,45 @@ void CTrackToolWidget::slotEdit()
     }
 }
 
+void CTrackToolWidget::slotShowProfile()
+{
+    const QListWidgetItem* item = listTracks->currentItem();
+
+    if(item == 0)
+    {
+        QMessageBox::information(0,tr("Edit track ..."), tr("You have to select a track first."),QMessageBox::Ok,QMessageBox::Ok);
+        return;
+    };
+
+    if(trackedit.isNull())
+    {
+        trackedit = new CTrackEditWidget(theMainWindow->getCanvas());
+        connect(&CTrackDB::self(), SIGNAL(sigHighlightTrack(CTrack*)), trackedit, SLOT(slotSetTrack(CTrack*)));
+        theMainWindow->setTempWidget(trackedit, tr("Track"));
+        trackedit->slotSetTrack(CTrackDB::self().highlightedTrack());
+    }
+    trackedit->slotShowProfile();
+
+
+}
+
 
 void CTrackToolWidget::slotDelete()
 {
     QStringList keys;
     QListWidgetItem * item;
-    const QList<QListWidgetItem*>& items = listTracks->selectedItems();
+    QList<QListWidgetItem*> items = listTracks->selectedItems();
     foreach(item,items)
     {
         keys << item->data(Qt::UserRole).toString();
     }
+
     CTrackDB::self().delTracks(keys);
+
+    if(!trackedit.isNull())
+    {
+        trackedit->deleteLater();
+    }
 }
 
 
@@ -344,7 +351,7 @@ void CTrackToolWidget::slotToOverlay()
             pts << pt;
         }
 
-        COverlayDB::self().addDistance(track->name, tr("created from track"), 0.0, pts);
+        COverlayDB::self().addDistance(track->getName(), tr("created from track"), 0.0, pts);
     }
 
     CMegaMenu::self().switchByKeyWord("Overlay");
@@ -409,3 +416,14 @@ void CTrackToolWidget::slotShowBullets()
     CTrackDB::self().setShowBullets(!CTrackDB::self().getShowBullets());
 
 }
+
+bool CTrackToolWidget::eventFilter(QObject *obj, QEvent *event)
+{
+
+    if(event->type() == QEvent::Leave)
+    {
+        listTracks->clearFocus();
+    }
+
+    return QObject::eventFilter(obj, event);
+}
