@@ -46,10 +46,12 @@ class CTrackToolWidget : public QWidget, private Ui::ITrackToolWidget
 
     public slots:
         void slotEdit();
+        void slotShowProfile();
         void slotDBChanged();
 
     protected:
         void keyPressEvent(QKeyEvent * e);
+        bool eventFilter(QObject *obj, QEvent *event);
 
     private slots:
         void slotItemDoubleClicked(QListWidgetItem * item);
