@@ -22,39 +22,47 @@
 #include "CWptDB.h"
 #include "CMapDB.h"
 #include "CTrackDB.h"
+#include "CRouteDB.h"
 #include "COverlayDB.h"
 #include "CWpt.h"
-#include "CTrack.h"
 #include "CMainWindow.h"
 #include "CResources.h"
 #include "IOverlay.h"
 #include "IUnit.h"
+#include "IMap.h"
 #include "CDlgEditWpt.h"
 #include "GeoMath.h"
 #include "CSearch.h"
 #include "CSearchDB.h"
-#include "WptIcons.h"
+#include "IMapSelection.h"
 #include <QtGui>
 
 QPointer<IOverlay> IMouse::selOverlay;
 
+QPointF IMouse::pos1Pixel(-1,-1);
+QPointF IMouse::pos1LonLat(-1,-1);
+
 IMouse::IMouse(CCanvas * canvas)
 : QObject(canvas)
 , cursor(QPixmap(":/cursor/Arrow"))
 , canvas(canvas)
 , selTrkPt(0)
+, selRtePt(0)
 , doSpecialCursorWpt(false)
 , doSpecialCursorSearch(false)
+, doShowWptBuddies(false)
 {
-    rectDelWpt          = QRect(0,0,16,16);
-    rectMoveWpt         = QRect(32,0,16,16);
-    rectEditWpt         = QRect(0,32,16,16);
-    rectCopyWpt         = QRect(32,32,16,16);
+    rectMarkWpt         = QRect(16,-8,16,16);
+    rectDelWpt          = QRect(-5, 3,16,16);
+    rectMoveWpt         = QRect(37, 3,16,16);
+    rectEditWpt         = QRect(-5,29,16,16);
+    rectCopyWpt         = QRect(37,29,16,16);
     rectViewWpt         = QRect(16,40,16,16);
 
     rectDelSearch       = QRect(0,0,16,16);
     rectConvertSearch   = QRect(0,32,16,16);
     rectCopySearch      = QRect(32,32,16,16);
+
 }
 
 
@@ -87,6 +95,34 @@ void IMouse::drawRect(QPainter& p)
 }
 
 
+#define LENGTH 100
+void IMouse::drawPos1(QPainter& p)
+{
+    if(pos1Pixel.x() == -1 || pos1Pixel.y() == -1)
+    {
+        return;
+    }
+
+    IMap& map = CMapDB::self().getMap();
+    double u = pos1LonLat.x();
+    double v = pos1LonLat.y();
+    map.convertRad2Pt(u,v);
+
+    p.setPen(QPen(Qt::white, 5));
+    p.drawLine(u - 10, v, u + LENGTH, v);
+    p.drawLine(u, v - 10, u, v + LENGTH);
+
+    p.setPen(QPen(Qt::blue, 3));
+    p.drawLine(u - 10, v, u + LENGTH, v);
+    p.drawLine(u, v - 10, u, v + LENGTH);
+
+    CCanvas::drawText("Pos. 1",p, QRect(u,v, LENGTH, - 20));
+
+    QString fn = map.getFilename(u, v);
+    QFileInfo fi(fn);
+    CCanvas::drawText(fi.fileName(), p, QRect(u,v, LENGTH, 20));
+}
+
 void IMouse::drawSelWpt(QPainter& p)
 {
     IMap& map = CMapDB::self().getMap();
@@ -96,83 +132,93 @@ void IMouse::drawSelWpt(QPainter& p)
         double v = selWpt->lat * DEG_TO_RAD;
         map.convertRad2Pt(u,v);
 
-        p.setPen(QColor(100,100,255,200));
-        p.setBrush(QColor(255,255,255,200));
+        QPixmap icon = selWpt->getIcon().scaled(16,16, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+
+
+        p.setPen(CCanvas::penBorderBlue);
+        p.setBrush(CCanvas::brushBackWhite);
         p.drawEllipse(u - 35, v - 35, 70, 70);
-        p.drawPixmap(u-7 , v-7, getWptIconByName(selWpt->icon));
+        p.drawPixmap(u - 8 , v - 8, icon);
 
         p.save();
         p.translate(u - 24, v - 24);
-        if(!selWpt->sticky)
+
+        if(selWpt->isDeletable())
         {
             p.drawPixmap(rectDelWpt, QPixmap(":/icons/iconClear16x16.png"));
+        }
+
+        if(selWpt->isMovable())
+        {
             p.drawPixmap(rectMoveWpt, QPixmap(":/icons/iconMove16x16.png"));
         }
+        else if(selWpt->isGeoCache() && selWpt->hasBuddies())
+        {
+            p.drawPixmap(rectMoveWpt, QPixmap(":/icons/iconWaypoint16x16.png"));
+        }
+
         p.drawPixmap(rectEditWpt, QPixmap(":/icons/iconEdit16x16.png"));
         p.drawPixmap(rectCopyWpt, QPixmap(":/icons/iconClipboard16x16.png"));
         if(!selWpt->images.isEmpty() && !selWpt->images[0].filePath.isEmpty())
         {
             p.drawPixmap(rectViewWpt, QPixmap(":/icons/iconRaster16x16.png"));
         }
+
+        if(selWpt->selected)
+        {
+            p.drawPixmap(rectMarkWpt, QPixmap(":/icons/iconCheckbox16x16.png"));
+        }
+
         p.restore();
 
-        QString str;
-        if(selWpt->timestamp != 0x00000000 && selWpt->timestamp != 0xFFFFFFFF)
+        if(doShowWptBuddies)
         {
-            QDateTime time = QDateTime::fromTime_t(selWpt->timestamp);
-            time.setTimeSpec(Qt::LocalTime);
-            str = time.toString();
+            return;
         }
 
-        if(selWpt->ele != WPT_NOFLOAT)
-        {
-            if(str.count()) str += "\n";
-            QString val, unit;
-            IUnit::self().meter2elevation(selWpt->ele, val, unit);
-            str += tr("elevation: %1 %2").arg(val).arg(unit);
-        }
-
-        if(selWpt->comment.count())
-        {
-            if(str.count()) str += "\n";
-
-            if(selWpt->comment.count() < 200)
-            {
-                str += selWpt->comment;
-            }
-            else
-            {
-                str += selWpt->comment.left(197) + "...";
-            }
-
-        }
-
-        QFont           f = CResources::self().getMapFont();
+        QString         str = selWpt->getInfo();
+        QFont           f   = CResources::self().getMapFont();
         QFontMetrics    fm(f);
-        QRect           r1 = fm.boundingRect(QRect(0,0,300,0), Qt::AlignLeft|Qt::AlignTop|Qt::TextWordWrap, str);
-        r1.moveTopLeft(QPoint(u + 45, v));
+        QRect           r1  = fm.boundingRect(QRect(0,0,300,0), Qt::AlignLeft|Qt::AlignTop|Qt::TextWordWrap, str);
+        r1.moveTopLeft(QPoint(u + 55, v));
 
         QRect           r2 = r1;
-        r2.setWidth(r1.width() + 4);
-        r2.moveLeft(r1.left() - 2);
+        r2.setWidth(r1.width() + 20);
+        r2.moveLeft(r1.left() - 10);
+        r2.setHeight(r1.height() + 20);
+        r2.moveTop(r1.top() - 10);
+
+        p.setPen(CCanvas::penBorderBlue);
+        p.setBrush(CCanvas::brushBackWhite);
+        PAINT_ROUNDED_RECT(p,r2);
 
-        p.setPen(QColor(100,100,255,200));
-        p.setBrush(QColor(255,255,255,200));
-        p.drawRect(r2);
 
         p.setFont(CResources::self().getMapFont());
         p.setPen(Qt::darkBlue);
-        p.drawText(r1, Qt::AlignLeft|Qt::AlignTop|Qt::TextWordWrap,str);
+        p.drawText(r1, Qt::AlignJustify|Qt::AlignTop|Qt::TextWordWrap,str);
 
         if(!selWpt->images.isEmpty())
         {
             QRect r = selWpt->images[0].pixmap.rect();
 
+            if(r.width() > 300)
+            {
+                qint32 h = r.height() * 300 / r.width();
+
+                r.setWidth(300);
+                r.setHeight(h);
+            }
+
             p.save();
-            p.translate(u - (r.width() + 40), v);
-            p.setPen(QPen(Qt::white,3));
-            p.drawRect(r);
-            p.drawPixmap(0,0,selWpt->images[0].pixmap);
+            p.translate(u - (r.width() + 45), v);
+            r.adjust(-1,-1,+1,+1);
+
+            p.drawPixmap(0,0,selWpt->images[0].pixmap.scaled(r.size(), Qt::IgnoreAspectRatio, Qt::SmoothTransformation));
+
+            p.setPen(CCanvas::penBorderBlue);
+            p.setBrush(Qt::NoBrush);
+            PAINT_ROUNDED_RECT(p,r);
+
             p.restore();
         }
 
@@ -189,8 +235,8 @@ void IMouse::drawSelSearch(QPainter& p)
         double v = selSearch->lat * DEG_TO_RAD;
         map.convertRad2Pt(u,v);
 
-        p.setPen(QColor(100,100,255,200));
-        p.setBrush(QColor(255,255,255,200));
+        p.setPen(CCanvas::penBorderBlue);
+        p.setBrush(CCanvas::brushBackWhite);
         p.drawEllipse(u - 35, v - 35, 70, 70);
         p.drawPixmap(u-8 , v-8, QPixmap(":/icons/iconBullseye16x16"));
 
@@ -207,15 +253,23 @@ void IMouse::drawSelSearch(QPainter& p)
 
 void IMouse::drawSelTrkPt(QPainter& p)
 {
-    IMap& map = CMapDB::self().getMap();
+    IMap& map       = CMapDB::self().getMap();
+
     if(selTrkPt && !selWpt)
     {
+        CTrack * track = CTrackDB::self().highlightedTrack();
+        if(track == 0)
+        {
+            return;
+        }
+
+        QString val, unit;
         double u = selTrkPt->lon * DEG_TO_RAD;
         double v = selTrkPt->lat * DEG_TO_RAD;
         map.convertRad2Pt(u,v);
 
-        p.setPen(QColor(100,100,255,200));
-        p.setBrush(QColor(255,255,255,200));
+        p.setPen(CCanvas::penBorderBlue);
+        p.setBrush(CCanvas::brushBackWhite);
         p.drawEllipse(QRect(u - 5,  v - 5, 11, 11));
 
         QString str;
@@ -224,15 +278,45 @@ void IMouse::drawSelTrkPt(QPainter& p)
             QDateTime time = QDateTime::fromTime_t(selTrkPt->timestamp);
             time.setTimeSpec(Qt::LocalTime);
             str = time.toString();
+
+            quint32 total = track->getTotalTime();
+            if(total)
+            {
+                quint32 t1s = selTrkPt->timeSinceStart;
+                quint32 t2s = total - selTrkPt->timeSinceStart;
+
+                quint32 t1h = qreal(t1s)/3600;
+                quint32 t2h = qreal(t2s)/3600;
+
+                quint32 t1m = quint32(qreal(t1s - t1h * 3600)/60  + 0.5);
+                quint32 t2m = quint32(qreal(t2s - t2h * 3600)/60  + 0.5);
+
+                quint32 t1p = quint32(qreal(100 * t1s) / total + 0.5);
+                quint32 t2p = 100 - t1p;
+
+
+                str += "\n";
+                str += tr("%4 %3 %1:%2h (%5%)").arg(t1h).arg(t1m, 2, 10, QChar('0')).arg(QChar(0x21A4)).arg(QChar(0x2690)).arg(t1p);
+                str += tr(" | (%5%) %1:%2h %3 %4").arg(t2h).arg(t2m, 2, 10, QChar('0')).arg(QChar(0x21A6)).arg(QChar(0x2691)).arg(t2p);
+            }
+
         }
 
+        if(str.count()) str += "\n";
+        IUnit::self().meter2distance(selTrkPt->distance, val, unit);
+        str += tr("%5 %4 %1%2 (%3%)").arg(val).arg(unit).arg(selTrkPt->distance * 100.0 / track->getTotalDistance(),0,'f',0).arg(QChar(0x21A4)).arg(QChar(0x2690));
+        IUnit::self().meter2distance(track->getTotalDistance() - selTrkPt->distance, val, unit);
+        str += tr(" | (%3%) %1%2 %4 %5").arg(val).arg(unit).arg((track->getTotalDistance() - selTrkPt->distance) * 100.0 / track->getTotalDistance(),0,'f',0).arg(QChar(0x21A6)).arg(QChar(0x2691));
+
         if(selTrkPt->ele != WPT_NOFLOAT)
         {
             if(str.count()) str += "\n";
-            QString val, unit;
             IUnit::self().meter2elevation(selTrkPt->ele, val, unit);
             str += tr("elevation: %1 %2").arg(val).arg(unit);
         }
+
+
+
         //-----------------------------------------------------------------------------------------------------------
         //TODO: HOVERTEXT FOR EXTENSIONS
 #ifdef GPX_EXTENSIONS
@@ -261,12 +345,15 @@ void IMouse::drawSelTrkPt(QPainter& p)
             r1.moveTopLeft(QPoint(u + 45, v));
 
             QRect           r2 = r1;
-            r2.setWidth(r1.width() + 4);
-            r2.moveLeft(r1.left() - 2);
+            r2.setWidth(r1.width() + 20);
+            r2.moveLeft(r1.left() - 10);
+            r2.setHeight(r1.height() + 20);
+            r2.moveTop(r1.top() - 10);
 
-            p.setPen(QColor(100,100,255,200));
-            p.setBrush(QColor(255,255,255,200));
-            p.drawRect(r2);
+
+            p.setPen(QPen(CCanvas::penBorderBlue));
+            p.setBrush(CCanvas::brushBackWhite);
+            PAINT_ROUNDED_RECT(p,r2);
 
             p.setFont(CResources::self().getMapFont());
             p.setPen(Qt::darkBlue);
@@ -275,6 +362,43 @@ void IMouse::drawSelTrkPt(QPainter& p)
     }
 }
 
+void IMouse::drawSelRtePt(QPainter& p)
+{
+    IMap& map = CMapDB::self().getMap();
+    if(selRtePt && !selWpt)
+    {
+        double u = selRtePt->lon * DEG_TO_RAD;
+        double v = selRtePt->lat * DEG_TO_RAD;
+        map.convertRad2Pt(u,v);
+
+        p.setPen(CCanvas::penBorderBlue);
+        p.setBrush(CCanvas::brushBackWhite);
+        p.drawEllipse(QRect(u - 5,  v - 5, 11, 11));
+
+        QString         str = selRtePt->action;
+        QFont           f = CResources::self().getMapFont();
+        QFontMetrics    fm(f);
+        QRect           r1 = fm.boundingRect(QRect(0,0,300,0), Qt::AlignLeft|Qt::AlignTop|Qt::TextWordWrap, str);
+        r1.moveTopLeft(QPoint(u + 45, v));
+
+        QRect           r2 = r1;
+        r2.setWidth(r1.width() + 20);
+        r2.moveLeft(r1.left() - 10);
+        r2.setHeight(r1.height() + 20);
+        r2.moveTop(r1.top() - 10);
+
+
+        p.setPen(QPen(CCanvas::penBorderBlue));
+        p.setBrush(CCanvas::brushBackWhite);
+        PAINT_ROUNDED_RECT(p,r2);
+
+        p.setFont(CResources::self().getMapFont());
+        p.setPen(Qt::darkBlue);
+        p.drawText(r1, Qt::AlignLeft|Qt::AlignTop|Qt::TextWordWrap,str);
+    }
+}
+
+
 
 void IMouse::mouseMoveEventWpt(QMouseEvent * e)
 {
@@ -324,6 +448,22 @@ void IMouse::mouseMoveEventWpt(QMouseEvent * e)
                 doSpecialCursorWpt = false;
             }
         }
+
+        if(selWpt->isGeoCache())
+        {
+            if(!doShowWptBuddies && rectMoveWpt.contains((pt)))
+            {
+                selWpt->showBuddies(true);
+                doShowWptBuddies = true;
+                canvas->update();
+            }
+            else if(!rectMoveWpt.contains(pt))
+            {
+                selWpt->showBuddies(false);
+                doShowWptBuddies = false;
+                canvas->update();
+            }
+        }
     }
     else
     {
@@ -332,6 +472,12 @@ void IMouse::mouseMoveEventWpt(QMouseEvent * e)
             QApplication::restoreOverrideCursor();
             doSpecialCursorWpt = false;
         }
+
+        if(oldWpt)
+        {
+            oldWpt->showBuddies(false);
+            doShowWptBuddies = false;
+        }
     }
 
     // do a canvas update on a change only
@@ -421,9 +567,9 @@ void IMouse::mousePressEventWpt(QMouseEvent * e)
     QPoint pt = pos - QPoint(u - 24, v - 24);
     if(rectDelWpt.contains(pt) && !selWpt->sticky)
     {
-        CWptDB::self().delWpt(selWpt->key(), false, true);
+        CWptDB::self().delWpt(selWpt->getKey(), false, true);
     }
-    else if(rectMoveWpt.contains(pt) && !selWpt->sticky)
+    else if(rectMoveWpt.contains(pt) && selWpt->isMovable())
     {
         canvas->setMouseMode(CCanvas::eMouseMoveWpt);
 
@@ -451,7 +597,12 @@ void IMouse::mousePressEventWpt(QMouseEvent * e)
     }
     else if(rectViewWpt.contains(pt) && !selWpt->images.isEmpty() && !selWpt->images[0].filePath.isEmpty())
     {
-        CResources::self().openLink("file:///" + selWpt->images[0].filePath);
+        QDesktopServices::openUrl(QUrl("file:///" + selWpt->images[0].filePath));
+    }
+    else if(rectMarkWpt.contains(pt))
+    {
+        CWptDB::self().selWptByKey(selWpt->getKey(), true);
+        canvas->update();
     }
 }
 
@@ -470,20 +621,22 @@ void IMouse::mousePressEventSearch(QMouseEvent * e)
     if(rectDelSearch.contains(pt))
     {
         QStringList keys;
-        keys << selSearch->query;
+        keys << selSearch->getKey();
         CSearchDB::self().delResults(keys);
         selSearch = 0;
         canvas->update();
     }
     else if(rectConvertSearch.contains(pt))
     {
+        QString key = selSearch->getKey();
         float ele = CMapDB::self().getDEM().getElevation(selSearch->lon * DEG_TO_RAD, selSearch->lat * DEG_TO_RAD);
-        CWpt * wpt = CWptDB::self().newWpt(selSearch->lon * DEG_TO_RAD, selSearch->lat * DEG_TO_RAD, ele);
+        CWpt * wpt = CWptDB::self().newWpt(selSearch->lon * DEG_TO_RAD, selSearch->lat * DEG_TO_RAD, ele, selSearch->getName());
         if(wpt)
         {
             selWpt = wpt;
             QStringList keys;
-            keys << selSearch->query;
+
+            keys << key;
             CSearchDB::self().delResults(keys);
             canvas->update();
         }
@@ -503,6 +656,7 @@ void IMouse::mousePressEventSearch(QMouseEvent * e)
 }
 
 
+
 void IMouse::mouseMoveEventTrack(QMouseEvent * e)
 {
     CTrack * track = CTrackDB::self().highlightedTrack();
@@ -533,6 +687,50 @@ void IMouse::mouseMoveEventTrack(QMouseEvent * e)
     }
 
     if(oldTrackPt != selTrkPt)
+    {        
+        canvas->update();
+        emit sigTrkPt(selTrkPt);
+    }
+
+}
+
+void IMouse::mouseMoveEventRoute(QMouseEvent * e)
+{
+    CRoute * route = CRouteDB::self().highlightedRoute();
+    if(route == 0) return;
+
+    IMap& map = CMapDB::self().getMap();
+    double u,v;
+
+    CRoute::pt_t * oldRoutePt = selRtePt;
+    int d1      = 20;
+    selRtePt    = 0;
+
+    QVector<CRoute::pt_t>& pts          = route->getSecRtePoints().isEmpty() ? route->getPriRtePoints() : route->getSecRtePoints();
+    QVector<CRoute::pt_t>::iterator pt  = pts.begin();
+    while(pt != pts.end())
+    {
+        if(pt->action.isEmpty())
+        {
+            ++pt; continue;
+        }
+
+        u = pt->lon * DEG_TO_RAD;
+        v = pt->lat * DEG_TO_RAD;
+        map.convertRad2Pt(u,v);
+
+        int d2 = abs(e->pos().x() - u) + abs(e->pos().y() - v);
+
+        if(d2 < d1)
+        {
+            selRtePt = &(*pt);
+            d1 = d2;
+        }
+
+        ++pt;
+    }
+
+    if(oldRoutePt != selRtePt)
     {
         canvas->update();
     }
@@ -569,7 +767,7 @@ void IMouse::mouseMoveEventOverlay(QMouseEvent * e)
 
     if(oldOverlay != selOverlay)
     {
-        if(selOverlay)
+        if(selOverlay && selOverlay->visible())
         {
             canvas->setMouseMode(CCanvas::eMouseOverlay);
         }
@@ -580,3 +778,56 @@ void IMouse::mouseMoveEventOverlay(QMouseEvent * e)
         canvas->update();
     }
 }
+
+void IMouse::mouseMoveEventMapSel(QMouseEvent * e)
+{
+
+    IMapSelection * oldSel = selMap;
+
+    IMap& map = CMapDB::self().getMap();
+    double u = e->pos().x();
+    double v = e->pos().y();
+
+    map.convertPt2Rad(u,v);
+
+    selMap = CMapDB::self().getSelectedMap(u,v);
+
+    if(selMap && !oldSel)
+    {
+        theMainWindow->getCanvas()->setMouseMode(CCanvas::eMouseSelectArea);
+    }
+    else if(!selMap && oldSel)
+    {
+        theMainWindow->getCanvas()->setMouseMode(CCanvas::eMouseMoveArea);
+    }
+
+
+    if(selMap != oldSel)
+    {
+        canvas->update();
+    }
+
+}
+
+void IMouse::slotSetPos1()
+{
+    IMap& map = CMapDB::self().getMap();
+
+    double u,v;
+    u = mousePos.x();
+    v = mousePos.y();
+    map.convertPt2Pixel(u,v);
+    pos1Pixel = QPointF(u,v);
+
+    u = mousePos.x();
+    v = mousePos.y();
+    map.convertPt2Rad(u,v);
+    pos1LonLat = QPointF(u,v);
+}
+
+
+void IMouse::setSelTrackPt(CTrack::pt_t * pt)
+{
+    selTrkPt = pt;
+    canvas->update();
+}
