@@ -40,11 +40,11 @@ ITrackStat::ITrackStat(type_e type, QWidget * parent)
 
     if(type == eOverDistance)
     {
-        plot = new CPlot(CPlotData::eLinear,this);
+        plot = new CPlot(CPlotData::eLinear, CPlot::eNormal, this);
     }
     else
     {
-        plot = new CPlot(CPlotData::eTime,this);
+        plot = new CPlot(CPlotData::eTime, CPlot::eNormal, this);
     }
     layout()->addWidget(plot);
     QObject::connect(plot, SIGNAL(activePointSignal(double)), this, SLOT(activePointEvent(double)));
@@ -75,12 +75,12 @@ void ITrackStat::activePointEvent(double dist)
 
         if(type == eOverDistance && dist < trkpt->distance)
         {
-            track->setPointOfFocus(idx);
+            track->setPointOfFocus(idx, true, true);
             break;
         }
         if(type == eOverTime && dist < trkpt->timestamp)
         {
-            track->setPointOfFocus(idx);
+            track->setPointOfFocus(idx, true, true);
             break;
         }
         idx = trkpt->idx;
